@@ -3,11 +3,15 @@
  * @copyright Copyright (c) 2016, ownCloud, Inc.
  * @copyright Copyright (c) 2017 Georg Ehrke
  *
+ * @author Georg Ehrke <oc.list@georgehrke.com>
  * @author Joas Schilling <coding@schilljs.com>
+ * @author Lukas Reschke <lukas@statuscode.ch>
+ * @author nhirokinet <nhirokinet@nhiroki.net>
+ * @author Robin Appelman <robin@icewind.nl>
+ * @author Roeland Jago Douma <roeland@famdouma.nl>
  * @author Stefan Weil <sw@weilnetz.de>
  * @author Thomas Citharel <tcit@tcit.fr>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
- * @author Georg Ehrke <oc.list@georgehrke.com>
  *
  * @license AGPL-3.0
  *
@@ -32,6 +36,8 @@ use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCA\DAV\Connector\Sabre\Principal;
 use OCA\DAV\DAV\Sharing\Backend;
 use OCP\IDBConnection;
+use OCP\IGroupManager;
+use OCP\ILogger;
 use OCP\IUser;
 use OCP\IUserManager;
 use OCP\Security\ISecureRandom;
@@ -45,11 +51,16 @@ use Sabre\DAV;
 use Sabre\DAV\Exception\Forbidden;
 use Sabre\DAV\Exception\NotFound;
 use Sabre\DAV\PropPatch;
-use Sabre\HTTP\URLUtil;
+use Sabre\VObject\Component;
 use Sabre\VObject\Component\VCalendar;
+use Sabre\VObject\Component\VTimeZone;
 use Sabre\VObject\DateTimeParser;
+use Sabre\VObject\InvalidDataException;
+use Sabre\VObject\ParseException;
+use Sabre\VObject\Property;
 use Sabre\VObject\Reader;
 use Sabre\VObject\Recur\EventIterator;
+use Sabre\Uri;
 use Symfony\Component\EventDispatcher\EventDispatcherInterface;
 use Symfony\Component\EventDispatcher\GenericEvent;
 
@@ -65,6 +76,9 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 	const PERSONAL_CALENDAR_URI = 'personal';
 	const PERSONAL_CALENDAR_NAME = 'Personal';
 
+	const RESOURCE_BOOKING_CALENDAR_URI = 'calendar';
+	const RESOURCE_BOOKING_CALENDAR_NAME = 'Calendar';
+
 	/**
 	 * We need to specify a max date, because we need to stop *somewhere*
 	 *
@@ -142,6 +156,9 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 	/** @var ISecureRandom */
 	private $random;
 
+	/** @var ILogger */
+	private $logger;
+
 	/** @var EventDispatcherInterface */
 	private $dispatcher;
 
@@ -157,21 +174,26 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 	 * @param IDBConnection $db
 	 * @param Principal $principalBackend
 	 * @param IUserManager $userManager
+	 * @param IGroupManager $groupManager
 	 * @param ISecureRandom $random
+	 * @param ILogger $logger
 	 * @param EventDispatcherInterface $dispatcher
 	 * @param bool $legacyEndpoint
 	 */
 	public function __construct(IDBConnection $db,
 								Principal $principalBackend,
 								IUserManager $userManager,
+								IGroupManager $groupManager,
 								ISecureRandom $random,
+								ILogger $logger,
 								EventDispatcherInterface $dispatcher,
 								$legacyEndpoint = false) {
 		$this->db = $db;
 		$this->principalBackend = $principalBackend;
 		$this->userManager = $userManager;
-		$this->sharingBackend = new Backend($this->db, $principalBackend, 'calendar');
+		$this->sharingBackend = new Backend($this->db, $this->userManager, $groupManager, $principalBackend, 'calendar');
 		$this->random = $random;
+		$this->logger = $logger;
 		$this->dispatcher = $dispatcher;
 		$this->legacyEndpoint = $legacyEndpoint;
 	}
@@ -318,7 +340,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 				}
 			}
 
-			list(, $name) = URLUtil::splitPath($row['principaluri']);
+			list(, $name) = Uri\split($row['principaluri']);
 			$uri = $row['uri'] . '_shared_by_' . $name;
 			$row['displayname'] = $row['displayname'] . ' (' . $this->getUserDisplayName($name) . ')';
 			$components = [];
@@ -332,7 +354,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 				'{' . Plugin::NS_CALENDARSERVER . '}getctag' => 'http://sabre.io/ns/sync/' . ($row['synctoken']?$row['synctoken']:'0'),
 				'{http://sabredav.org/ns}sync-token' => $row['synctoken']?$row['synctoken']:'0',
 				'{' . Plugin::NS_CALDAV . '}supported-calendar-component-set' => new SupportedCalendarComponentSet($components),
-				'{' . Plugin::NS_CALDAV . '}schedule-calendar-transp' => new ScheduleCalendarTransp($row['transparent']?'transparent':'opaque'),
+				'{' . Plugin::NS_CALDAV . '}schedule-calendar-transp' => new ScheduleCalendarTransp('transparent'),
 				'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}owner-principal' => $this->convertPrincipal($row['principaluri'], !$this->legacyEndpoint),
 				$readOnlyPropertyName => $readOnly,
 			];
@@ -432,7 +454,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 			->execute();
 
 		while($row = $result->fetch()) {
-			list(, $name) = URLUtil::splitPath($row['principaluri']);
+			list(, $name) = Uri\split($row['principaluri']);
 			$row['displayname'] = $row['displayname'] . "($name)";
 			$components = [];
 			if ($row['components']) {
@@ -498,7 +520,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 			throw new NotFound('Node with name \'' . $uri . '\' could not be found');
 		}
 
-		list(, $name) = URLUtil::splitPath($row['principaluri']);
+		list(, $name) = Uri\split($row['principaluri']);
 		$row['displayname'] = $row['displayname'] . ' ' . "($name)";
 		$components = [];
 		if ($row['components']) {
@@ -635,6 +657,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 	 * @param string $calendarUri
 	 * @param array $properties
 	 * @return int
+	 * @suppress SqlInjectionChecker
 	 */
 	function createCalendar($principalUri, $calendarUri, array $properties) {
 		$values = [
@@ -695,6 +718,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 	 *
 	 * Read the PropPatch documentation for more info and examples.
 	 *
+	 * @param mixed $calendarId
 	 * @param PropPatch $propPatch
 	 * @return void
 	 */
@@ -702,6 +726,9 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		$supportedProperties = array_keys($this->propertyMap);
 		$supportedProperties[] = '{' . Plugin::NS_CALDAV . '}schedule-calendar-transp';
 
+		/**
+		 * @suppress SqlInjectionChecker
+		 */
 		$propPatch->handle($supportedProperties, function($mutations) use ($calendarId) {
 			$newValues = [];
 			foreach ($mutations as $propertyName => $propertyValue) {
@@ -1166,7 +1193,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 				$requirePostFilter = false;
 			}
 			// There was a time-range filter
-			if ($componentType == 'VEVENT' && isset($filters['comp-filters'][0]['time-range'])) {
+			if ($componentType === 'VEVENT' && isset($filters['comp-filters'][0]['time-range'])) {
 				$timeRange = $filters['comp-filters'][0]['time-range'];
 
 				// If start time OR the end time is not specified, we can do a
@@ -1202,7 +1229,25 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		$result = [];
 		while($row = $stmt->fetch(\PDO::FETCH_ASSOC)) {
 			if ($requirePostFilter) {
-				if (!$this->validateFilterForObject($row, $filters)) {
+				// validateFilterForObject will parse the calendar data
+				// catch parsing errors
+				try {
+					$matches = $this->validateFilterForObject($row, $filters);
+				} catch(ParseException $ex) {
+					$this->logger->logException($ex, [
+						'app' => 'dav',
+						'message' => 'Caught parsing exception for calendar data. This usually indicates invalid calendar data. calendar-id:'.$calendarId.' uri:'.$row['uri']
+					]);
+					continue;
+				} catch (InvalidDataException $ex) {
+					$this->logger->logException($ex, [
+						'app' => 'dav',
+						'message' => 'Caught invalid data exception for calendar data. This usually indicates invalid calendar data. calendar-id:'.$calendarId.' uri:'.$row['uri']
+					]);
+					continue;
+				}
+
+				if (!$matches) {
 					continue;
 				}
 			}
@@ -1331,6 +1376,173 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		return $result;
 	}
 
+	/**
+	 * used for Nextcloud's calendar API
+	 *
+	 * @param array $calendarInfo
+	 * @param string $pattern
+	 * @param array $searchProperties
+	 * @param array $options
+	 * @param integer|null $limit
+	 * @param integer|null $offset
+	 *
+	 * @return array
+	 */
+	public function search(array $calendarInfo, $pattern, array $searchProperties,
+						   array $options, $limit, $offset) {
+		$outerQuery = $this->db->getQueryBuilder();
+		$innerQuery = $this->db->getQueryBuilder();
+
+		$innerQuery->selectDistinct('op.objectid')
+			->from($this->dbObjectPropertiesTable, 'op')
+			->andWhere($innerQuery->expr()->eq('op.calendarid',
+				$outerQuery->createNamedParameter($calendarInfo['id'])));
+
+		// only return public items for shared calendars for now
+		if ($calendarInfo['principaluri'] !== $calendarInfo['{http://owncloud.org/ns}owner-principal']) {
+			$innerQuery->andWhere($innerQuery->expr()->eq('c.classification',
+				$outerQuery->createNamedParameter(self::CLASSIFICATION_PUBLIC)));
+		}
+
+		$or = $innerQuery->expr()->orX();
+		foreach($searchProperties as $searchProperty) {
+			$or->add($innerQuery->expr()->eq('op.name',
+				$outerQuery->createNamedParameter($searchProperty)));
+		}
+		$innerQuery->andWhere($or);
+
+		if ($pattern !== '') {
+			$innerQuery->andWhere($innerQuery->expr()->iLike('op.value',
+				$outerQuery->createNamedParameter('%' .
+					$this->db->escapeLikeParameter($pattern) . '%')));
+		}
+
+		$outerQuery->select('c.id', 'c.calendardata', 'c.componenttype', 'c.uid', 'c.uri')
+			->from('calendarobjects', 'c');
+
+		if (isset($options['timerange'])) {
+			if (isset($options['timerange']['start'])) {
+				$outerQuery->andWhere($outerQuery->expr()->gt('lastoccurence',
+					$outerQuery->createNamedParameter($options['timerange']['start']->getTimeStamp)));
+
+			}
+			if (isset($options['timerange']['end'])) {
+				$outerQuery->andWhere($outerQuery->expr()->lt('firstoccurence',
+					$outerQuery->createNamedParameter($options['timerange']['end']->getTimeStamp)));
+			}
+		}
+
+		if (isset($options['types'])) {
+			$or = $outerQuery->expr()->orX();
+			foreach($options['types'] as $type) {
+				$or->add($outerQuery->expr()->eq('componenttype',
+					$outerQuery->createNamedParameter($type)));
+			}
+			$outerQuery->andWhere($or);
+		}
+
+		$outerQuery->andWhere($outerQuery->expr()->in('c.id',
+			$outerQuery->createFunction($innerQuery->getSQL())));
+
+		if ($offset) {
+			$outerQuery->setFirstResult($offset);
+		}
+		if ($limit) {
+			$outerQuery->setMaxResults($limit);
+		}
+
+		$result = $outerQuery->execute();
+		$calendarObjects = $result->fetchAll();
+
+		return array_map(function($o) {
+			$calendarData = Reader::read($o['calendardata']);
+			$comps = $calendarData->getComponents();
+			$objects = [];
+			$timezones = [];
+			foreach($comps as $comp) {
+				if ($comp instanceof VTimeZone) {
+					$timezones[] = $comp;
+				} else {
+					$objects[] = $comp;
+				}
+			}
+
+			return [
+				'id' => $o['id'],
+				'type' => $o['componenttype'],
+				'uid' => $o['uid'],
+				'uri' => $o['uri'],
+				'objects' => array_map(function($c) {
+					return $this->transformSearchData($c);
+				}, $objects),
+				'timezones' => array_map(function($c) {
+					return $this->transformSearchData($c);
+				}, $timezones),
+			];
+		}, $calendarObjects);
+	}
+
+	/**
+	 * @param Component $comp
+	 * @return array
+	 */
+	private function transformSearchData(Component $comp) {
+		$data = [];
+		/** @var Component[] $subComponents */
+		$subComponents = $comp->getComponents();
+		/** @var Property[] $properties */
+		$properties = array_filter($comp->children(), function($c) {
+			return $c instanceof Property;
+		});
+		$validationRules = $comp->getValidationRules();
+
+		foreach($subComponents as $subComponent) {
+			$name = $subComponent->name;
+			if (!isset($data[$name])) {
+				$data[$name] = [];
+			}
+			$data[$name][] = $this->transformSearchData($subComponent);
+		}
+
+		foreach($properties as $property) {
+			$name = $property->name;
+			if (!isset($validationRules[$name])) {
+				$validationRules[$name] = '*';
+			}
+
+			$rule = $validationRules[$property->name];
+			if ($rule === '+' || $rule === '*') { // multiple
+				if (!isset($data[$name])) {
+					$data[$name] = [];
+				}
+
+				$data[$name][] = $this->transformSearchProperty($property);
+			} else { // once
+				$data[$name] = $this->transformSearchProperty($property);
+			}
+		}
+
+		return $data;
+	}
+
+	/**
+	 * @param Property $prop
+	 * @return array
+	 */
+	private function transformSearchProperty(Property $prop) {
+		// No need to check Date, as it extends DateTime
+		if ($prop instanceof Property\ICalendar\DateTime) {
+			$value = $prop->getDateTime();
+		} else {
+			$value = $prop->getValue();
+		}
+
+		return [
+			$value,
+			$prop->parameters()
+		];
+	}
+
 	/**
 	 * Searches through all of a users calendars and calendar objects to find
 	 * an object with a specific UID.
@@ -1632,6 +1844,9 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		$supportedProperties = array_keys($this->subscriptionPropertyMap);
 		$supportedProperties[] = '{http://calendarserver.org/ns/}source';
 
+		/**
+		 * @suppress SqlInjectionChecker
+		 */
 		$propPatch->handle($supportedProperties, function($mutations) use ($subscriptionId) {
 
 			$newValues = [];
@@ -1771,7 +1986,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		$query->insert('schedulingobjects')
 			->values([
 				'principaluri' => $query->createNamedParameter($principalUri),
-				'calendardata' => $query->createNamedParameter($objectData),
+				'calendardata' => $query->createNamedParameter($objectData, IQueryBuilder::PARAM_LOB),
 				'uri' => $query->createNamedParameter($objectUri),
 				'lastmodified' => $query->createNamedParameter(time()),
 				'etag' => $query->createNamedParameter(md5($objectData)),
@@ -1937,9 +2152,19 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 	 * @return string|null
 	 */
 	public function setPublishStatus($value, $calendar) {
+
+		$calendarId = $calendar->getResourceId();
+		$this->dispatcher->dispatch('\OCA\DAV\CalDAV\CalDavBackend::publishCalendar', new GenericEvent(
+			'\OCA\DAV\CalDAV\CalDavBackend::updateShares',
+			[
+				'calendarId' => $calendarId,
+				'calendarData' => $this->getCalendarById($calendarId),
+				'public' => $value,
+			]));
+
 		$query = $this->db->getQueryBuilder();
 		if ($value) {
-			$publicUri = $this->random->generate(16, ISecureRandom::CHAR_UPPER.ISecureRandom::CHAR_DIGITS);
+			$publicUri = $this->random->generate(16, ISecureRandom::CHAR_HUMAN_READABLE);
 			$query->insert('dav_shares')
 				->values([
 					'principaluri' => $query->createNamedParameter($calendar->getPrincipalURI()),
@@ -2037,7 +2262,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 					$query->execute();
 				}
 
-				if (in_array($property->name, array_keys(self::$indexParameters))) {
+				if (array_key_exists($property->name, self::$indexParameters)) {
 					$parameters = $property->parameters();
 					$indexedParametersForProperty = self::$indexParameters[$property->name];
 
@@ -2060,6 +2285,22 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		}
 	}
 
+	/**
+	 * deletes all birthday calendars
+	 */
+	public function deleteAllBirthdayCalendars() {
+		$query = $this->db->getQueryBuilder();
+		$result = $query->select(['id'])->from('calendars')
+			->where($query->expr()->eq('uri',
+				$query->createNamedParameter(BirthdayService::BIRTHDAY_CALENDAR_URI)))
+			->execute();
+
+		$ids = $result->fetchAll();
+		foreach($ids as $id) {
+			$this->deleteCalendar($id['id']);
+		}
+	}
+
 	/**
 	 * read VCalendar data into a VCalendar object
 	 *
@@ -2110,7 +2351,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 
 	private function convertPrincipal($principalUri, $toV2) {
 		if ($this->principalBackend->getPrincipalPrefix() === 'principals') {
-			list(, $name) = URLUtil::splitPath($principalUri);
+			list(, $name) = Uri\split($principalUri);
 			if ($toV2 === true) {
 				return "principals/users/$name";
 			}
