@@ -17,10 +17,8 @@ OC.L10N.register(
     "Couldn't establish a federated share." : "No s'ha pogut establir una part federada.",
     "Couldn't establish a federated share, maybe the password was wrong." : "No s'ha pogut establir una acció compartida federada, potser la contrasenya ha estat incorrecta.",
     "Federated Share request sent, you will receive an invitation. Check your notifications." : "S'ha enviat la sol·licitud de participació federada, rebràs una invitació. Comproveu les vostres notificacions.",
-    "Sharing %s failed, because this item is already shared with %s" : "Ha fallat en compartir %s, perquè l'element ja està compartit amb %s",
     "Not allowed to create a federated share with the same user" : "No està permés crear una compartició federada amb el mateix usuari",
     "File is already shared with %s" : "El fitxer ja està compartit amb %s",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "S'ha produït un error en compartir%s, no s'ha pogut trobar%s, potser el servidor no estigui disponible o s'utilitzi un certificat autofirmat.",
     "Could not find share" : "No s'ha pogut trobar la compartició",
     "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Has rebut \"/%3$s\" com una compartició remota des de %1$s (de part de %2$s)",
     "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Has rebut {share} com un recompte remot de {user} (en nom de {nom})",
@@ -40,7 +38,7 @@ OC.L10N.register(
     "Search global and public address book for users" : "Cerca llibreta d'adreces global i pública per als usuaris",
     "Allow users to publish their data to a global and public address book" : "Permetre als usuaris publicar les seves dades en una llibreta d'adreces global i pública",
     "Federated Cloud" : "Núvol federat",
-    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Podeu compartir amb qualsevol persona que usi Nextcloud, ownCloud vs Pydio! Acaba de posar el seu identificador de núvol federat al diàleg d'accions. Sembla person@cloud.example.com",
+    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Podeu compartir amb qualsevol persona que usi Nextcloud, ownCloud o Pydio! Només s'ha de posar el seu identificador de núvol federat a la finestra de compartir. És semblant a algu@cloud.web.cat",
     "Your Federated Cloud ID:" : "El teu ID de Núvol Federat:",
     "Share it so your friends can share files with you:" : "Compartiu-lo perquè els vostres amics puguin compartir fitxers amb vosaltres:",
     "Add to your website" : "Afegeix a la teva pàgina web",
@@ -50,9 +48,11 @@ OC.L10N.register(
     "Not allowed to create a federated share with the owner." : "No es permet crear una compartida federada amb el propietari.",
     "Invalid or untrusted SSL certificate" : "El certificat SSL és invàlid o no és fiable",
     "Could not authenticate to remote share, password might be wrong" : "No s'ha pogut autenticar per compartir de manera remota, la contrasenya podria estar equivocada",
-    "Storage not valid" : "Emmagatzemament no vàlid",
+    "Storage not valid" : "Emmagatzematge no vàlid",
     "Federated share added" : "S'ha afegit una part federada",
     "Couldn't add remote share" : "No s'ha pogut afegir una compartició remota",
+    "Sharing %s failed, because this item is already shared with %s" : "Ha fallat en compartir %s, perquè l'element ja està compartit amb %s",
+    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "S'ha produït un error en compartir%s, no s'ha pogut trobar%s, potser el servidor no estigui disponible o s'utilitzi un certificat autofirmat.",
     "Search global and public address book for users and let local users publish their data" : "Busqueu llibreta d'adreces global i pública per als usuaris i deixeu que els usuaris locals publiquin les seves dades"
 },
 "nplurals=2; plural=(n != 1);");
