@@ -14,13 +14,16 @@ OC.L10N.register(
     "Home" : "Главная",
     "Close" : "Закрыть",
     "Could not create folder \"{dir}\"" : "Невозможно создать каталог «{dir}»",
+    "This will stop your current uploads." : "Это действие остановит активные сеансы передачи файлов на сервер. ",
     "Upload cancelled." : "Выгрузка отменена.",
+    "…" : "…",
+    "Processing files …" : "Обработка файлов…",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Невозможно загрузить «{filename}», так как это либо каталог, либо файл нулевого размера",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Недостаточно свободного места, вы загружаете {size1}, но только {size2} доступно",
     "Target folder \"{dir}\" does not exist any more" : "Целевой каталог «{dir}» более не существует",
     "Not enough free space" : "Недостаточно свободного места",
+    "An unknown error has occurred" : "Произошла неизвестная ошибка",
     "Uploading …" : "Загрузка…",
-    "…" : "…",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} из {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Загрузка этого элемента не поддерживается",
     "Target folder does not exist any more" : "Каталог больше не существует",
@@ -28,7 +31,7 @@ OC.L10N.register(
     "Actions" : "Действия",
     "Rename" : "Переименовать",
     "Copy" : "Копировать",
-    "Target folder" : "Целевой каталог",
+    "Choose target folder" : "Выберите каталога назначения",
     "Disconnect storage" : "Отсоединить хранилище",
     "Unshare" : "Закрыть доступ",
     "Could not load info for file \"{file}\"" : "Не удаётся загрузить информацию для файла \"{file}\"",
@@ -127,18 +130,20 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "Файл или каталог был <strong>восстановлен</strong>",
     "Unlimited" : "Неограничено",
     "Upload (max. %s)" : "Загрузка (максимум %s)",
+    "File Management" : "Управление файлами",
     "File handling" : "Управление файлами",
     "Maximum upload size" : "Максимальный размер загружаемого файла",
     "max. possible: " : "макс. возможно: ",
     "Save" : "Сохранить",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "В режиме PHP-FPM применение изменений может занять до 5 минут.",
     "Missing permissions to edit from here." : "Отсутствуют права на внесение здесь изменений.",
-    "%s of %s used" : "использовано %s из %s",
+    "%1$s of %2$s used" : "использовано %1$s из %2$s ",
     "%s used" : "%s использовано",
     "Settings" : "Настройки",
     "Show hidden files" : "Показывать скрытые файлы",
     "WebDAV" : "WebDAV",
     "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Используйте этот адрес для <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">доступа к вашим файлам через WebDAV</a>",
+    "Toggle grid view" : "Включить или отключить режим просмотра сеткой",
     "Cancel upload" : "Отменить загрузку",
     "No files in here" : "Здесь нет файлов",
     "Upload some content or sync with your devices!" : "Загрузите что-нибудь или синхронизируйте со своими устройствами!",
@@ -158,8 +163,10 @@ OC.L10N.register(
     "Text file" : "Текстовый файл",
     "New text file.txt" : "Новый текстовый файл.txt",
     "Move" : "Переместить",
+    "Target folder" : "Целевой каталог",
     "A new file or folder has been <strong>deleted</strong>" : "Новый файл или каталог был <strong>удален</strong>",
     "A new file or folder has been <strong>restored</strong>" : "Новый файл или каталог был <strong>восстановлен</strong>",
+    "%s of %s used" : "использовано %s из %s",
     "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Используйте этот адрес <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">для доступа по WebDAV</a>"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
