@@ -6,22 +6,27 @@ OC.L10N.register(
     "Unknown error" : "Neznana napaka",
     "All files" : "Vse datoteke",
     "Recent" : "Nedavno",
+    "Favorites" : "Priljubljene",
     "File could not be found" : "Datoteke ne najdem",
+    "Move or copy" : "Premakni ali kopiraj",
+    "Download" : "Prejmi",
+    "Delete" : "Izbriši",
     "Home" : "Domači naslov",
     "Close" : "Zapri",
-    "Favorites" : "Priljubljene",
     "Could not create folder \"{dir}\"" : "Ni mogoče ustvariti mape \"{dir}\"",
     "Upload cancelled." : "Pošiljanje je preklicano.",
+    "…" : "...",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ni mogoče poslati datoteke {filename}, saj je to ali mapa ali pa je velikost datoteke 0 bajtov.",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Na voljo ni dovolj prostora. Velikost poslane datoteke je {size1}, na voljo pa je je {size2}.",
     "Target folder \"{dir}\" does not exist any more" : "Ciljna mapa \"{dir}\" ne obstaja več",
     "Not enough free space" : "Ni dovolj prostora",
+    "Uploading …" : "Poteka pošiljanje ...",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} od {totalSize} ({bitrate})",
+    "Target folder does not exist any more" : "Ciljna mapa ne obstaja več",
+    "Error when assembling chunks, status code {status}" : "Napaka pri sestavljanju kosov, statusna koda {status}",
     "Actions" : "Dejanja",
-    "Download" : "Prejmi",
     "Rename" : "Preimenuj",
-    "Target folder" : "Ciljna mapa",
-    "Delete" : "Izbriši",
+    "Copy" : "Kopiraj",
     "Disconnect storage" : "Odklopi shrambo",
     "Unshare" : "Prekini souporabo",
     "Could not load info for file \"{file}\"" : "Ni bilo mogoče naložiti podatke za datoteko \"{file}\"",
@@ -34,6 +39,10 @@ OC.L10N.register(
     "This directory is unavailable, please check the logs or contact the administrator" : "Mapa ni na voljo. Preverite dnevnik in stopite v stik s skrbnikom sistema.",
     "Could not move \"{file}\", target exists" : "Datoteke \"{file}\" ni mogoče premakniti, ker cilj že obstaja",
     "Could not move \"{file}\"" : "Ni mogoče premakniti \"{file}\"",
+    "Could not copy \"{file}\", target exists" : "Datoteke »{file}« ni mogoče kopirati, ker ta že obstaja",
+    "Could not copy \"{file}\"" : "Datoteke »{file}« ni mogoče kopirati.",
+    "Copied {origin} inside {destination}" : "Kopirano {origin} v {destination}",
+    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopirano {origin} in {nbfiles} ostale datoteke v {destination}",
     "{newName} already exists" : "{newName} že obstaja",
     "Could not rename \"{fileName}\", it does not exist any more" : "Ni mogoče preimenovati \"{fileName}\", ker datoteka ne obstaja več",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime \"{targetName}\" je že v uporabi v mapi \"{dir}\". Izberite drugo ime ali drugo mapo.",
@@ -53,6 +62,8 @@ OC.L10N.register(
     "You don’t have permission to upload or create files here" : "Ni ustreznih dovoljenj za pošiljanje ali ustvarjanje datotek na tem mestu.",
     "_Uploading %n file_::_Uploading %n files_" : ["Posodabljanje %n datoteke","Posodabljanje %n datotek","Posodabljanje %n datotek","Posodabljanje %n datotek"],
     "New" : "Novo",
+    "{used} of {quota} used" : "{used} od {quota} uporabljeno",
+    "{used} used" : "{used} uporabljeno",
     "\"{name}\" is an invalid file name." : "\"{name}\" je neveljavno ime datoteke.",
     "File name cannot be empty." : "Ime datoteke ne sme biti prazno polje.",
     "\"{name}\" is not an allowed filetype" : "\"{name}\" ni dovoljena vrsta datoteke",
@@ -63,17 +74,20 @@ OC.L10N.register(
     "_matches '{filter}'_::_match '{filter}'_" : ["se sklada s filtrom '{filter}'","se skladata s filtrom '{filter}'","se skladajo s filtrom '{filter}'","se skladajo s filtrom '{filter}'"],
     "View in folder" : "Prikaži v mapi",
     "Copied!" : "Kopirano!",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiraj direktno povezavo (deluje sa mo za uporabnike, ki imajo dostop do datoteke ali mape)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiraj neposredno povezavo (za uporabnike, ki imajo dostop do datoteke ali mape)",
     "Path" : "Pot",
     "_%n byte_::_%n bytes_" : ["%n bajt","%n bajta","%n bajti","%n bajtov"],
     "Favorited" : "Označeno kot priljubljeno",
     "Favorite" : "Priljubljene",
     "New folder" : "Nova mapa",
     "Upload file" : "Naloži datoteko",
+    "Not favorited" : "Ni priljubljeno",
+    "Remove from favorites" : "Odstrani iz priljubljenih",
+    "Add to favorites" : "Dodaj med priljubljene",
     "An error occurred while trying to update the tags" : "Prišlo je do napake med posodabljanjem oznak",
     "Added to favorites" : "Dodano med priljubljene",
     "Removed from favorites" : "Odstranjeno iz priljubljenih",
-    "You added {file} to your favorites" : "Dodali ste {file} med priljubljene",
+    "You added {file} to your favorites" : "Med priljubljene je dodana je datoteka {file}",
     "You removed {file} from your favorites" : "Odstranili ste {file} od priljubljenih",
     "File changes" : "Sprememba datoteke",
     "Created by {user}" : "Ustvarjeno od {user}",
@@ -84,9 +98,12 @@ OC.L10N.register(
     "Moved by {user}" : "Premaknjeno od {user}",
     "\"remote user\"" : "\"oddaljeni uporabnik\"",
     "You created {file}" : "Ustvaril(a) si {file}",
+    "You created an encrypted file in {file}" : "Ustvarjena je šifrirana datoteka v {file}",
     "{user} created {file}" : "{user} ustvaril(a) {file}",
+    "{user} created an encrypted file in {file}" : "{user} ustvaril(a) kodirano datoteko {file}",
     "{file} was created in a public folder" : "{file} ustvarjena je bila v javni mapi",
     "You changed {file}" : "Spremenil(a) si {file}",
+    "You changed an encrypted file in {file}" : "Spremenil(a) si kodirano datoteko v {file}",
     "{user} changed {file}" : "{user} spremenil/a {file}",
     "You deleted {file}" : "Izbrisal(a) si {file}",
     "{user} deleted {file}" : "{user} izbrisal(a) {file}",
@@ -96,10 +113,10 @@ OC.L10N.register(
     "{user} renamed {oldfile} to {newfile}" : "{user} preimenoval(a) {oldfile} v {newfile}",
     "You moved {oldfile} to {newfile}" : "Premaknil(a) si {oldfile} v {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} premaknil(a) {oldfile} v {newfile}",
-    "A file has been added to or removed from your <strong>favorites</strong>" : "Datoteka je bila dodana ali umaknjena iz tvojih <strong>priljubljenih</strong>",
+    "A file has been added to or removed from your <strong>favorites</strong>" : "Datoteka je bila ali dodana ali umaknjena iz <strong>priljubljenih</strong>",
     "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Datoteka ali mapa je bila <strong>spremenjena</strong> ali <strong>preimenovana</strong>",
     "A new file or folder has been <strong>created</strong>" : "Nova datoteka ali mapa je <strong>ustvarjena</strong>",
-    "A file or folder has been <strong>deleted</strong>" : "Datoteka ali mapa je bila <strong>pobrisana</strong>",
+    "A file or folder has been <strong>deleted</strong>" : "Datoteka ali mapa je bila <strong>izbrisana</strong>",
     "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Omeji obvestila o ustvarjanju in spreminjanju <strong>najpogosteje uporabljenih </strong> datotek <em>(omogoči pretok)</em>",
     "A file or folder has been <strong>restored</strong>" : "A file or folder has been <strong>restored</strong>",
     "Unlimited" : "Neomejeno",
@@ -110,12 +127,12 @@ OC.L10N.register(
     "Save" : "Shrani",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Uveljavljanje sprememb prek PHP-FPM lahko traja tudi 5  minut.",
     "Missing permissions to edit from here." : "Ni ustreznih dovoljenj za urejanje na tej ravni.",
-    "%s of %s used" : "%s od %s uporabljeno",
     "%s used" : "%s uporabljeno",
     "Settings" : "Nastavitve",
     "Show hidden files" : "Pokaži skrite datoteke",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Uporabite naslov <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\"> za dostop do datotek prek sistema WebDAV</a>.",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Naslov omogoča dostop do datotek prek <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">WebDAV</a>.",
+    "Cancel upload" : "Prekliči pošiljanje",
     "No files in here" : "V mapi ni datotek",
     "Upload some content or sync with your devices!" : "Uvozite vsebino ali pa omogočite usklajevanje z napravami!",
     "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
@@ -124,30 +141,20 @@ OC.L10N.register(
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke, ki jih želite poslati, presegajo največjo dovoljeno velikost na strežniku.",
     "No favorites yet" : "Še ni priljubljena",
     "Files and folders you mark as favorite will show up here" : "Datoteke ali mape, ki so označene kot priljubljene, bodo zbrane na tem mestu.",
-    "Shared with you" : "V skupni rabi z vami",
-    "Shared with others" : "V skupni rabi z ostalimi",
-    "Shared by link" : "Deljeno s povezavo",
     "Tags" : "Oznake",
     "Deleted files" : "Izbrisane datoteke",
+    "Shares" : "Souporaba",
+    "Shared with others" : "V skupni rabi z ostalimi",
+    "Shared with you" : "V skupni rabi z vami",
+    "Shared by link" : "Deljeno s povezavo",
+    "Deleted shares" : "Izbrisane povezave za souporabo",
     "Text file" : "Besedilna datoteka",
     "New text file.txt" : "Nova datoteka.txt",
-    "Uploading..." : "Poteka pošiljanje ...",
-    "..." : "...",
-    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["{hours}:{minutes}:{seconds} ura še","{hours}:{minutes}:{seconds} uri še","{hours}:{minutes}:{seconds} ure še","{hours}:{minutes}:{seconds} ur še"],
-    "{hours}:{minutes}h" : "{hours}:{minutes}h",
-    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["{minutes}:{seconds} minuta še","{minutes}:{seconds} minuti še","{minutes}:{seconds} minute še","{minutes}:{seconds} minut še"],
-    "{minutes}:{seconds}m" : "{minutes}:{seconds}min",
-    "_{seconds} second left_::_{seconds} seconds left_" : ["{seconds} sekund še","{seconds} sekundi še","{seconds} sekunde še","{seconds} sekund še"],
-    "{seconds}s" : "{seconds}s",
-    "Any moment now..." : "Vsak trenutek ...",
-    "Soon..." : "Kmalu",
-    "File upload is in progress. Leaving the page now will cancel the upload." : "V teku je pošiljanje datoteke. Če zapustite to stran zdaj, bo pošiljanje preklicano.",
     "Move" : "Premakni",
-    "Copy local link" : "Kopiraj lokalno povezavo",
-    "Folder" : "Mapa",
-    "Upload" : "Pošlji",
-    "A new file or folder has been <strong>deleted</strong>" : "Nova datoteka ali mapa je bila <strong>pobrisana</strong>",
+    "Target folder" : "Ciljna mapa",
+    "A new file or folder has been <strong>deleted</strong>" : "Nova datoteka ali mapa je bila <strong>izbrisana</strong>",
     "A new file or folder has been <strong>restored</strong>" : "Nova datoteka ali mapa je bila <strong>obnovljena</strong>",
-    "No favorites" : "Ni priljubljenih predmetov"
+    "%s of %s used" : "%s od %s uporabljeno",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Naslov omogoča dostop do datotek prek<a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">WebDAV</a>."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
