@@ -1,25 +1,29 @@
 OC.L10N.register(
     "files_external",
     {
-    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Fetching request tokens failed. Verify that your app key and secret are correct.",
-    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Fetching access tokens failed. Verify that your app key and secret are correct.",
-    "Please provide a valid app key and secret." : "Please provide a valid app key and secret.",
-    "Step 1 failed. Exception: %s" : "Step 1 failed. Exception: %s",
-    "Step 2 failed. Exception: %s" : "Step 2 failed. Exception: %s",
     "External storages" : "External storages",
-    "Dropbox App Configuration" : "Dropbox App Configuration",
-    "Google Drive App Configuration" : "Google Drive App Configuration",
     "Personal" : "Personal",
     "System" : "System",
     "Grant access" : "Grant access",
     "Error configuring OAuth1" : "Error configuring OAuth1",
+    "Please provide a valid app key and secret." : "Please provide a valid app key and secret.",
     "Error configuring OAuth2" : "Error configuring OAuth2",
     "Generate keys" : "Generate keys",
     "Error generating key pair" : "Error generating key pair",
     "All users. Type to select user or group." : "All users. Type to select user or group.",
     "(group)" : "(group)",
     "Compatibility with Mac NFD encoding (slow)" : "Compatibility with Mac NFD encoding (slow)",
+    "Enable encryption" : "Enable encryption",
+    "Enable previews" : "Enable previews",
+    "Enable sharing" : "Enable sharing",
+    "Check for changes" : "Check for changes",
+    "Never" : "Never",
+    "Once every direct access" : "Once every direct access",
+    "Read only" : "Read only",
+    "Delete" : "Delete",
     "Admin defined" : "Admin defined",
+    "Are you sure you want to delete this external storage?" : "Are you sure you want to delete this external storage?",
+    "Delete storage?" : "Delete storage?",
     "Saved" : "Saved",
     "Saving..." : "Saving...",
     "Save" : "Save",
@@ -60,9 +64,11 @@ OC.L10N.register(
     "OAuth2" : "OAuth2",
     "Client ID" : "Client ID",
     "Client secret" : "Client secret",
-    "OpenStack" : "OpenStack",
+    "OpenStack v2" : "OpenStack v2",
     "Tenant name" : "Tenant name",
     "Identity endpoint URL" : "Identity endpoint URL",
+    "OpenStack v3" : "OpenStack v3",
+    "Domain" : "Domain",
     "Rackspace" : "Rackspace",
     "API key" : "API key",
     "Global credentials" : "Global credentials",
@@ -72,6 +78,9 @@ OC.L10N.register(
     "User entered, store in database" : "User entered, store in database",
     "RSA public key" : "RSA public key",
     "Public key" : "Public key",
+    "RSA private key" : "RSA private key",
+    "Private key" : "Private key",
+    "Kerberos ticket" : "Kerberos ticket",
     "Amazon S3" : "Amazon S3",
     "Bucket" : "Bucket",
     "Hostname" : "Hostname",
@@ -79,15 +88,14 @@ OC.L10N.register(
     "Region" : "Region",
     "Enable SSL" : "Enable SSL",
     "Enable Path Style" : "Enable Path Style",
+    "Legacy (v2) authentication" : "Legacy (v2) authentication",
     "WebDAV" : "WebDAV",
     "URL" : "URL",
     "Remote subfolder" : "Remote subfolder",
     "Secure https://" : "Secure https://",
-    "Dropbox" : "Dropbox",
     "FTP" : "FTP",
     "Host" : "Host",
     "Secure ftps://" : "Secure ftps://",
-    "Google Drive" : "Google Drive",
     "Local" : "Local",
     "Location" : "Location",
     "Nextcloud" : "Nextcloud",
@@ -96,7 +104,6 @@ OC.L10N.register(
     "SFTP with secret key login" : "SFTP with secret key login",
     "SMB / CIFS" : "SMB / CIFS",
     "Share" : "Share",
-    "Domain" : "Domain",
     "SMB / CIFS using OC login" : "SMB / CIFS using OC login",
     "Username as share" : "Username as share",
     "OpenStack Object Storage" : "OpenStack Object Storage",
@@ -104,30 +111,33 @@ OC.L10N.register(
     "Request timeout (seconds)" : "Request timeout (seconds)",
     "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it.",
     "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it.",
-    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it.",
     "External storage support" : "External storage support",
-    "No external storage configured" : "No external storage configured",
-    "You can add external storages in the personal settings" : "You can add external storages in the personal settings",
+    "No external storage configured or you don't have the permission to configure them" : "No external storage configured or you don't have the permission to configure them",
     "Name" : "Name",
     "Storage type" : "Storage type",
     "Scope" : "Scope",
-    "Enable encryption" : "Enable encryption",
-    "Enable previews" : "Enable previews",
-    "Enable sharing" : "Enable sharing",
-    "Check for changes" : "Check for changes",
-    "Never" : "Never",
-    "Once every direct access" : "Once every direct access",
     "Folder name" : "Folder name",
     "External storage" : "External storage",
     "Authentication" : "Authentication",
     "Configuration" : "Configuration",
     "Available for" : "Available for",
+    "Click to recheck the configuration" : "Click to recheck the configuration",
     "Add storage" : "Add storage",
     "Advanced settings" : "Advanced settings",
-    "Delete" : "Delete",
     "Allow users to mount external storage" : "Allow users to mount external storage",
+    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Fetching request tokens failed. Verify that your app key and secret are correct.",
+    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Fetching access tokens failed. Verify that your app key and secret are correct.",
+    "Step 1 failed. Exception: %s" : "Step 1 failed. Exception: %s",
+    "Step 2 failed. Exception: %s" : "Step 2 failed. Exception: %s",
+    "Dropbox App Configuration" : "Dropbox App Configuration",
+    "Google Drive App Configuration" : "Google Drive App Configuration",
+    "OpenStack" : "OpenStack",
+    "Dropbox" : "Dropbox",
+    "Google Drive" : "Google Drive",
+    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it.",
+    "No external storage configured" : "No external storage configured",
+    "You can add external storages in the personal settings" : "You can add external storages in the personal settings",
     "Allow users to mount the following external storage" : "Allow users to mount the following external storage",
-    "Storage with id \"%i\" not found" : "Storage with id \"%i\" not found",
-    "Storage with id \"%i\" is not user editable" : "Storage with id \"%i\" is not user editable"
+    "Are you sure you want to delete this external storage" : "Are you sure you want to delete this external storage"
 },
 "nplurals=2; plural=(n != 1);");
