@@ -5,23 +5,32 @@ OC.L10N.register(
     "Personal" : "個人",
     "System" : "システム",
     "Grant access" : "アクセスを許可",
-    "Error configuring OAuth1" : "OAuth1 設定エラー",
+    "Error configuring OAuth1" : "OAuth1設定エラー",
     "Please provide a valid app key and secret." : "有効なアプリのキーとパスワードを入力してください。",
-    "Error configuring OAuth2" : "OAuth2 設定エラー",
+    "Error configuring OAuth2" : "OAuth2設定エラー",
     "Generate keys" : "キーを生成",
     "Error generating key pair" : "キーペアの生成エラー",
     "All users. Type to select user or group." : "すべてのユーザー。ユーザー、グループを追加",
     "(group)" : "(グループ)",
     "Compatibility with Mac NFD encoding (slow)" : "Mac NFD エンコード互換 (遅い)",
+    "Enable encryption" : "暗号化を有効に",
+    "Enable previews" : "プレビューを有効に",
+    "Enable sharing" : "共有の有効化",
+    "Check for changes" : "変更点を確認",
+    "Never" : "更新無",
+    "Once every direct access" : "直指定時のみ",
+    "Read only" : "読み取り専用",
+    "Delete" : "削除",
     "Admin defined" : "管理者設定済",
+    "Are you sure you want to delete this external storage?" : "この外部ストレージを本当に削除しますか?",
     "Delete storage?" : "ストレージを削除しますか?",
-    "Saved" : "保存されました",
+    "Saved" : "保存しました",
     "Saving..." : "保存中...",
     "Save" : "保存",
     "Empty response from the server" : "サーバーから空の応答がありました",
     "Couldn't access. Please log out and in again to activate this mount point" : "アクセスできません。ログアウトして、再度このマウントポイントをアクティベートしてください。",
     "Couldn't get the information from the remote server: {code} {type}" : "リモートサーバーから情報を取得できませんでした：{code} {type}",
-    "Couldn't get the list of external mount points: {type}" : "外部マウントポイントのリストを取得出来ませんでした。: {type}",
+    "Couldn't get the list of external mount points: {type}" : "外部マウントポイントのリストを取得できませんでした。: {type}",
     "There was an error with message: " : "メッセージ付きのエラーが発生しました：",
     "External mount error" : "外部マウントエラー",
     "external-storage" : "外部ストレージ",
@@ -55,8 +64,10 @@ OC.L10N.register(
     "OAuth2" : "OAuth2",
     "Client ID" : "クライアントID",
     "Client secret" : "クライアント秘密キー",
+    "OpenStack v2" : "OpenStack v2",
     "Tenant name" : "テナント名",
     "Identity endpoint URL" : "認証エンドポイントURL",
+    "OpenStack v3" : "OpenStack v3",
     "Domain" : "ドメイン",
     "Rackspace" : "Rackspace",
     "API key" : "APIキー",
@@ -67,6 +78,9 @@ OC.L10N.register(
     "User entered, store in database" : "入力されたユーザーデータは、データベースに保管します",
     "RSA public key" : "RSA公開鍵",
     "Public key" : "公開鍵",
+    "RSA private key" : "RSA秘密鍵",
+    "Private key" : "秘密鍵",
+    "Kerberos ticket" : "ケルベロスチケット",
     "Amazon S3" : "Amazon S3",
     "Bucket" : "バケット名",
     "Hostname" : "ホスト名",
@@ -97,27 +111,23 @@ OC.L10N.register(
     "Request timeout (seconds)" : "リクエストがタイムアウトするまでの秒数",
     "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "PHPでのcURLのサポートが有効になっていないか、インストールされていません。 %s のマウントは不可能です。システム管理者にインストールを依頼してください。",
     "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "PHPのFTPサポートが有効になっていないか、インストールされていません。%s のマウントは不可能です。システム管理者にインストールを依頼してください。",
-    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\"はインストールされていません。 %s のマウントは不可能です。システム管理者にインストールを依頼してください。",
     "External storage support" : "外部ストレージのサポート",
+    "Adds basic external storage support" : "基本的な外部ストレージのサポートを追加",
+    "No external storage configured or you don't have the permission to configure them" : "外部ストレージが設定されていないか、外部ストレージを設定する権限がありません",
     "Name" : "名前",
     "Storage type" : "ストレージ種別",
     "Scope" : "スコープ",
-    "Enable encryption" : "暗号化を有効に",
-    "Enable previews" : "プレビューを有効に",
-    "Enable sharing" : "共有の有効化",
-    "Check for changes" : "変更点を確認",
-    "Never" : "更新無",
-    "Once every direct access" : "直指定時のみ",
+    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow users to mount their own external storage services." : "外部ストレージを使用すると、外部ストレージサービスおよびデバイスをセカンダリのNextcloudストレージデバイスとしてマウントできます。 また、ユーザーが独自の外部ストレージサービスをマウントできるようにすることもできます。",
     "Folder name" : "フォルダー名",
     "External storage" : "外部ストレージ",
     "Authentication" : "認証",
     "Configuration" : "設定",
     "Available for" : "利用可能",
+    "Click to recheck the configuration" : "クリックすると設定が再確認されます",
     "Add storage" : "ストレージを追加",
     "Advanced settings" : "詳細設定",
-    "Delete" : "削除",
     "Allow users to mount external storage" : "ユーザーに外部ストレージの接続を許可する",
-    "Allow users to mount the following external storage" : "ユーザーに以下の外部ストレージのマウントを許可する",
+    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "グローバル資格情報を使用して、同じ資格情報を持つ複数の外部記憶装置で認証することができます。",
     "Fetching request tokens failed. Verify that your app key and secret are correct." : "リクエストトークンの取得に失敗しました。アプリのキーとパスワードが正しいことを確認してください。",
     "Fetching access tokens failed. Verify that your app key and secret are correct." : "アクセストークンの取得に失敗しました。アプリのキーとパスワードが正しいことを確認してください。",
     "Step 1 failed. Exception: %s" : "ステップ 1 の実行に失敗しました。例外: %s",
@@ -127,8 +137,10 @@ OC.L10N.register(
     "OpenStack" : "OpenStack",
     "Dropbox" : "Dropbox",
     "Google Drive" : "Google Drive",
+    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\"はインストールされていません。 %s のマウントは不可能です。システム管理者にインストールを依頼してください。",
     "No external storage configured" : "外部ストレージは設定されていません",
     "You can add external storages in the personal settings" : "個人設定で外部ストレージを設定することができます。",
+    "Allow users to mount the following external storage" : "ユーザーに次の外部ストレージのマウントを許可する",
     "Are you sure you want to delete this external storage" : "この外部ストレージを本当に削除しますか?"
 },
 "nplurals=1; plural=0;");
