@@ -13,7 +13,16 @@ OC.L10N.register(
     "All users. Type to select user or group." : "Všetci používatelia. Začnite písať pre výber používateľa alebo skupinu.",
     "(group)" : "(skupina)",
     "Compatibility with Mac NFD encoding (slow)" : "Kompatibilita s Mac NFD enkódovaním (pomalé)",
+    "Enable encryption" : "Povoliť šifrovanie",
+    "Enable previews" : "Povoliť náhľady",
+    "Enable sharing" : "Povoliť sprístupňovanie",
+    "Check for changes" : "Zisťovať zmeny",
+    "Never" : "Nikdy",
+    "Once every direct access" : "S každým priamym prístupom",
+    "Read only" : "Len na čítanie",
+    "Delete" : "Zmazať",
     "Admin defined" : "Nastavené správcom",
+    "Are you sure you want to delete this external storage?" : "Naozaj chcete zmazať toto externé úložisko?",
     "Delete storage?" : "Zmazať externé úložisko?",
     "Saved" : "Uložené",
     "Saving..." : "Ukladá sa...",
@@ -69,6 +78,8 @@ OC.L10N.register(
     "User entered, store in database" : "Používateľ zadaný, uložiť v databáze",
     "RSA public key" : "RSA verejný kľúč",
     "Public key" : "Verejný kľúč",
+    "RSA private key" : "RSA súkromný kľúč",
+    "Private key" : "Súkromný kľúč",
     "Amazon S3" : "Amazon S3",
     "Bucket" : "Sektor",
     "Hostname" : "Hostname",
@@ -76,6 +87,7 @@ OC.L10N.register(
     "Region" : "Región",
     "Enable SSL" : "Povoliť SSL",
     "Enable Path Style" : "Povoliť štýl cesty",
+    "Legacy (v2) authentication" : "Staršie (v2) overovanie",
     "WebDAV" : "WebDAV",
     "URL" : "URL",
     "Remote subfolder" : "Vzdialený podpriečinok",
@@ -98,34 +110,34 @@ OC.L10N.register(
     "Request timeout (seconds)" : "Timeout požiadavky (s)",
     "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Nie je povolená alebo nainštalovaná cURL podpora v PHP. Pripojenie %s nie je možné. Požiadajte svojho správcu, aby doplnil podporu.",
     "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Nie je povolená alebo nainštalovaná FTP podpora v PHP. Pripojenie %s nie je možné. Požiadajte svojho správcu, aby doplnil podporu.",
-    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Nie je nainštalované \"%s\". Pripojenie %s nie je možné. Požiadajte svojho správcu o inštaláciu.",
+    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "Nie je nainštalované \"%1$s\". Pripojenie %2$s nie je možné. Požiadajte svojho správcu o inštaláciu.",
     "External storage support" : "Podpora externého úložiska",
+    "Adds basic external storage support" : "Pridáva základnú podporu externého úložiska",
+    "No external storage configured or you don't have the permission to configure them" : "Žiadne externé úložisko nie je nakonfigurované alebo nemáte práva ich konfigurovať",
     "Name" : "Názov",
     "Storage type" : "Typ úložiska",
     "Scope" : "Rozsah",
-    "Enable encryption" : "Povoliť šifrovanie",
-    "Enable previews" : "Povoliť náhľady",
-    "Enable sharing" : "Povoliť sprístupňovanie",
-    "Check for changes" : "Zisťovať zmeny",
-    "Never" : "Nikdy",
-    "Once every direct access" : "S každým priamym prístupom",
     "Folder name" : "Názov priečinka",
     "External storage" : "Externé úložisko",
     "Authentication" : "Autentifikácia",
     "Configuration" : "Nastavenia",
     "Available for" : "K dispozícii pre",
+    "Click to recheck the configuration" : "Kliknite na opätovnú kontrolu konfigurácie",
     "Add storage" : "Pridať úložisko",
     "Advanced settings" : "Rozšírené nastavenia",
-    "Delete" : "Zmazať",
     "Allow users to mount external storage" : "Povoliť používateľom pripojiť externé úložiská",
-    "Allow users to mount the following external storage" : "Povoliť používateľom pripojiť tieto externé úložiská",
+    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Sťahovanie prístupových tokenov zlyhalo. Overte prosím, či je aplikačný kľúč a heslo (secret) zadané správne.",
     "Step 1 failed. Exception: %s" : "Krok 1 zlyhal. Výnimka: %s",
     "Step 2 failed. Exception: %s" : "Krok 2 zlyhal. Výnimka: %s",
+    "Dropbox App Configuration" : "Nastavenie Dropbox aplikácie",
+    "Google Drive App Configuration" : "Nastavenie Google Drive aplikácie",
     "OpenStack" : "OpenStack",
     "Dropbox" : "Dropbox",
     "Google Drive" : "Google Drive",
+    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Nie je nainštalované \"%s\". Pripojenie %s nie je možné. Požiadajte svojho správcu o inštaláciu.",
     "No external storage configured" : "Žiadne externé úložisko nie je nakonfigurované",
     "You can add external storages in the personal settings" : "Externé úložisko je možné pridať v osobných nastaveniach",
+    "Allow users to mount the following external storage" : "Povoliť používateľom pripojiť tieto externé úložiská",
     "Are you sure you want to delete this external storage" : "Naozaj chcete zmazať toto externé úložisko?"
 },
-"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
+"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
