@@ -35,7 +35,6 @@ OC.L10N.register(
     "Turned on maintenance mode" : "Kveikt á viðhaldsham",
     "Turned off maintenance mode" : "Slökkt á viðhaldsham",
     "Maintenance mode is kept active" : "Viðhaldsham er haldið virkum",
-    "Waiting for cron to finish (checks again in 5 seconds) …" : "Bíð þess að cron ljúki vinnslu (athugaðu aftur eftir 5 sekúndur) …",
     "Updating database schema" : "Uppfæri gagnagrunnsskema",
     "Updated database" : "Uppfærði gagnagrunn",
     "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Athuga hvort hægt sé að uppfæra gagnagrunnsskema (þetta getur tekið langan tíma ef gagnagrunnurinn er mjög stór)",
@@ -46,7 +45,7 @@ OC.L10N.register(
     "Checked for update of app \"%s\" in appstore" : "Athugaði með uppfærslur á \"%s\"-forriti í hugbúnaðarsafni",
     "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Athuga hvort hægt sé að uppfæra gagnagrunnsskema fyrir %s (þetta getur tekið langan tíma ef gagnagrunnurinn er mjög stór)",
     "Checked database schema update for apps" : "Athugaði uppfærslu á gagnagrunnsskema fyrir öpp",
-    "Updated \"%s\" to %s" : "Uppfærði \"%s\" í %s",
+    "Updated \"%1$s\" to %2$s" : "Uppfærði \"%1$s\" í %2$s",
     "Set log level to debug" : "Setja annálsstig á aflúsun",
     "Reset log level" : "Frumstilla annálsstig",
     "Starting code integrity check" : "Ræsi athugun á áreiðanleika kóða",
@@ -54,13 +53,12 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (ósamhæft)",
     "Following apps have been disabled: %s" : "Eftirfarandi forrit hafa verið gerð óvirk: %s",
     "Already up to date" : "Allt uppfært nú þegar",
+    "Could not load your contacts" : "Gat ekki hlaðið inn tengiliðalistanum þínum",
     "Search contacts …" : "Leita í tengiliðum ",
     "No contacts found" : "Engir tengiliðir fundust",
     "Show all contacts …" : "Birta alla tengiliði ...",
-    "Could not load your contacts" : "Gat ekki hlaðið inn tengiliðalistanum þínum",
     "Loading your contacts …" : "Hleð inn tengiliðalistum ...",
     "Looking for {term} …" : "Leita að {term} …",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Það komu upp vandamál með athugun á áreiðanleika kóða. Nánari upplýsingar…</a>",
     "No action available" : "Engin aðgerð tiltæk",
     "Error fetching contact actions" : "Villa við að sækja aðgerðir tengiliða",
     "Settings" : "Stillingar",
@@ -84,6 +82,7 @@ OC.L10N.register(
     "No" : "Nei",
     "Yes" : "Já",
     "No files in here" : "Engar skrár hér",
+    "No more subfolders in here" : "Engar fleiri undirmöppur hér",
     "Choose" : "Veldu",
     "Copy" : "Afrita",
     "Move" : "Færa",
@@ -127,22 +126,30 @@ OC.L10N.register(
     "Check the background job settings" : "Athugaðu stillingar bakgrunnsvinnslunnar",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Þessi þjónn er ekki með virka nettengingu: ekki náðis tenging við fjölmarga endapunkta. Þetta þýðir að sumir eiginleikar eins og að virkja ytri gagnageymslu, tilkynningar um uppfærslur eða uppsetningu á forritum þriðja aðila, mun ekki virka. Fjartengdur aðgangur að skrám og sending tilkynninga í tölvupósti virka líklega ekki heldur. Við leggjum til að internettenging sé virkjuð fyrir þennan vefþjón ef þú vilt hafa alla eiginleika tiltæka.",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Ekkert skyndiminni (cache) hefur verið stillt. Til að auka afköst ættirðu að setja upp skyndiminni (með memcache) ef það er tiltækt. Hægt er að finna nánari upplýsingar um þetta í <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">hjálparskjölum</a> okkar.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "/dev/urandom er ekki lesanlegt af PHP sem er mjög óráðlegt af öryggisástæðum. Hægt er að finna nánari upplýsingar um þetta í <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">hjálparskjölum</a> okkar.",
+    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Enginn hentugur gagnagjafi fyrir handahófsreikning fannst fyrir PHP, sem er mjög óráðlegt af öryggisástæðum. Hægt er að finna nánari upplýsingar um þetta í <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">hjálparskjölum</a> okkar.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Þú ert að keyra PHP {version}. Við hvetjum þig til að uppfæra PHP útgáfuna til að njóta <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">afkastaaukningar og öryggisuppfærslna frá PHP Group</a> um leið og dreifingin þín styður það.",
     "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "Þú ert núna að keyra PHP 5.6. Núverandi aðalútgáfa Nextcloud er sú síðasta sem  mun virka á PHP 5.6. Mælt er með því að uppfæra PHP í útgáfu 7.0+ til að eiga möguleika á að uppfæra í Nextcloud 14.",
     "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Uppsetning gagnstæðs milliþjónshauss (reverse proxy header) er röng, eða að þú ert að tengjast Nextcloud frá treystum milliþjóni Ef þú ert ekki að tengjast Nextcloud frá treystum milliþjóni, þá er þetta er öryggisvandamál og getur leyft árásaraðilum að dulbúa IP-vistfang þeirra sem sýnilegt Nextcloud. Nánari upplýsingar má finna í <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">hjálparskjölum</a> okkar.",
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached er sett upp sem dreift skyndiminni, en hinsvegar er ranga PHP-einingin \"memcache\" uppsett. \\OC\\Memcache\\Memcached styður einungis \"memcached\" en ekki \"memcache\". Skoðaðu <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki-síðurnar um báðar einingarnar</a>.",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Sumar skrár hafa ekki staðist áreiðanleikaprófun. Hægt er að finna nánari upplýsingar um þetta í <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">hjálparskjölum</a> okkar. (<a href=\"{codeIntegrityDownloadEndpoint}\">Listi yfir ógildar skrár…</a> / <a href=\"{rescanEndpoint}\">Endurskanna…</a>)",
+    "The PHP OPcache module is not loaded. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to load it into your PHP installation." : "PHP Opcache er ekki hlaðið inn. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Fyrir betri afköst mælum við með</a> því að nota eftirfarandi stillingar í <code>php.ini</code>:",
     "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "PHP Opcache er ekki rétt uppsett. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Fyrir betri afköst mælum við með</a> því að nota eftirfarandi stillingar í <code>php.ini</code>:",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-fallið \"set_time_limit\" er ekki tiltækt. Þetta gæti valdið því að skriftur stöðvist í miðri keyrslu og skemmi uppsetninguna þína. Við mælumst til þess að þetta fall sé gert virkt.",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP-uppsetningin er ekki með stuðning við Free Type. Þetta mun valda því að notendamyndir og stillingaviðmót virki ekki.",
+    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Vantar vísinn \"{indexName}\" í töflunni \"{tableName}\".",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Gagnagrunninn vantar nokkra atriðavísa (indexes). Vegna þess að það að bæta atriðavísum við stórar töflur getur tekið töluverðan tíma, þá var þeim ekki bætt við sjálfvirkt. Með því að keyra \"occ db:add-missing-indices\" væri hægt að bæta inn þessum atriðavísum sem vantar, á meðan kerfið er í gangi. Um leið og búið er að bæta inn þessum atriðavísum, munu fyrirspurnir í þessar töflur verða miklu hraðvirkari.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Núna er stuðst við SQLite sem bakenda fyrir gagnagrunn. Fyrir stærri uppsetningar mælum við með að skipta yfir í annan gagnagrunnsbakenda.",
     "This is particularly recommended when using the desktop client for file synchronisation." : "Mælt er sérstaklega með þessu þegar skjáborðsforritið er notað til að samstilla skrár.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a>." : "Til að yfirfæra í annan gagnagrunn skaltu nota skipanalínutólið: 'occ db:convert-type', eða lesa <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">hjálparskjölin ↗</a>.",
+    "Use of the the built in php mailer is no longer supported. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Please update your email server settings ↗<a/>." : "Notkun á innbyggðum php póstsendingum er ekki lengur studd. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Uppfærðu stillingar póstþjónsins þíns ↗<a/>.",
+    "The PHP memory limit is below the recommended value of 512MB." : "Minnismörk PHP eru lægri en gildið sem mælt er með; 512MB.",
+    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Sumar forritamöppur eru í eigu annarra notenda en möppurnar á vefþjóninum. Þetta getur komið upp ef forritin hafa verið sett upp handvirkt. Athugaðu með heimildir á eftirfarandi forritamöppum:",
     "Error occurred while checking server setup" : "Villa kom upp við athugun á uppsetningu þjóns",
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Gagnamappan og skrárnar þínar eru líklega aðgengilegar öllum af internetinu vegna þess að .htaccess skrá er ekki virk. Við mælum eindregið með að þú stillir vefþjóninn þinn á þann hátt að gagnamappa er ekki lengur aðgengileg eða þú færir gagnamöppu út fyrir skjalarót vefþjóns.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP-hausinn er ekki stilltur á \"{expected}\". Þetta er möguleg áhætta varðandi  öryggi og gagnaleynd, við mælum með því að laga þessa stillingu.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP-hausinn er ekki stilltur á \"{expected}\". Einhverjir eiginleikar gætu virkað ekki rétt, við mælum með því að laga þessa stillingu.",
+    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP-hausinn inniheldur ekki \"{expected}\". Þetta er möguleg áhætta varðandi öryggi og gagnaleynd, við mælum með því að laga þessa stillingu.",
+    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "HTTP-hausinn \"{header}\" er ekki stilltur á \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" eða \"{val5}\". Þetta getur lekið upplýsingum um kerfið. Skoðaðu hvað <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C mælir með ↗</a>.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "\"Strict-Transport-Security\" HTTP-hausinn er ekki stilltur á að minnsa kosti \"{seconds}\" sekúndur. Fyrir aukið öryggi mælum við með því að virkja HSTS eins og lýst er í <a href=\"{docUrl}\" rel=\"noreferrer noopener\">öryggisleiðbeiningum ↗ </a>.",
     "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : " Þú ert að tengjast þessu vefsvæði með HTTP. Við mælum eindregið með að þú stillir þjóninn á að krefjast HTTPS í staðinn eins og lýst er í <a href=\"{docUrl}\">öryggisleiðbeiningunum okkar ↗</a>.",
     "Shared" : "Deilt",
@@ -151,13 +158,17 @@ OC.L10N.register(
     "Choose a password for the public link" : "Veldu þér lykilorð fyrir almenningstengil",
     "Choose a password for the public link or press the \"Enter\" key" : "Veldu þér lykilorð fyrir opinbera tengilinn eða ýttu á \"Ente\" lykilinn",
     "Copied!" : "Afritað!",
+    "Copy link" : "Afrita tengil",
     "Not supported!" : "Óstutt!",
     "Press ⌘-C to copy." : "Ýttu á ⌘-C til að afrita.",
     "Press Ctrl-C to copy." : "Ýttu á Ctrl-C til að afrita.",
+    "Unable to create a link share" : "Gat ekki búið til sameignartengil",
+    "Unable to toggle this option" : "Tekst ekki að víxla þessum valkosti af/á",
     "Resharing is not allowed" : "Endurdeiling er ekki leyfð",
     "Share to {name}" : "Deila til {name}",
-    "Copy URL" : "Afrita slóð",
     "Link" : "Tengill",
+    "Hide download" : "Fela niðurhal",
+    "Password protection enforced" : "Gerði verndun með lykilorði nauðsynlega",
     "Password protect" : "Verja með lykilorði",
     "Allow editing" : "Leyfa breytingar",
     "Email link to person" : "Senda veftengil í tölvupósti til notanda",
@@ -165,29 +176,38 @@ OC.L10N.register(
     "Allow upload and editing" : "Leyfa innsendingu og breytingar",
     "Read only" : "Skrifvarið",
     "File drop (upload only)" : "Slepping skráa (einungis innsending)",
+    "Expiration date enforced" : "Gerði gildistíma nauðsynlegan",
     "Set expiration date" : "Setja gildistíma",
     "Expiration" : "Rennur út",
     "Expiration date" : "Gildir til",
+    "Note to recipient" : "Minnispunktur til viðtakanda",
+    "Unshare" : "Hætta deilingu",
+    "Delete share link" : "Eyða tengli á sameign",
+    "Add another link" : "Bæta við öðrum tengli",
+    "Password protection for links is mandatory" : "Verndun tengla með lykilorði er skylda",
     "Share link" : "Deila tengli",
-    "Enable" : "Virkja",
+    "New share link" : "Nýr tengill á sameign",
+    "Password protect by Talk" : "Verja með lykilorði í gegnum Talk",
+    "Could not unshare" : "Gat ekki hætt deilingu",
     "Shared with you and the group {group} by {owner}" : "Deilt með þér og hópnum {group} af {owner}",
     "Shared with you and {circle} by {owner}" : "Deilt með þér og {circle} af {owner}",
+    "Shared with you and the conversation {conversation} by {owner}" : "Deilt með þér og samtalinu {conversation} af {owner}",
+    "Shared with you in a conversation by {owner}" : "Deilt með þér í samtali af {owner}",
     "Shared with you by {owner}" : "Deilt með þér af {owner}",
     "Choose a password for the mail share" : "Veldu lykilorð fyrir póstsameign",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} deildi með tengli",
     "group" : "hópur",
     "remote" : "fjartengt",
     "remote group" : "fjartengdur hópur",
     "email" : "tölvupóstur",
+    "conversation" : "samtal",
     "shared by {sharer}" : "deilt af {sharer}",
-    "Unshare" : "Hætta deilingu",
     "Can reshare" : "Getur endurdeilt",
     "Can edit" : "Getur breytt",
     "Can create" : "Getur búið til",
     "Can change" : "Getur skipt um",
     "Can delete" : "Getur eytt",
     "Access control" : "Aðgangsstýring",
-    "Could not unshare" : "Gat ekki hætt deilingu",
+    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} deildi með tengli",
     "Error while sharing" : "Villa við deilingu",
     "Share details could not be loaded for this item." : "Ekki tókst að hlaða inn upplýsingum um sameign varðandi þetta atriði.",
     "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Það þarf a.m.k. {count} staf til að sjálfvirk útfylling virki","Það þarf a.m.k. {count} stafi til að sjálfvirk útfylling virki"],
@@ -196,10 +216,10 @@ OC.L10N.register(
     "No users found for {search}" : "Engir notendur fundust með {search}",
     "An error occurred (\"{message}\"). Please try again" : "Villa kom upp (\"{message}\"). Endilega reyndu aftur",
     "An error occurred. Please try again" : "Villa kom upp. Endilega reyndu aftur",
-    "{sharee} (group)" : "{sharee} (hópur)",
-    "{sharee} (remote)" : "{sharee} (fjartengdur)",
+    "Home" : "Heima",
+    "Work" : "Vinna",
+    "Other" : "Annað",
     "{sharee} (remote group)" : "{sharee} (fjartengdur hópur)",
-    "{sharee} (email)" : "{sharee} (tölvupóstur)",
     "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
     "Share" : "Deila",
     "Name or email address..." : "Nafn eða tölvupóstfang...",
@@ -242,8 +262,8 @@ OC.L10N.register(
     "Help" : "Hjálp",
     "Access forbidden" : "Aðgangur bannaður",
     "File not found" : "Skrá finnst ekki",
-    "The specified document has not been found on the server." : "Tiltekið skjal hefur ekki fundist á þjóninum.",
-    "You can click here to return to %s." : "Þú getur smellt hér til að fara aftur á %s.",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Skjalið fannst ekki á þjóninum. Hugsanlega hefur sameigninni verið eytt eða sé útrunnin?",
+    "Back to %s" : "Til baka í %s",
     "Internal Server Error" : "Innri villa",
     "The server was unable to complete your request." : "Þjóninum tókst ekki að afgreiða beiðnina þína.",
     "If this happens again, please send the technical details below to the server administrator." : "Ef þetta gerist aftur, sendu tæknilegu lýsinguna hér fyrir neðan til kerfisstjóra þjónsins.",
@@ -284,7 +304,9 @@ OC.L10N.register(
     "See the documentation" : "Sjá hjálparskjölin",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Þetta forrit krefst JavaScript fyrir rétta virkni. {linkstart} virkjaðu JavaScript {linkend} og endurlestu síðan síðuna.",
     "Skip to main content" : "Sleppa og fara í meginefni",
+    "Skip to navigation of app" : "Hlaupa yfir í flakk innan forrits",
     "More apps" : "Fleiri forrit",
+    "More" : "Meira",
     "More apps menu" : "Valmynd með fleiri forrit",
     "Search" : "Leita",
     "Reset search" : "Núllstilla leit",
@@ -304,27 +326,30 @@ OC.L10N.register(
     "Forgot password?" : "Gleymdirðu lykilorði?",
     "Back to login" : "Til baka í innskráningu",
     "Connect to your account" : "Tengdu við notandaaðganginn þinn",
-    "Please log in before granting %s access to your %s account." : "Skráði þig inn áður en þú leyfir %s aðgang að %s notandaaðgangnum þínum.",
+    "Please log in before granting %1$s access to your %2$s account." : "Skráði þig inn áður en þú leyfir %1$s aðgang að %2$s notandaaðgangnum þínum.",
     "App token" : "Teikn forrits",
     "Grant access" : "Veita aðgengi",
     "Alternative log in using app token" : "Önnur innskráning með forritsteikni",
     "Account access" : "Aðgangur að notandaaðgangi",
-    "You are about to grant %s access to your %s account." : "Þú ert að fara að leyfa %s aðgang að %s notandaaðgangnum þínum.",
+    "You are about to grant %1$s access to your %2$s account." : "Þú ert að fara að leyfa \"%1$s\" aðgang að %2$s notandaaðgangnum þínum.",
     "Redirecting …" : "Endurbeini ...",
     "New password" : "Nýtt lykilorð",
     "New Password" : "Nýtt lykilorð",
     "This share is password-protected" : "Þessi sameign er varin með lykilorði",
     "The password is wrong. Try again." : "Lykilorðið er rangt. Reyndu aftur.",
     "Two-factor authentication" : "Tveggja-þrepa auðkenning",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Aukið öryggi var virkjað fyrir aðganginn þinn. Auðkenndu þig með aukaþrepi.",
-    "Cancel log in" : "Hætta við innskráningu",
+    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Aukið öryggi var virkjað fyrir aðganginn þinn. Veldu aukaþrep til auðkenningar:",
+    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Gat ekki hlaðið inn a.m.k. einni af virkum tveggja-þrepa auðkenningaraðferðunum þínum. Hafðu samband við kerfisstjóra.",
+    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Tveggja-þátta auðkenningar er krafist, en er ekki búið að setja upp á aðgangnu þínum. Hafðu samband við kerfisstjóra til að fá aðstoð varðandi þetta.",
+    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Tveggja-þátta auðkenningar er krafist, en er ekki búið að setja upp á aðgangnu þínum. Notaðu einn af öryggisafritunarkóðunum þínum til að skrá þig inn, eða hafðu samband við kerfisstjóra til að fá aðstoð varðandi þetta.",
     "Use backup code" : "Nota öryggisafritskóða",
+    "Cancel log in" : "Hætta við innskráningu",
     "Error while validating your second factor" : "Villa við að sannreyna seinna þrepið",
     "Access through untrusted domain" : "Tenging frá ótreystu léni",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Hafðu samband við kerfisstjóra. Ef þú ert stjórnandi, stilltu \"trusted_domains\" setninguna í config/config.php. Dæmi um stillingar má sjá í config/config.sample.php.",
-    "Further information how to configure this can be found in the %sdocumentation%s." : "Frekari upplýsingar um hvernig hægt er að stilla þetta má finna í %shjálparskjölunum%s.",
+    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Frekari upplýsingar um hvernig hægt er að stilla þetta má finna í %1$shjálparskjölunum%2$s.",
     "App update required" : "App þarfnast uppfærslu ",
-    "%s will be updated to version %s" : "%s verður uppfært í útgáfu %s.",
+    "%1$s will be updated to version %2$s" : "%1$s verður uppfært í útgáfu %2$s.",
     "These apps will be updated:" : "Eftirfarandi öpp verða uppfærð:",
     "These incompatible apps will be disabled:" : "Eftirfarandi forrit eru ósamhæfð og verið gerð óvirk: %s",
     "The theme %s has been disabled." : "Þema %s hefur verið gert óvirkt.",
@@ -337,12 +362,14 @@ OC.L10N.register(
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Til að fá hjálp er best að skoða fyrst  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">hjálparskjölin</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Ég veit að ef ég held uppfærslunni áfram í gegnum vefviðmótið, þá er sú áhætta fyrir hendi að beiðnin falli á tímamörkum, sem aftur gæti valdið gagnatapi - en ég á öryggisafrit og veit hvernig ég get endurheimt uppsetninguna mína ef aðgerðin misferst.",
     "Upgrade via web on my own risk" : "Uppfæra með vefviðmóti á mína eigin ábyrgð",
+    "Maintenance mode" : "Viðhaldshamur",
     "This %s instance is currently in maintenance mode, which may take a while." : "Þessi %s er nú í viðhaldsham, sem getur tekið smá stund.",
-    "This page will refresh itself when the %s instance is available again." : "Þessi síða mun uppfæra sig þegar %s er í boði á ný.",
+    "This page will refresh itself when the instance is available again." : "Þessi síða mun uppfæra sig þegar tilvikið er í boði á ný.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Hafðu samband við kerfisstjóra ef þessi skilaboð eru viðvarandi eða birtust óvænt.",
-    "Thank you for your patience." : "Þakka þér fyrir biðlundina.",
+    "Updated \"%s\" to %s" : "Uppfærði \"%s\" í %s",
     "%s (3rdparty)" : "%s (frá 3. aðila)",
     "There was an error loading your contacts" : "Það kom upp villa við að hlaða inn tengiliðunum þínum",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Það komu upp vandamál með athugun á áreiðanleika kóða. Nánari upplýsingar…</a>",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Vefþjónninn er ekki enn sett upp á réttan hátt til að leyfa skráasamstillingu því WebDAV viðmótið virðist vera skemmt.",
     "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Vefþjónninn þinn er ekki uppsettur þannig að hann geti leyst \"{url}\". Frekari upplýsingar er að finna í <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">hjálparskjölum</a> okkar.",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Þessi þjónn er ekki með virka nettengingu: ekki náðis tenging við fjölmarga endapunkta. Þetta þýðir að sumir eiginleikar eins og að virkja ytri gagnageymslu, tilkynningar um uppfærslur eða uppsetningu á forritum þriðja aðila, mun ekki virka. Fjartengdur aðgangur að skrám og sending tilkynninga í tölvupósti virka líklega ekki heldur. Við leggjum til að internettenging sé virkjuð fyrir þennan vefþjón ef þú vilt hafa alla eiginleika tiltæka.",
@@ -361,9 +388,15 @@ OC.L10N.register(
     "Shared with {recipients}" : "Deilt með {recipients}",
     "Error setting expiration date" : "Villa við að setja gildistíma",
     "The public link will expire no later than {days} days after it is created" : "Almenningstengillinn rennur út eigi síðar en {days} dögum eftir að hann er útbúinn",
+    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} deildi með tengli",
+    "{sharee} (group)" : "{sharee} (hópur)",
+    "{sharee} (remote)" : "{sharee} (fjartengdur)",
+    "{sharee} (email)" : "{sharee} (tölvupóstur)",
     "Share with other people by entering a user or group, a federated cloud ID or an email address." : "Deildu með öðru fólki með því að setja inn notanda, hóp, skýjasambandsauðkenni eða tölvupóstfang.",
     "Share with other people by entering a user or group or a federated cloud ID." : "Deildu með öðru fólki með því að setja inn notanda, hóp eða skýjasambandsauðkenni.",
     "Share with other people by entering a user or group or an email address." : "Deildu með öðru fólki með því að setja inn notanda, hóp eða tölvupóstfang.",
+    "The specified document has not been found on the server." : "Tiltekið skjal hefur ekki fundist á þjóninum.",
+    "You can click here to return to %s." : "Þú getur smellt hér til að fara aftur á %s.",
     "The server encountered an internal error and was unable to complete your request." : "Innri villa kom upp á þjóninum og ekki náðist að afgreiða beiðnina.",
     "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Hafðu samband við kerfisstjóra ef þessi villa birtist oft aftur, láttu þá tæknilegu upplýsingarnar hér að neðan fylgja með.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentation</a>." : "Til að fá upplýsingar hvernig á að stilla miðlara almennilega, skaltu skoða <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">hjálparskjölin</a>.",
@@ -373,15 +406,26 @@ OC.L10N.register(
     "Alternative Logins" : "Aðrar innskráningar",
     "You are about to grant \"%s\" access to your %s account." : "Þú ert að fara að leyfa \"%s\" aðgang að %s notandaaðgangnum þínum.",
     "Alternative login using app token" : "Önnur innskráning með forritsteikni",
+    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Aukið öryggi var virkjað fyrir aðganginn þinn. Auðkenndu þig með aukaþrepi.",
     "You are accessing the server from an untrusted domain." : "Þú ert að tengjast þjóninum frá ótreystu léni.",
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Hafðu samband við kerfisstjóra. Ef þú ert stjórnandi á þessu tilviki, stilltu \"trusted_domains\" setninguna í config/config.php. Dæmi um stillingar má sjá í config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Það fer eftir stillingum þínum, sem stjórnandi þá gætir þú einnig notað hnappinn hér fyrir neðan til að treysta þessu léni.",
     "Add \"%s\" as trusted domain" : "Bæta við \"%s\" sem treystu léni",
+    "%s will be updated to version %s" : "%s verður uppfært í útgáfu %s.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Til að fá hjálp er best að skoða fyrst  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">hjálparskjölin</a>.",
+    "This page will refresh itself when the %s instance is available again." : "Þessi síða mun uppfæra sig þegar %s er í boði á ný.",
+    "Thank you for your patience." : "Þakka þér fyrir biðlundina.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "/dev/urandom er ekki lesanlegt af PHP sem er mjög óráðlegt af öryggisástæðum. Hægt er að finna nánari upplýsingar um þetta í <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">hjálparskjölum</a> okkar.",
     "Your PHP does not have freetype support. This will result in broken profile pictures and settings interface." : "PHP-uppsetningin er ekki með stuðning við 'freetype'. Þetta mun valda því að notendamyndir og stillingaviðmót virki ekki.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips</a>." : "\"Strict-Transport-Security\" HTTP-hausinn er ekki stilltur á að minnsa kosti \"{seconds}\" sekúndur. Fyrir aukið öryggi mælum við með því að virkja HSTS eins og lýst er í <a href=\"{docUrl}\" rel=\"noreferrer noopener\">öryggisleiðbeiningum</a>.",
     "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips</a>." : " Þú ert að tengjast þessu vefsvæði með HTTP. Við mælum eindregið með að þú stillir þjóninn á að krefjast HTTPS í staðinn eins og lýst er í <a href=\"{docUrl}\">öryggisleiðbeiningunum</a> okkar.",
     "Back to log in" : "Til baka í innskráningu",
-    "Depending on your configuration, this button could also work to trust the domain:" : "Það fer eftir stillingunum þínum, þessi hnappur gæti einnig virkað til að treysta þessu léni."
+    "You are about to grant %s access to your %s account." : "Þú ert að fara að leyfa %s aðgang að %s notandaaðgangnum þínum.",
+    "Depending on your configuration, this button could also work to trust the domain:" : "Það fer eftir stillingunum þínum, þessi hnappur gæti einnig virkað til að treysta þessu léni.",
+    "Copy URL" : "Afrita slóð",
+    "Enable" : "Virkja",
+    "{sharee} (conversation)" : "{sharee} (samtal)",
+    "Please log in before granting %s access to your %s account." : "Skráði þig inn áður en þú leyfir %s aðgang að %s notandaaðgangnum þínum.",
+    "Further information how to configure this can be found in the %sdocumentation%s." : "Frekari upplýsingar um hvernig hægt er að stilla þetta má finna í %shjálparskjölunum%s."
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
