@@ -35,7 +35,6 @@ OC.L10N.register(
     "Turned on maintenance mode" : "Режим одржавања укључен",
     "Turned off maintenance mode" : "Режим одржавања искључен",
     "Maintenance mode is kept active" : "Режим одржавања се држи активним",
-    "Waiting for cron to finish (checks again in 5 seconds) …" : "Чекање да се заврши крон (проверите опет за 5 секунди) …",
     "Updating database schema" : "Освежава се шема базе података",
     "Updated database" : "База података ажурирана",
     "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Провера да ли шема базе података може да се ажурира (ово може потрајати, у зависности колика је база)",
@@ -46,7 +45,7 @@ OC.L10N.register(
     "Checked for update of app \"%s\" in appstore" : "Проверено ажурирање апликације „%s“ у продавници",
     "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Провера да ли шема база за %s може бити ажурирана (ово може да потраје, у зависности колика је база)",
     "Checked database schema update for apps" : "Проверено ажурирање шеме базе података за апликације",
-    "Updated \"%s\" to %s" : "„%s“ ажуриран на %s",
+    "Updated \"%1$s\" to %2$s" : "„%1$s“ ажурирано на %2$s",
     "Set log level to debug" : "Постави ниво уписа у дневник на дебаговање",
     "Reset log level" : "Поништи ниво уписа у дневник",
     "Starting code integrity check" : "Почиње провера интегритета кода",
@@ -54,13 +53,12 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (некомпатибилан)",
     "Following apps have been disabled: %s" : "Следеће апликације су онемогућене: %s",
     "Already up to date" : "Већ има последњу верзију",
+    "Could not load your contacts" : "Не могу да учитам Ваше контакте",
     "Search contacts …" : "Претражи контакте ...",
     "No contacts found" : "Контакти нису нађени",
     "Show all contacts …" : "Прикажи све контакте ...",
-    "Could not load your contacts" : "Не могу да учитам Ваше контакте",
     "Loading your contacts …" : "Учитавам контакте ...",
     "Looking for {term} …" : "Тражим {term} …",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Догодила се грешка приликом провере интегритета кода. Више информација...</a>",
     "No action available" : "Нема доступне радње",
     "Error fetching contact actions" : "Грешка приликом дохватања акција над контактима",
     "Settings" : "Поставке",
@@ -128,7 +126,7 @@ OC.L10N.register(
     "Check the background job settings" : "Проверите поставке послова у позадини",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Овај сервер нема интернет конекцију: немогуће је доћи до више интернет крајњих тачака. Ово значи да неке могућности као што су качење спољних складишта, обавештења о ажурирањима или инсталација апликација треће стране неће радити. Приступање фајловима споља и слање обавештења е-поштом исто тако може да не ради. Омогућите интернет конекцију на овом серверу ако желите да уживате у свим могућностима.",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Нисте подесили меморијски кеш. Да побољшате перформансе, подесите меморијски кеш, ако је доступан. Више информација има у <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацији</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "PHP не може да чита /dev/urandom. Ово се баш не препоручује из сигурносних разлога. Можете наћи више информација у <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацији</a>.",
+    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "PHP не може да чита погодан извор случајних бројева што се не препоручује из сигурносних разлога. Можете наћи више информација у <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацији</a>.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Тренутно користите {version} верзију PHP-а. Надоградите PHP верзију да искористите сва <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">безбедоносна ажурирања и побољшања брзине које обезбеђује PHP група</a>, чим Ваша дистрибуција почне да је подржава.",
     "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "Тренутно користите PHP верзију 5.6. Тренутна главна верзија Некстклауда је последња која подржава PHP 5.6. Препорука је да пређете на PHP верзију 7.0+ да бисте могли да ажурирате Некстклауд на верзију 14.",
     "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Или подешавање обрнутих прокси заглавља није исправно, или приступате Некстклауду преко проксија од поверења. Ако то не радите, ово је безбедоносни проблем и може омогућити нападачу да лажира да је његова IP адреса видљива Некстклауду. Више информација о овоме има у <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацији</a>.",
@@ -150,7 +148,8 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Ваша фасцикла са подацима и фајлови су вероватно доступни са интернета. .htaccess фајл не ради. Препоручујемо да подесите Ваш веб сервер тако да је фасцикла са подацима ван фасцикле кореног документа веб сервера.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавље „{header}“ није подешено као „{expected}“. Ово потенцијално угрожава безбедност и приватност и препоручује се да подесите ову поставку.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP заглавље „{header}“ није подешено као „{expected}“. Неке функције можда неће радити исправно, па препоручује се да подесите ову поставку.",
-    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\" or \"{val4}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "HTTP заглавље \"{header}\" није постављено на \"{val1}\", \"{val2}\", \"{val3}\" или \"{val4}\". Овиме могу процурети информације о рефералу. Погледајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C препоруке↗</a>",
+    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавље „{header}“ не садржи „{expected}“. Ово потенцијално угрожава безбедност и приватност и препоручује се да подесите ову поставку.",
+    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "HTTP заглавље \"{header}\" није постављено на \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" или \"{val5}\". Овиме могу процурети информације о рефералу. Погледајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C препоруке↗</a>",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "\"Strict-Transport-Security\" HTTP заглавље није подешено да буде бар \"{seconds}\" секунди. За додатну сигурност, предлаже се да омогућите HSTS као што је описано у <a href=\"{docUrl}\" rel=\"noreferrer noopener\">сигурносним саветима↗</a>.",
     "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "Приступање сајту преко HTTP-а. Препоручује се да подесите Ваш сервер да захтева HTTPS као што је описано у <a href=\"{docUrl}\">безбедоносним саветима↗</a>",
     "Shared" : "Дељено",
@@ -159,13 +158,17 @@ OC.L10N.register(
     "Choose a password for the public link" : "Унесите лозинку за јавну везу",
     "Choose a password for the public link or press the \"Enter\" key" : "Унесите лозинку за јавну везу или притисните \"Ентер\"",
     "Copied!" : "Копирано!",
+    "Copy link" : "Копирај везу",
     "Not supported!" : "Није подржано!",
     "Press ⌘-C to copy." : "Притисни ⌘-C за копирање.",
     "Press Ctrl-C to copy." : "Притисни Ctrl-C за копирање.",
+    "Unable to create a link share" : "Не могу да направим везу дељења",
+    "Unable to toggle this option" : "Не могу да укључим/искључим ову опцију",
     "Resharing is not allowed" : "Поновно дељење није дозвољено",
     "Share to {name}" : "Подели са {name}",
-    "Copy URL" : "Копирај URL",
     "Link" : "Веза",
+    "Hide download" : "Сакриј скидање",
+    "Password protection enforced" : "Захтевана заштита лозинком",
     "Password protect" : "Заштићено лозинком",
     "Allow editing" : "Дозволи уређивање",
     "Email link to person" : "Пошаљи е-поштом",
@@ -173,33 +176,38 @@ OC.L10N.register(
     "Allow upload and editing" : "Дозволи отпремање и уређивање",
     "Read only" : "Само за читање",
     "File drop (upload only)" : "Превлачење фајлова (само за отпремање)",
+    "Expiration date enforced" : "Захтевано постављање датума истека",
     "Set expiration date" : "Постави датум истека",
     "Expiration" : "Истиче",
     "Expiration date" : "Датум истека",
     "Note to recipient" : "Белешка примаоцу",
+    "Unshare" : "Укини дељење",
+    "Delete share link" : "Обриши везу дељења",
+    "Add another link" : "Додај још једну везу",
+    "Password protection for links is mandatory" : "За везе је обавезна заштита лозинком",
     "Share link" : "Веза дељења",
-    "Enable" : "Укључи",
+    "New share link" : "Нова веза дељења",
+    "Password protect by Talk" : "Заштити лозинком преко Talk-а",
+    "Could not unshare" : "Не могу да укинем дељење",
     "Shared with you and the group {group} by {owner}" : "{owner} дели са вама и са групом {group}.",
     "Shared with you and {circle} by {owner}" : "Дељемп са Вама и кругом {circle} од стране корисника {owner}",
     "Shared with you and the conversation {conversation} by {owner}" : "{owner} поделио са Вама и у разговору {conversation}",
+    "Shared with you in a conversation by {owner}" : "{owner} поделио са Вама у разговору",
     "Shared with you by {owner}" : "{owner} дели са вама",
     "Choose a password for the mail share" : "Изаберите лозинку за дељење е-поштом",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} је поделио преко везе",
     "group" : "група",
     "remote" : "удаљени",
     "remote group" : "удаљена група",
     "email" : "е-пошта",
     "conversation" : "разговор",
     "shared by {sharer}" : "поделио је {sharer}",
-    "Unshare" : "Укини дељење",
     "Can reshare" : "Може да дели даље",
     "Can edit" : "Може да мења",
     "Can create" : "Може да направи",
     "Can change" : "Може да мења",
     "Can delete" : "Може да брише",
-    "Password protect by Talk" : "Заштити лозинком преко Talk-а",
     "Access control" : "Контрола приступа",
-    "Could not unshare" : "Не могу да укинем дељење",
+    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} је поделио преко везе",
     "Error while sharing" : "Грешка при дељењу",
     "Share details could not be loaded for this item." : "Не могу да учитам детаље дељења за ову ставку.",
     "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Најмање {count} слово је потребно за аутокомплетирање","Најмање {count} слова је потребно за аутокомплетирање","Најмање {count} слова је потребно за аутокомплетирање"],
@@ -208,12 +216,11 @@ OC.L10N.register(
     "No users found for {search}" : "Није нађен ниједан корисник за претрагу {search}",
     "An error occurred (\"{message}\"). Please try again" : "Десила се грешка (\"{message}\"). Покушајте поново.",
     "An error occurred. Please try again" : "Дошло је до грешке. Покушајте поново",
-    "{sharee} (group)" : "{sharee} (група)",
-    "{sharee} (remote)" : "{sharee} (удаљено)",
+    "Home" : "Почетна",
+    "Work" : "Посао",
+    "Other" : "Остало",
     "{sharee} (remote group)" : "{sharee} (удаљена група)",
-    "{sharee} (email)" : "{sharee} (е-пошта)",
     "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "{sharee} (conversation)" : "{sharee} (разговор)",
     "Share" : "Дели",
     "Name or email address..." : "Име или адреса е-поште...",
     "Name or federated cloud ID..." : "Име или ID здруженог облака...",
@@ -255,8 +262,8 @@ OC.L10N.register(
     "Help" : "Помоћ",
     "Access forbidden" : "Забрањен приступ",
     "File not found" : "Фајл није нађен",
-    "The specified document has not been found on the server." : "Наведени документ није нађен на серверу.",
-    "You can click here to return to %s." : "Кликните овде да се вратите на %s.",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Овај документ није нађен на серверу. Можда је дељење избрисано или му је истекао рок трајања?",
+    "Back to %s" : "Назад на %s",
     "Internal Server Error" : "Унутрашња грешка сервера",
     "The server was unable to complete your request." : "Сервер не може да обради Ваш захтев.",
     "If this happens again, please send the technical details below to the server administrator." : "Ако се ово понови, пошаљите техниче детаље испод администратору овог сервера.",
@@ -299,6 +306,7 @@ OC.L10N.register(
     "Skip to main content" : "Прескочи на главни садржај",
     "Skip to navigation of app" : "Прескочи на навигацију апликације",
     "More apps" : "Још апликација",
+    "More" : "Још",
     "More apps menu" : "Мени још апликација",
     "Search" : "Претражи",
     "Reset search" : "Ресетуј претрагу",
@@ -318,28 +326,30 @@ OC.L10N.register(
     "Forgot password?" : "Заборавили сте лозинку?",
     "Back to login" : "Назад на пријаву",
     "Connect to your account" : "Повежите се на Ваш налог",
-    "Please log in before granting %s access to your %s account." : "Прво се пријавите пре него што одобрите привилегију %s приступ Вашем налогу %s.",
+    "Please log in before granting %1$s access to your %2$s account." : "Прво се пријавите пре него што одобрите привилегију %1$s приступ Вашем налогу %2$s.",
     "App token" : "Апликативни жетон",
     "Grant access" : "Одобри приступ",
     "Alternative log in using app token" : "Алтернативна пријава коришћењем апликативног жетона",
     "Account access" : "Приступ налогу",
-    "You are about to grant %s access to your %s account." : "Управо ћете одобрити %s приступ Вашем %s налогу.",
+    "You are about to grant %1$s access to your %2$s account." : "Управо ћете одобрити %1$s приступ Вашем %2$s налогу.",
     "Redirecting …" : "Преусмеравање ...",
     "New password" : "Нова лозинка",
     "New Password" : "Нова лозинка",
     "This share is password-protected" : "Ово дељење је заштићено лозинком",
     "The password is wrong. Try again." : "Лозинка је погрешна. Покушајте поново.",
-    "Two-factor authentication" : "Двофакторска провера идентитека",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Повећана сигурност је омогућена за овај налог. Проверите идентитет и другим фактором.",
+    "Two-factor authentication" : "Двофакторска провера идентитета",
+    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Повећана сигурност је омогућена за овај налог. Одаберите други фактор за проверу идентитета:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Није могуће учитати ниједан метод двофакторске провере идентитета. Контактирајте администратора.",
-    "Cancel log in" : "Поништите пријаву",
+    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Двофакторска провера идентитета је захтевана, али није још подешена на Вашем налогу. Контактирајте администратора за помоћ.",
+    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Двофакторска провера идентитета је захтевана, али није још подешена на Вашем налогу. Или употребите Ваше резервне кôдове, или контактирајте администратора за помоћ.",
     "Use backup code" : "Користите резервни кôд",
+    "Cancel log in" : "Поништите пријаву",
     "Error while validating your second factor" : "Грешка при провери Вашег другог фактора",
     "Access through untrusted domain" : "Приступ кроз небезбедни домен",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Контактирајте Вашег администратора. Ако сте Ви администратор, измените \"trusted_domains\" подешавање у config/config.php као у примеру config.sample.php.",
-    "Further information how to configure this can be found in the %sdocumentation%s." : "Више информација о томе како ово подесити можете да нађете у %s документацији%s.",
+    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Више информација о томе како ово подесити можете да нађете у %1$s документацији%2$s.",
     "App update required" : "Потребно ажурирање апликације",
-    "%s will be updated to version %s" : "%s ће бити ажурирана на верзију %s",
+    "%1$s will be updated to version %2$s" : "%1$s ће бити ажурирана на верзију %2$s",
     "These apps will be updated:" : "Следеће апликације ће бити ажуриране:",
     "These incompatible apps will be disabled:" : "Следеће некомпатибилне апликације ће бити онемогућене:",
     "The theme %s has been disabled." : "Тема %s је онемогућена.",
@@ -352,12 +362,14 @@ OC.L10N.register(
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "За помоћ, погледајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документацију</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Свестан сам да уколико наставим ажурирање преко веба да постоји ризик да захтеву истекне време за извршење и да то може да изазове губитак података, али имам резервну копију и знам како да је повратим у случају грешака.",
     "Upgrade via web on my own risk" : "Надогради преко веба на сопствену одговорност",
+    "Maintenance mode" : "Режим одржавања",
     "This %s instance is currently in maintenance mode, which may take a while." : "Овај %s је тренутно у режиму одржавања што може потрајати.",
-    "This page will refresh itself when the %s instance is available again." : "Ова страница ће се сама освежити када %s постане поново доступан.",
+    "This page will refresh itself when the instance is available again." : "Ова страница ће се сама освежити када инстанца постане поново доступна.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте администратора ако се порука понавља или се неочекивано појавила.",
-    "Thank you for your patience." : "Хвала Вам на стрпљењу.",
+    "Updated \"%s\" to %s" : "„%s“ ажуриран на %s",
     "%s (3rdparty)" : "%s (од 3. лица)",
     "There was an error loading your contacts" : "Догодила се грешка приликом учитавања Ваших контаката",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Догодила се грешка приликом провере интегритета кода. Више информација...</a>",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Ваш сервер није правилно подешен да омогући синхронизацију фајлова. Изгледа да је ВебДАВ сучеље покварено.",
     "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Ваш сервер није правилно подешен да разлучи \"{url}\". Можете наћи више информација у нашој <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">документацији</a>.",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Овај сервер нема интернет конекцију: немогуће је доћи до више интернет крајњих тачака. Ово значи да неке могућности као што су качење спољних складишта, обавештења о ажурирањима или инсталација апликација треће стране неће радити. Приступање фајловима споља и слање обавештења е-поштом исто тако може да не ради. Саветујемо да омогућите интернет конекцију овом серверу ако желите све могућности.",
@@ -376,9 +388,15 @@ OC.L10N.register(
     "Shared with {recipients}" : "Дељено са {recipients}",
     "Error setting expiration date" : "Грешка при постављању датума истека",
     "The public link will expire no later than {days} days after it is created" : "Јавна веза ће престати да важи {days} дана након стварања",
+    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} је поделио преко везе",
+    "{sharee} (group)" : "{sharee} (група)",
+    "{sharee} (remote)" : "{sharee} (удаљено)",
+    "{sharee} (email)" : "{sharee} (е-пошта)",
     "Share with other people by entering a user or group, a federated cloud ID or an email address." : "Делите са другим људима тако што унесете корисника, групу, ID здруженог облака или адресу е-поште. ",
     "Share with other people by entering a user or group or a federated cloud ID." : "Делите са другим људима тако што унесете корисника, групу или ID здруженог облака.",
     "Share with other people by entering a user or group or an email address." : "Делите са другим људима тако што унесете корисника или групу.",
+    "The specified document has not been found on the server." : "Наведени документ није нађен на серверу.",
+    "You can click here to return to %s." : "Кликните овде да се вратите на %s.",
     "The server encountered an internal error and was unable to complete your request." : "Због интерне грешке на серверу, ваш захтев није могао бити довршен.",
     "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Контактирајте администратора ако се грешка понови више пута и укључите у извештај техничке појединости наведене испод.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentation</a>." : "За информације како да правилно подесите Ваш сервер, погледајте <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">документацију</a>.",
@@ -388,15 +406,26 @@ OC.L10N.register(
     "Alternative Logins" : "Алтернативне пријаве",
     "You are about to grant \"%s\" access to your %s account." : "Управо ћете одобрити \"%s\" приступ Вашем %s налогу.",
     "Alternative login using app token" : "Алтернативна пријава коришћењем апликативног жетона",
+    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Повећана сигурност је омогућена за овај налог. Проверите идентитет и другим фактором.",
     "You are accessing the server from an untrusted domain." : "Приступате серверу са непоузданог домена.",
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Контактирајте Вашег администратора. Ако сте Ви администратор, измените \"trusted_domains\" подешавање у config/config.php. Пример једног подешавања је дат у config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Зависно од ваших подешавања, као администратор можете употребити дугме испод да потврдите поузданост домена.",
     "Add \"%s\" as trusted domain" : "Додај „%s“ као поуздан домен",
+    "%s will be updated to version %s" : "%s ће бити ажурирана на верзију %s",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "За помоћ, погледајте <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">документацију</a>.",
+    "This page will refresh itself when the %s instance is available again." : "Ова страница ће се сама освежити када %s постане поново доступан.",
+    "Thank you for your patience." : "Хвала Вам на стрпљењу.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "PHP не може да чита /dev/urandom. Ово се баш не препоручује из сигурносних разлога. Можете наћи више информација у <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацији</a>.",
     "Your PHP does not have freetype support. This will result in broken profile pictures and settings interface." : "Ваша PHP инсталација нема подршку за freetype. Ово ће довести до неисправних профилних слика и неисправног интерфејса за подешавања.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips</a>." : "\"Strict-Transport-Security\" HTTP заглавље није подешено да буде бар \"{seconds}\" секунди. За додатну сигурност, предлаже се да омогућите HSTS као што је описано у <a href=\"{docUrl}\" rel=\"noreferrer noopener\">сигурносним саветима</a>.",
     "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips</a>." : "Приступање сајту преко HTTP-а. Препоручује се да подесите Ваш сервер да захтева HTTPS као што је описано у <a href=\"{docUrl}\">безбедоносним саветима</a>.",
     "Back to log in" : "Назад на пријаву",
-    "Depending on your configuration, this button could also work to trust the domain:" : "У зависности од Ваше конфигурације, овим дугметом може да послужи да почнете да верујете овом домену:"
+    "You are about to grant %s access to your %s account." : "Управо ћете одобрити %s приступ Вашем %s налогу.",
+    "Depending on your configuration, this button could also work to trust the domain:" : "У зависности од Ваше конфигурације, овим дугметом може да послужи да почнете да верујете овом домену:",
+    "Copy URL" : "Копирај URL",
+    "Enable" : "Укључи",
+    "{sharee} (conversation)" : "{sharee} (разговор)",
+    "Please log in before granting %s access to your %s account." : "Прво се пријавите пре него што одобрите привилегију %s приступ Вашем налогу %s.",
+    "Further information how to configure this can be found in the %sdocumentation%s." : "Више информација о томе како ово подесити можете да нађете у %s документацији%s."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
