@@ -4,7 +4,9 @@ OC.L10N.register(
     "Cannot write into \"config\" directory!" : "Impossible d’écrire dans le répertoire « config » !",
     "This can usually be fixed by giving the webserver write access to the config directory" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire \"config\"",
     "See %s" : "Voir %s",
-    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Ce problème est généralement résolu %sen donnant au serveur web un accès en écriture au répertoire de configuration%s.",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ou, si vous préférez conserver le fichier config.php en lecture seule, définissez l'option \"config_is_read_only\" sur true.",
+    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire \"config\". Voir %s",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ou, si vous préférez conserver le fichier config.php en lecture seule, définissez l'option \"config_is_read_only\" sur true. Voir %s",
     "The files of the app %$1s were not replaced correctly. Make sure it is a version compatible with the server." : "Les fichiers de l'application %$1s n'ont pas été remplacés correctement. Veuillez vérifier que c'est une version compatible avec le serveur.",
     "Sample configuration detected" : "Configuration d'exemple détectée",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Il a été détecté que la configuration donnée à titre d'exemple a été copiée. Cela peut rendre votre installation inopérante et n'est pas pris en charge. Veuillez lire la documentation avant d'effectuer des modifications dans config.php",
@@ -12,54 +14,84 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s et %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s et %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s et %5$s",
+    "Education Edition" : "Édition pour l'éducation ",
+    "Enterprise bundle" : "Pack pour entreprise",
+    "Groupware bundle" : "Pack pour travail collaboratif",
+    "Social sharing bundle" : "Pack pour partage social",
     "PHP %s or higher is required." : "PHP %s ou supérieur est requis.",
     "PHP with a version lower than %s is required." : "PHP avec une version antérieure à %s est requis.",
-    "%sbit or higher PHP required." : "%sbit ou PHP supérieur est requis.",
+    "%sbit or higher PHP required." : "PHP %sbits ou supérieur est requis.",
     "Following databases are supported: %s" : "Les bases de données suivantes sont supportées : %s",
     "The command line tool %s could not be found" : "La commande %s est introuvable",
     "The library %s is not available." : "La librairie %s n'est pas disponible.",
-    "Library %s with a version higher than %s is required - available version %s." : "La librairie %s doit être au moins à la version %s. Version disponible : %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "La librairie %s doit avoir une version antérieure à %s. Version disponible : %s.",
+    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "La librairie %1$s doit être au moins à la version %2$s. Version disponible : %3$s.",
+    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "La librairie %1$s doit avoir une version antérieure à %2$s. Version disponible : %3$s.",
     "Following platforms are supported: %s" : "Les plateformes suivantes sont prises en charge : %s",
     "Server version %s or higher is required." : "Un serveur de version %s ou supérieure est requis.",
     "Server version %s or lower is required." : "Un serveur de version %s ou inférieure est requis.",
+    "Logged in user must be an admin" : "L'utilisateur connecté doit être un administrateur",
     "Unknown filetype" : "Type de fichier inconnu",
     "Invalid image" : "Image non valable",
     "Avatar image is not square" : "L'image d'avatar n'est pas carré",
     "today" : "aujourd'hui",
+    "tomorrow" : "demain",
     "yesterday" : "hier",
+    "_in %n day_::_in %n days_" : ["dans %n jour","dans %n jours"],
     "_%n day ago_::_%n days ago_" : ["il y a %n jour","il y a %n jours"],
+    "next month" : "mois suivant",
     "last month" : "le mois dernier",
+    "_in %n month_::_in %n months_" : ["dans %n mois","dans %n mois"],
     "_%n month ago_::_%n months ago_" : ["Il y a %n mois","Il y a %n mois"],
+    "next year" : "année suivante",
     "last year" : "l'année dernière",
+    "_in %n year_::_in %n years_" : ["dans %n an","dans %n ans"],
     "_%n year ago_::_%n years ago_" : ["il y a %n an","il y a %n ans"],
+    "_in %n hour_::_in %n hours_" : ["dans %n heure","dans %n heures"],
     "_%n hour ago_::_%n hours ago_" : ["Il y a %n heure","Il y a %n heures"],
+    "_in %n minute_::_in %n minutes_" : ["dans %n minute","dans %n minutes"],
     "_%n minute ago_::_%n minutes ago_" : ["il y a %n minute","il y a %n minutes"],
+    "in a few seconds" : "dans quelques secondes",
     "seconds ago" : "il y a quelques secondes",
-    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Le module avec l'id: %s n'existe pas. Merci de l'activer dans les paramètres d'applications ou de contacter votre administrateur.",
+    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Le module avec l'ID: %s n'existe pas. Merci de l'activer dans les paramètres d'applications ou de contacter votre administrateur.",
     "File name is a reserved word" : "Ce nom de fichier est un mot réservé",
     "File name contains at least one invalid character" : "Le nom de fichier contient un (des) caractère(s) non valide(s)",
     "File name is too long" : "Nom de fichier trop long",
     "Dot files are not allowed" : "Le nom de fichier ne peut pas commencer par un point",
     "Empty filename is not allowed" : "Le nom de fichier ne peut pas être vide",
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Server settings" : "Paramètres serveur",
+    "App \"%s\" cannot be installed because appinfo file cannot be read." : "L'application \"%s\" ne peut pas être installée car le fichier appinfo ne peut pas être lu.",
+    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "L'application \"%s\" ne peut être installée car elle n'est pas compatible avec cette version du serveur",
+    "__language_name__" : "Français",
+    "This is an automatically sent email, please do not reply." : "Ceci est un e-mail envoyé automatiquement, veuillez ne pas y répondre.",
+    "Help" : "Aide",
+    "Apps" : "Applications",
+    "Settings" : "Paramètres",
+    "Log out" : "Se déconnecter",
+    "Users" : "Utilisateurs",
+    "Unknown user" : "Utilisateur inconnu",
+    "Create" : "Créer",
+    "Change" : "Modifier",
+    "Delete" : "Supprimer",
+    "Share" : "Partager",
+    "Overview" : "Vue d'ensemble",
+    "Basic settings" : "Paramètres de base",
     "Sharing" : "Partage",
-    "Encryption" : "Chiffrement",
+    "Security" : "Sécurité",
+    "Groupware" : "Travail collaboratif",
     "Additional settings" : "Paramètres supplémentaires",
-    "Tips & tricks" : "Trucs et astuces",
+    "Personal info" : "Informations personnelles",
+    "Mobile & desktop" : "Mobile & bureau",
+    "Unlimited" : "Illimité",
+    "Verifying" : "Vérification en cours",
+    "Verifying …" : "Vérification en cours...",
+    "Verify" : "Vérifié",
     "%s enter the database username and name." : "%s entrez le nom d'utilisateur et le nom de la base de données.",
     "%s enter the database username." : "%s entrez le nom d'utilisateur de la base de données.",
     "%s enter the database name." : "%s entrez le nom de la base de données.",
     "%s you may not use dots in the database name" : "%s vous ne pouvez pas utiliser de points dans le nom de la base de données",
     "Oracle connection could not be established" : "La connexion Oracle ne peut être établie",
     "Oracle username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base Oracle non valide(s)",
-    "DB Error: \"%s\"" : "Erreur de la base de données : \"%s\"",
-    "Offending command was: \"%s\"" : "La requête en cause est : \"%s\"",
-    "You need to enter either an existing account or the administrator." : "Vous devez spécifier le nom d'un compte existant, ou celui de l'administrateur.",
-    "Offending command was: \"%s\", name: %s, password: %s" : "La requête en cause est : \"%s\", nom : %s, mot de passe : %s",
     "PostgreSQL username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base PostgreSQL non valide(s)",
+    "You need to enter details of an existing account." : "Vous devez indiquer les détails d'un compte existant.",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X n'est pas pris en charge et %s ne fonctionnera pas correctement sur cette plate-forme. Son utilisation est à vos risques et périls !",
     "For the best results, please consider using a GNU/Linux server instead." : "Pour obtenir les meilleurs résultats, vous devriez utiliser un serveur GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Il semble que cette instance %s fonctionne sur un environnement PHP 32-bit et open_basedir a été configuré dans php.ini. Cela engendre des problèmes avec les fichiers de taille supérieure à 4 Go et est donc fortement déconseillé.",
@@ -68,41 +100,45 @@ OC.L10N.register(
     "Set an admin password." : "Spécifiez un mot de passe pour l'administrateur.",
     "Can't create or write into the data directory %s" : "Impossible de créer, ou d'écrire dans, le répertoire des données %s",
     "Invalid Federated Cloud ID" : "ID Federated Cloud incorrect",
-    "%s shared »%s« with you" : "%s a partagé «%s» avec vous",
-    "%s via %s" : "%s via %s",
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Le partage de %s a échoué car l’infrastructure n'autorise pas les partages de type %i",
     "Sharing %s failed, because the file does not exist" : "Le partage de %s a échoué car le fichier n'existe pas",
     "You are not allowed to share %s" : "Vous n'êtes pas autorisé à partager %s",
     "Sharing %s failed, because you can not share with yourself" : "Le partage de %s a échoué car vous ne pouvez pas partager avec vous-même",
-    "Sharing %s failed, because the user %s does not exist" : "Le partage de %s a échoué car l'utilisateur %s n'existe pas",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Le partage de %s a échoué car l'utilisateur %s n'est membre d'aucun groupe auquel %s appartient",
-    "Sharing %s failed, because this item is already shared with %s" : "Le partage de %s a échoué car cet objet est déjà partagé avec %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "Le partage de %s a échoué car cet élément est déjà partagé avec l'utilisateur %s",
-    "Sharing %s failed, because the group %s does not exist" : "Le partage de %s a échoué car le groupe %s n'existe pas",
-    "Sharing %s failed, because %s is not a member of the group %s" : "Le partage de %s a échoué car %s n'est pas membre du groupe %s",
+    "Sharing %1$s failed, because the user %2$s does not exist" : "Le partage de %1$s a échoué car l'utilisateur %2$s n'existe pas",
+    "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "Le partage de %1$s a échoué car l'utilisateur %2$s n'est membre d'aucun groupe auquel %3$s appartient",
+    "Sharing %1$s failed, because this item is already shared with %2$s" : "Le partage de %1$s a échoué car cet élément est déjà partagé avec %2$s",
+    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Le partage de %1$s a échoué car cet élément est déjà partagé avec l'utilisateur %2$s",
+    "Sharing %1$s failed, because the group %2$s does not exist" : "Le partage de %1$s a échoué car le groupe %2$s n'existe pas",
+    "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "Le partage de %1$s a échoué car %2$s n'est pas membre du groupe %3$s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Vous devez fournir un mot de passe pour créer un lien public, seuls les liens protégés sont autorisées.",
     "Sharing %s failed, because sharing with links is not allowed" : "Le partage de %s a échoué car le partage par lien n'est pas permis",
     "Not allowed to create a federated share with the same user" : "Non autorisé à créer un partage fédéré avec le même utilisateur",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Le partage de %s a échoué : impossible de trouver %s. Peut-être le serveur est-il momentanément injoignable.",
-    "Share type %s is not valid for %s" : "Le type de partage %s n'est pas valide pour %s",
-    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Le réglage des permissions pour %s a échoué car les permissions dépassent celles accordées à %s",
-    "Setting permissions for %s failed, because the item was not found" : "Le réglage des permissions pour %s a échoué car l'objet n'a pas été trouvé",
+    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Le partage de %1$s a échoué : impossible de trouver %2$s. Le serveur est peut-être momentanément injoignable.",
+    "Share type %1$s is not valid for %2$s" : "Le type de partage %1$s n'est pas valide pour %2$s",
     "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Impossible de configurer la date d'expiration. Un partage ne peut expirer plus de %s après sa création",
     "Cannot set expiration date. Expiration date is in the past" : "Impossible de configurer la date d'expiration : elle est dans le passé.",
-    "Cannot clear expiration date. Shares are required to have an expiration date." : "Impossible de supprimer la date d'expiration. Les partages doivent avoir une date d'expiration.",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Le service de partage %s doit implémenter l'interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "Service de partage %s non trouvé",
     "Sharing backend for %s not found" : "Le service de partage pour %s est introuvable",
     "Sharing failed, because the user %s is the original sharer" : "Le partage a échoué car l'utilisateur %s est le propriétaire original",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Le partage de %s a échoué car les permissions dépassent celles accordées à %s",
+    "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "Le partage de %1$s a échoué car les permissions dépassent celles accordées à %2$s",
     "Sharing %s failed, because resharing is not allowed" : "Le partage de %s a échoué car le repartage n'est pas autorisé",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Le partage de %s a échoué car le service %s n'a pas trouvé sa source..",
+    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Le partage de %1$s a échoué car le service %2$s n'a pas trouvé sa source..",
     "Sharing %s failed, because the file could not be found in the file cache" : "Le partage de %s a échoué car le fichier n'a pas été trouvé dans les fichiers mis en cache.",
-    "Cannot increase permissions of %s" : "Impossible d'augmenter les permissions de %s",
-    "Files can't be shared with delete permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de suppression",
-    "Files can't be shared with create permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de création",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$sa partagé \"%2$s\" avec vous et veut ajouter :",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$sa partagé \"%2$s\" avec vous et veut ajouter",
+    "»%s« added a note to a file shared with you" : "\"%s\" a ajouté une note à un fichier partagé avec vous",
+    "Open »%s«" : "Ouvrir «%s»",
+    "%1$s via %2$s" : "%1$s via %2$s",
+    "Can’t increase permissions of %s" : "Impossible d'augmenter les permissions de %s",
+    "Files can’t be shared with delete permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de suppression",
+    "Files can’t be shared with create permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de création",
     "Expiration date is in the past" : "La date d'expiration est dans le passé",
-    "Cannot set expiration date more than %s days in the future" : "Impossible de définir la date d'expiration à plus de %s jours dans le futur",
+    "Can’t set expiration date more than %s days in the future" : "Impossible de définir la date d'expiration à plus de %s jours dans le futur",
+    "%1$s shared »%2$s« with you" : "%1$s a partagé «%2$s» avec vous",
+    "%1$s shared »%2$s« with you." : "%1$s a partagé «%2$s» avec vous.",
+    "Click the button below to open it." : "Cliquez sur le bouton ci-dessous pour l'ouvrir",
+    "The requested share does not exist anymore" : "Le partage demandé n'existe plus",
     "Could not find category \"%s\"" : "Impossible de trouver la catégorie \"%s\"",
     "Sunday" : "Dimanche",
     "Monday" : "Lundi",
@@ -149,37 +185,29 @@ OC.L10N.register(
     "Oct." : "Oct.",
     "Nov." : "Nov.",
     "Dec." : "Déc.",
-    "Apps" : "Applications",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Seuls les caractères suivants sont autorisés dans un nom d'utilisateur : \"a-z\", \"A-Z\", \"0-9\", \"_@-\" et \".\" (le point)",
     "A valid username must be provided" : "Un nom d'utilisateur valide doit être saisi",
     "Username contains whitespace at the beginning or at the end" : "Le nom d'utilisateur contient des espaces au début ou à la fin",
+    "Username must not consist of dots only" : "Le nom d'utilisateur ne doit pas être composé uniquement de points",
     "A valid password must be provided" : "Un mot de passe valide doit être saisi",
     "The username is already being used" : "Ce nom d'utilisateur est déjà utilisé",
-    "Login canceled by app" : "L'authentification a été annulé par l'application",
+    "Could not create user" : "Impossible de créer l'utilisateur",
     "User disabled" : "Utilisateur désactivé",
-    "Help" : "Aide",
-    "Personal" : "Personnel",
-    "Users" : "Utilisateurs",
-    "Admin" : "Administration",
-    "App \"%s\" cannot be installed because appinfo file cannot be read." : "L'application \"%s\" ne peut pas être installée car le fichier appinfo ne peut pas être lu.",
-    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "L'application \"%s\" ne peut être installée car elle n'est pas compatible avec cette version du serveur",
-    "No app name specified" : "Aucun nom d'application spécifié",
-    "App '%s' could not be installed!" : "L'application \"%s\" ne peut pas être installée !",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "L'application \"%s\" ne peut pas être installée à cause des dépendances suivantes non satisfaites : %s",
+    "Login canceled by app" : "L'authentification a été annulé par l'application",
+    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "L'application \"%1$s\" ne peut pas être installée à cause des dépendances suivantes non satisfaites : %2$s",
     "a safe home for all your data" : "un endroit sûr pour toutes vos données",
     "File is currently busy, please try again later" : "Le fichier est actuellement utilisé, veuillez réessayer plus tard",
     "Can't read file" : "Impossible de lire le fichier",
     "Application is not enabled" : "L'application n'est pas activée",
     "Authentication error" : "Erreur d'authentification",
     "Token expired. Please reload page." : "La session a expiré. Veuillez recharger la page.",
-    "Unknown user" : "Utilisateur inconnu",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Aucun pilote de base de données n’est installé (sqlite, mysql ou postgresql).",
     "Cannot write into \"config\" directory" : "Impossible d’écrire dans le répertoire \"config\"",
     "Cannot write into \"apps\" directory" : "Impossible d’écrire dans le répertoire \"apps\"",
-    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Ce problème est généralement résolu %sen donnant au serveur web un accès en écriture au répertoire apps%s ou en désactivant l'appstore dans le fichier de configuration.",
-    "Cannot create \"data\" directory (%s)" : "Impossible de créer le répertoire \"data\" (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Ce problème est généralement résolu <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">en donnant au serveur web un accès en écriture au répertoire racine</a>.",
-    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Le problème de permissions peut généralement être résolu %sen donnant au serveur web un accès en écriture au répertoire racine%s",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire \"apps\" ou en désactivant l'appstore dans le fichier de configuration. Voir %s",
+    "Cannot create \"data\" directory" : "Impossible de créer le dossier \"data\"",
+    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire racine. Voir %s",
+    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Le problème de permissions peut généralement être résolu en donnant au serveur web un accès en écriture au répertoire racine. Voir %s.",
     "Setting locale to %s failed" : "Echec de la spécification des paramètres régionaux à %s",
     "Please install one of these locales on your system and restart your webserver." : "Veuillez installer l'un de ces paramètres régionaux sur votre système et redémarrer votre serveur web.",
     "Please ask your server administrator to install the module." : "Veuillez demander à votre administrateur d’installer le module.",
@@ -197,45 +225,57 @@ OC.L10N.register(
     "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requis",
     "Please upgrade your database version" : "Veuillez mettre à jour votre gestionnaire de base de données",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Veuillez changer les permissions du répertoire en mode 0770 afin que son contenu ne puisse pas être listé par les autres utilisateurs.",
-    "Data directory (%s) is readable by other users" : "Le répertoire de données (%s) est lisible par les autres utilisateurs",
-    "Data directory (%s) must be an absolute path" : "Le chemin du dossier de données (%s) doit être absolu",
+    "Your data directory is readable by other users" : "Votre répertoire est lisible par les autres utilisateurs",
+    "Your data directory must be an absolute path" : "Le chemin de votre répertoire doit être un lien absolu",
     "Check the value of \"datadirectory\" in your configuration" : "Verifiez la valeur de \"datadirectory\" dans votre configuration",
-    "Data directory (%s) is invalid" : "Le répertoire (%s) n'est pas valide",
-    "Please check that the data directory contains a file \".ocdata\" in its root." : "Veuillez vérifier que le répertoire de données contient un fichier \".ocdata\" à sa racine.",
+    "Your data directory is invalid" : "Votre répertoire n'est pas valide",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Assurez-vous que le répertoire de données contient un fichier \".ocdata\" à sa racine.",
+    "Action \"%s\" not supported or implemented." : "Action \"%s\" non supportée ou implémentée.",
+    "Authentication failed, wrong token or provider ID given" : "Échec de l'authentification, jeton erroné ou identification du fournisseur donnée",
+    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Paramètres manquants pour compléter la requête. Paramètres manquants : \"%s\"",
+    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "L'identifiant \"%1$s\" est déjà utilisé par le fournisseur de cloud \"%2$s\"",
+    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Le fournisseur de cloud avec l'identifiant \"%s\" n'existe pas.",
     "Could not obtain lock type %d on \"%s\"." : "Impossible d'obtenir le verrouillage de type %d sur \"%s\".",
     "Storage unauthorized. %s" : "Espace de stockage non autorisé. %s",
     "Storage incomplete configuration. %s" : "Configuration de l'espace de stockage incomplète. %s",
     "Storage connection error. %s" : "Erreur de connexion à l'espace stockage. %s",
     "Storage is temporarily not available" : "Le support de stockage est temporairement indisponible",
     "Storage connection timeout. %s" : "Le délai d'attente pour la connexion à l'espace de stockage a été dépassé. %s",
-    "4-byte characters are not supported in file names" : "Les caractères sur 4 octets ne sont pas pris en charge dans les noms de fichiers",
-    "App directory already exists" : "Le dossier de l'application existe déjà",
-    "Can't create app folder. Please fix permissions. %s" : "Impossible de créer le dossier de l'application. Corrigez les droits d'accès. %s",
-    "Archive does not contain a directory named %s" : "Le fichier archive ne contient pas de répertoire %s",
-    "No source specified when installing app" : "Aucune source spécifiée pour installer l'application",
-    "No href specified when installing app from http" : "Aucun href spécifié pour installer l'application par http",
-    "No path specified when installing app from local file" : "Aucun chemin spécifié pour installer l'application depuis un fichier local",
-    "Archives of type %s are not supported" : "Les archives de type %s ne sont pas prises en charge",
-    "Failed to open archive when installing app" : "Échec de l'ouverture de l'archive lors de l'installation de l'application",
-    "App does not provide an info.xml file" : "L'application ne fournit pas de fichier info.xml",
-    "App cannot be installed because appinfo file cannot be read." : "L'application ne peut pas être installée car le fichier appinfo ne peut pas être lu.",
-    "Signature could not get checked. Please contact the app developer and check your admin screen." : "La signature n'a pas pu être vérifiée. Merci de contacter le développeur de l'application et de vérifier votre page d'administration.",
-    "App can't be installed because of not allowed code in the App" : "L'application ne peut être installée car elle contient du code non-autorisé",
-    "App can't be installed because it is not compatible with this version of the server" : "L'application ne peut être installée car elle n'est pas compatible avec cette version du serveur",
-    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "L'application ne peut être installée car elle contient la balise <shipped>true</shipped> qui n'est pas autorisée pour les applications non incluses par défaut",
-    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "L'App ne peut pas être installé car la version dans info.xml diffère de la version signalée par l' app store",
-    "Logging" : "Connexion",
-    "Recommended" : "Recommandée",
-    "Microsoft Windows Platform is not supported" : "La plate-forme Microsoft Windows n'est pas prise en charge.",
-    "Running Nextcloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself." : "L'exécution de Nextcloud Server sur une plateforme Microsoft Windows n'est pas supportée. Nous suggérons d'utilier un serveur Linux dans une machine virtuelle si vous n'avez pas la possibilité de migrer le serveur lui-même.",
-    "Storage not available" : "Support de stockage non disponible",
-    "ownCloud %s or higher is required." : "Nextcloud %s ou supérieur est requis.",
-    "ownCloud %s or lower is required." : "Nextcloud %s ou inférieur est requis.",
-    "App \"%s\" cannot be installed because it is not compatible with this version of Nextcloud." : "L'application \"%s\" ne peut être installée car elle n'est pas compatible avec cette version de Nextcloud.",
-    "App can't be installed because it is not compatible with this version of Nextcloud" : "L'application ne peut être installée car elle n'est pas compatible avec cette version de Nextcloud",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "L'application ne peut être installée car la version dans info.xml/version n'est pas la même que la version signalée sur l'app store",
-    "Hint: You can speed up the upgrade by executing this SQL command manually: ALTER TABLE %s ADD COLUMN checksum varchar(255) DEFAULT NULL AFTER permissions;" : "Aide : Vous pouvez accélérer la mise à jour en exécutant manuellement la commande SQL suivante : ALTER TABLE %s ADD COLUMN checksum varchar(255) DEFAULT NULL AFTER permissions;",
-    "Running Nextcloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Exécuter Nextcloud Server sur une plateforme Microsoft Windows n'est pas supporté. Nous vous suggérons d'utiliser un serveur Linux dans une machine virtuelle si vous n'avez pas l'option de migrer votre serveur. Trouver les paquets Linux aussi facilement que de déployer une image de machine virtuelle sur <a href=\"%s\">%s</a>. Pour migrer vos installations existantes sur Linux, vous pouvez trouver plein d'astuces et un script de migration sur  <a href=\"%s\">notre documentation</a>.",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Ce problème est généralement résolu en <a href=\"%s\" target=\"_blank\">donnant les accès en écriture dans le répertoire root</a>."
+    "Library %s with a version higher than %s is required - available version %s." : "La librairie %s doit être au moins à la version %s. Version disponible : %s.",
+    "Library %s with a version lower than %s is required - available version %s." : "La librairie %s doit avoir une version antérieure à %s. Version disponible : %s.",
+    "Personal" : "Personnel",
+    "Admin" : "Administration",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Encryption" : "Chiffrement",
+    "Tips & tricks" : "Trucs et astuces",
+    "DB Error: \"%s\"" : "Erreur de la base de données : \"%s\"",
+    "Offending command was: \"%s\"" : "La requête en cause est : \"%s\"",
+    "Offending command was: \"%s\", name: %s, password: %s" : "La requête en cause est : \"%s\", nom : %s, mot de passe : %s",
+    "Sharing %s failed, because the user %s does not exist" : "Le partage de %s a échoué car l'utilisateur %s n'existe pas",
+    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Le partage de %s a échoué car l'utilisateur %s n'est membre d'aucun groupe auquel %s appartient",
+    "Sharing %s failed, because this item is already shared with %s" : "Le partage de %s a échoué car cet objet est déjà partagé avec %s",
+    "Sharing %s failed, because this item is already shared with user %s" : "Le partage de %s a échoué car cet élément est déjà partagé avec l'utilisateur %s",
+    "Sharing %s failed, because the group %s does not exist" : "Le partage de %s a échoué car le groupe %s n'existe pas",
+    "Sharing %s failed, because %s is not a member of the group %s" : "Le partage de %s a échoué car %s n'est pas membre du groupe %s",
+    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Le partage de %s a échoué : impossible de trouver %s. Peut-être le serveur est-il momentanément injoignable.",
+    "Share type %s is not valid for %s" : "Le type de partage %s n'est pas valide pour %s",
+    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Le réglage des permissions pour %s a échoué car les permissions dépassent celles accordées à %s",
+    "Setting permissions for %s failed, because the item was not found" : "Le réglage des permissions pour %s a échoué car l'objet n'a pas été trouvé",
+    "Cannot clear expiration date. Shares are required to have an expiration date." : "Impossible de supprimer la date d'expiration. Les partages doivent avoir une date d'expiration.",
+    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Le partage de %s a échoué car les permissions dépassent celles accordées à %s",
+    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Le partage de %s a échoué car le service %s n'a pas trouvé sa source..",
+    "Cannot increase permissions of %s" : "Impossible d'augmenter les permissions de %s",
+    "Files can't be shared with delete permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de suppression",
+    "Files can't be shared with create permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de création",
+    "Cannot set expiration date more than %s days in the future" : "Impossible de définir la date d'expiration à plus de %s jours dans le futur",
+    "%s shared »%s« with you" : "%s a partagé «%s» avec vous",
+    "%s shared »%s« with you." : "%s a partagé «%s» avec vous.",
+    "%s via %s" : "%s via %s",
+    "No app name specified" : "Aucun nom d'application spécifié",
+    "App '%s' could not be installed!" : "L'application \"%s\" ne peut pas être installée !",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "L'application \"%s\" ne peut pas être installée à cause des dépendances suivantes non satisfaites : %s",
+    "Sync clients" : "Clients de synchronisation",
+    "ID \"%s\" already used by cloud federation provider \"%s\"" : "L'identifiant \"%s\" est déjà utilisé par le fournisseur de cloud \"%s\""
 },
 "nplurals=2; plural=(n > 1);");
