@@ -10,28 +10,32 @@
  * @author Birk Borkason <daniel.niccoli@gmail.com>
  * @author Björn Schießle <bjoern@schiessle.org>
  * @author Brice Maron <brice@bmaron.net>
- * @author Christopher Schäpers <kondou@ts.unde.re>
  * @author Christoph Wurst <christoph@owncloud.com>
+ * @author Christopher Schäpers <kondou@ts.unde.re>
  * @author Clark Tomlinson <fallen013@gmail.com>
  * @author cmeh <cmeh@users.noreply.github.com>
- * @author Felix Anand Epp <work@felixepp.de>
+ * @author Felix Epp <work@felixepp.de>
  * @author Florin Peter <github@florin-peter.de>
  * @author Frank Karlitschek <frank@karlitschek.de>
- * @author Georg Ehrke <georg@owncloud.com>
+ * @author Georg Ehrke <oc.list@georgehrke.com>
  * @author helix84 <helix84@centrum.sk>
+ * @author Ilja Neumann <ineumann@owncloud.com>
  * @author Individual IT Services <info@individual-it.net>
  * @author Jakob Sack <mail@jakobsack.de>
  * @author Joas Schilling <coding@schilljs.com>
  * @author Jörn Friedrich Dreyer <jfd@butonic.de>
+ * @author Kawohl <john@owncloud.com>
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Markus Goetz <markus@woboq.com>
  * @author Martin Mattel <martin.mattel@diemattels.at>
  * @author Marvin Thomas Rabe <mrabe@marvinrabe.de>
  * @author Michael Gapczynski <GapczynskiM@gmail.com>
  * @author Morris Jobke <hey@morrisjobke.de>
+ * @author rakekniven <mark.ziegler@rakekniven.de>
  * @author Robin Appelman <robin@icewind.nl>
  * @author Robin McCorkell <robin@mccorkell.me.uk>
  * @author Roeland Jago Douma <roeland@famdouma.nl>
+ * @author Sebastian Wessalowski <sebastian@wessalowski.org>
  * @author Stefan Rado <owncloud@sradonia.net>
  * @author Stefan Weil <sw@weilnetz.de>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
@@ -58,7 +62,9 @@
 
 use OCP\IConfig;
 use OCP\IGroupManager;
+use OCP\ILogger;
 use OCP\IUser;
+use OC\AppFramework\Http\Request;
 
 class OC_Util {
 	public static $scripts = array();
@@ -91,11 +97,12 @@ class OC_Util {
 	 * TODO make home storage aware of this and use the object storage instead of local disk access
 	 *
 	 * @param array $config containing 'class' and optional 'arguments'
+	 * @suppress PhanDeprecatedFunction
 	 */
 	private static function initObjectStoreRootFS($config) {
 		// check misconfiguration
 		if (empty($config['class'])) {
-			\OCP\Util::writeLog('files', 'No class given for objectstore', \OCP\Util::ERROR);
+			\OCP\Util::writeLog('files', 'No class given for objectstore', ILogger::ERROR);
 		}
 		if (!isset($config['arguments'])) {
 			$config['arguments'] = array();
@@ -124,11 +131,12 @@ class OC_Util {
 	 * necessity of a data folder being present.
 	 *
 	 * @param array $config containing 'class' and optional 'arguments'
+	 * @suppress PhanDeprecatedFunction
 	 */
 	private static function initObjectStoreMultibucketRootFS($config) {
 		// check misconfiguration
 		if (empty($config['class'])) {
-			\OCP\Util::writeLog('files', 'No class given for objectstore', \OCP\Util::ERROR);
+			\OCP\Util::writeLog('files', 'No class given for objectstore', ILogger::ERROR);
 		}
 		if (!isset($config['arguments'])) {
 			$config['arguments'] = array();
@@ -165,6 +173,8 @@ class OC_Util {
 	 * @param string $user
 	 * @return boolean
 	 * @description configure the initial filesystem based on the configuration
+	 * @suppress PhanDeprecatedFunction
+	 * @suppress PhanAccessMethodInternal
 	 */
 	public static function setupFS($user = '') {
 		//setting up the filesystem twice can only lead to trouble
@@ -202,7 +212,7 @@ class OC_Util {
 			return $storage;
 		});
 
-		\OC\Files\Filesystem::addStorageWrapper('enable_sharing', function ($mountPoint, \OCP\Files\Storage $storage, \OCP\Files\Mount\IMountPoint $mount) {
+		\OC\Files\Filesystem::addStorageWrapper('enable_sharing', function ($mountPoint, \OCP\Files\Storage\IStorage $storage, \OCP\Files\Mount\IMountPoint $mount) {
 			if (!$mount->getOption('enable_sharing', true)) {
 				return new \OC\Files\Storage\Wrapper\PermissionsMask([
 					'storage' => $storage,
@@ -213,7 +223,7 @@ class OC_Util {
 		});
 
 		// install storage availability wrapper, before most other wrappers
-		\OC\Files\Filesystem::addStorageWrapper('oc_availability', function ($mountPoint, $storage) {
+		\OC\Files\Filesystem::addStorageWrapper('oc_availability', function ($mountPoint, \OCP\Files\Storage\IStorage $storage) {
 			if (!$storage->instanceOfStorage('\OCA\Files_Sharing\SharedStorage') && !$storage->isLocal()) {
 				return new \OC\Files\Storage\Wrapper\Availability(['storage' => $storage]);
 			}
@@ -250,6 +260,23 @@ class OC_Util {
 			return $storage;
 		});
 
+		\OC\Files\Filesystem::addStorageWrapper('readonly', function ($mountPoint, \OCP\Files\Storage\IStorage $storage, \OCP\Files\Mount\IMountPoint $mount) {
+			/*
+			 * Do not allow any operations that modify the storage
+			 */
+			if ($mount->getOption('readonly', false)) {
+				return new \OC\Files\Storage\Wrapper\PermissionsMask([
+					'storage' => $storage,
+					'mask' => \OCP\Constants::PERMISSION_ALL & ~(
+						\OCP\Constants::PERMISSION_UPDATE |
+						\OCP\Constants::PERMISSION_CREATE |
+						\OCP\Constants::PERMISSION_DELETE
+					),
+				]);
+			}
+			return $storage;
+		});
+
 		OC_Hook::emit('OC_Filesystem', 'preSetup', array('user' => $user));
 		\OC\Files\Filesystem::logWarningWhenAddingStorageWrapper(true);
 
@@ -266,7 +293,7 @@ class OC_Util {
 			self::initLocalStorageRootFS();
 		}
 
-		if ($user != '' && !OCP\User::userExists($user)) {
+		if ($user != '' && !\OC::$server->getUserManager()->userExists($user)) {
 			\OC::$server->getEventLogger()->end('setup_fs');
 			return false;
 		}
@@ -289,11 +316,11 @@ class OC_Util {
 	 * check if a password is required for each public link
 	 *
 	 * @return boolean
+	 * @suppress PhanDeprecatedFunction
 	 */
 	public static function isPublicLinkPasswordRequired() {
-		$appConfig = \OC::$server->getAppConfig();
-		$enforcePassword = $appConfig->getValue('core', 'shareapi_enforce_links_password', 'no');
-		return ($enforcePassword === 'yes') ? true : false;
+		$enforcePassword = \OC::$server->getConfig()->getAppValue('core', 'shareapi_enforce_links_password', 'no');
+		return $enforcePassword === 'yes';
 	}
 
 	/**
@@ -329,13 +356,14 @@ class OC_Util {
 	 * check if share API enforces a default expire date
 	 *
 	 * @return boolean
+	 * @suppress PhanDeprecatedFunction
 	 */
 	public static function isDefaultExpireDateEnforced() {
-		$isDefaultExpireDateEnabled = \OCP\Config::getAppValue('core', 'shareapi_default_expire_date', 'no');
+		$isDefaultExpireDateEnabled = \OC::$server->getConfig()->getAppValue('core', 'shareapi_default_expire_date', 'no');
 		$enforceDefaultExpireDate = false;
 		if ($isDefaultExpireDateEnabled === 'yes') {
-			$value = \OCP\Config::getAppValue('core', 'shareapi_enforce_expire_date', 'no');
-			$enforceDefaultExpireDate = ($value === 'yes') ? true : false;
+			$value = \OC::$server->getConfig()->getAppValue('core', 'shareapi_enforce_expire_date', 'no');
+			$enforceDefaultExpireDate = $value === 'yes';
 		}
 
 		return $enforceDefaultExpireDate;
@@ -345,7 +373,7 @@ class OC_Util {
 	 * Get the quota of a user
 	 *
 	 * @param string $userId
-	 * @return int Quota bytes
+	 * @return float Quota bytes
 	 */
 	public static function getUserQuota($userId) {
 		$user = \OC::$server->getUserManager()->get($userId);
@@ -365,10 +393,27 @@ class OC_Util {
 	 * @param String $userId
 	 * @param \OCP\Files\Folder $userDirectory
 	 * @throws \RuntimeException
+	 * @suppress PhanDeprecatedFunction
 	 */
 	public static function copySkeleton($userId, \OCP\Files\Folder $userDirectory) {
 
-		$skeletonDirectory = \OC::$server->getConfig()->getSystemValue('skeletondirectory', \OC::$SERVERROOT . '/core/skeleton');
+		$plainSkeletonDirectory = \OC::$server->getConfig()->getSystemValue('skeletondirectory', \OC::$SERVERROOT . '/core/skeleton');
+		$userLang = \OC::$server->getL10NFactory()->findLanguage();
+		$skeletonDirectory = str_replace('{lang}', $userLang, $plainSkeletonDirectory);
+
+		if (!file_exists($skeletonDirectory)) {
+			$dialectStart = strpos($userLang, '_');
+			if ($dialectStart !== false) {
+				$skeletonDirectory = str_replace('{lang}', substr($userLang, 0, $dialectStart), $plainSkeletonDirectory);
+			}
+			if ($dialectStart === false || !file_exists($skeletonDirectory)) {
+				$skeletonDirectory = str_replace('{lang}', 'default', $plainSkeletonDirectory);
+			}
+			if (!file_exists($skeletonDirectory)) {
+				$skeletonDirectory = '';
+			}
+		}
+
 		$instanceId = \OC::$server->getConfig()->getSystemValue('instanceid', '');
 
 		if ($instanceId === null) {
@@ -383,7 +428,7 @@ class OC_Util {
 			\OCP\Util::writeLog(
 				'files_skeleton',
 				'copying skeleton for '.$userId.' from '.$skeletonDirectory.' to '.$userDirectory->getFullPath('/'),
-				\OCP\Util::DEBUG
+				ILogger::DEBUG
 			);
 			self::copyr($skeletonDirectory, $userDirectory);
 			// update the file cache
@@ -431,6 +476,7 @@ class OC_Util {
 
 	/**
 	 * @return void
+	 * @suppress PhanUndeclaredMethod
 	 */
 	public static function tearDownFS() {
 		\OC\Files\Filesystem::tearDown();
@@ -487,6 +533,7 @@ class OC_Util {
 
 	/**
 	 * @description load the version.php into the session as cache
+	 * @suppress PhanUndeclaredVariable
 	 */
 	private static function loadVersion() {
 		if (self::$versionCache !== null) {
@@ -563,8 +610,8 @@ class OC_Util {
 	 * add a translation JS file
 	 *
 	 * @param string $application application id
-	 * @param string $languageCode language code, defaults to the current language
-	 * @param bool $prepend prepend the Script to the beginning of the list
+	 * @param string|null $languageCode language code, defaults to the current language
+	 * @param bool|null $prepend prepend the Script to the beginning of the list
 	 */
 	public static function addTranslations($application, $languageCode = null, $prepend = false) {
 		if (is_null($languageCode)) {
@@ -641,36 +688,20 @@ class OC_Util {
 	 * @param string $tag tag name of the element
 	 * @param array $attributes array of attributes for the element
 	 * @param string $text the text content for the element
+	 * @param bool $prepend prepend the header to the beginning of the list
 	 */
-	public static function addHeader($tag, $attributes, $text=null) {
-		self::$headers[] = array(
+	public static function addHeader($tag, $attributes, $text = null, $prepend = false) {
+		$header = array(
 			'tag' => $tag,
 			'attributes' => $attributes,
 			'text' => $text
 		);
-	}
+		if ($prepend === true) {
+			array_unshift (self::$headers, $header);
 
-	/**
-	 * formats a timestamp in the "right" way
-	 *
-	 * @param int $timestamp
-	 * @param bool $dateOnly option to omit time from the result
-	 * @param DateTimeZone|string $timeZone where the given timestamp shall be converted to
-	 * @return string timestamp
-	 *
-	 * @deprecated Use \OC::$server->query('DateTimeFormatter') instead
-	 */
-	public static function formatDate($timestamp, $dateOnly = false, $timeZone = null) {
-		if ($timeZone !== null && !$timeZone instanceof \DateTimeZone) {
-			$timeZone = new \DateTimeZone($timeZone);
+		} else {
+			self::$headers[] = $header;
 		}
-
-		/** @var \OC\DateTimeFormatter $formatter */
-		$formatter = \OC::$server->query('DateTimeFormatter');
-		if ($dateOnly) {
-			return $formatter->formatDate($timestamp, 'long', $timeZone);
-		}
-		return $formatter->formatDateTime($timestamp, 'long', 'long', $timeZone);
 	}
 
 	/**
@@ -695,8 +726,15 @@ class OC_Util {
 		}
 
 		$webServerRestart = false;
-		$setup = new \OC\Setup($config, \OC::$server->getIniWrapper(), \OC::$server->getL10N('lib'),
-			\OC::$server->query(\OCP\Defaults::class), \OC::$server->getLogger(), \OC::$server->getSecureRandom());
+		$setup = new \OC\Setup(
+			$config,
+			\OC::$server->getIniWrapper(),
+			\OC::$server->getL10N('lib'),
+			\OC::$server->query(\OCP\Defaults::class),
+			\OC::$server->getLogger(),
+			\OC::$server->getSecureRandom(),
+			\OC::$server->query(\OC\Installer::class)
+		);
 
 		$urlGenerator = \OC::$server->getURLGenerator();
 
@@ -715,7 +753,9 @@ class OC_Util {
 				$errors[] = array(
 					'error' => $l->t('Cannot write into "config" directory'),
 					'hint' => $l->t('This can usually be fixed by giving the webserver write access to the config directory. See %s',
-						[$urlGenerator->linkToDocs('admin-dir_permissions')])
+						[ $urlGenerator->linkToDocs('admin-dir_permissions') ]) . '. '
+						. $l->t('Or, if you prefer to keep config.php file read only, set the option "config_is_read_only" to true in it. See %s',
+						[ $urlGenerator->linkToDocs('admin-config') ] )
 				);
 			}
 		}
@@ -859,7 +899,7 @@ class OC_Util {
 		}
 		foreach($invalidIniSettings as $setting) {
 			if(is_bool($setting[1])) {
-				$setting[1] = ($setting[1]) ? 'on' : 'off';
+				$setting[1] = $setting[1] ? 'on' : 'off';
 			}
 			$errors[] = [
 				'error' => $l->t('PHP setting "%s" is not set to "%s".', [$setting[0], var_export($setting[1], true)]),
@@ -1071,6 +1111,7 @@ class OC_Util {
 	 * the apps visible for the current user
 	 *
 	 * @return string URL
+	 * @suppress PhanDeprecatedFunction
 	 */
 	public static function getDefaultPageUrl() {
 		$urlGenerator = \OC::$server->getURLGenerator();
@@ -1079,12 +1120,13 @@ class OC_Util {
 		if (isset($_REQUEST['redirect_url']) && strpos($_REQUEST['redirect_url'], '@') === false) {
 			$location = $urlGenerator->getAbsoluteURL(urldecode($_REQUEST['redirect_url']));
 		} else {
-			$defaultPage = \OC::$server->getAppConfig()->getValue('core', 'defaultpage');
+			$defaultPage = \OC::$server->getConfig()->getAppValue('core', 'defaultpage');
 			if ($defaultPage) {
 				$location = $urlGenerator->getAbsoluteURL($defaultPage);
 			} else {
 				$appId = 'files';
-				$defaultApps = explode(',', \OCP\Config::getSystemValue('defaultapp', 'files'));
+				$config = \OC::$server->getConfig();
+				$defaultApps = explode(',', $config->getSystemValue('defaultapp', 'files'));
 				// find the first app that is enabled for the current user
 				foreach ($defaultApps as $defaultApp) {
 					$defaultApp = OC_App::cleanAppId(strip_tags($defaultApp));
@@ -1094,7 +1136,7 @@ class OC_Util {
 					}
 				}
 
-				if(\OC::$server->getConfig()->getSystemValue('htaccess.IgnoreFrontController', false) === true || getenv('front_controller_active') === 'true') {
+				if($config->getSystemValue('htaccess.IgnoreFrontController', false) === true || getenv('front_controller_active') === 'true') {
 					$location = $urlGenerator->getAbsoluteURL('/apps/' . $appId . '/');
 				} else {
 					$location = $urlGenerator->getAbsoluteURL('/index.php/apps/' . $appId . '/');
@@ -1337,7 +1379,7 @@ class OC_Util {
 			}
 			// Zend OpCache >= 7.0.0, PHP >= 5.5.0
 			if (function_exists('opcache_invalidate')) {
-				$ret = opcache_invalidate($path);
+				$ret = @opcache_invalidate($path);
 			}
 		}
 		return $ret;
@@ -1349,6 +1391,8 @@ class OC_Util {
 	 * in case the opcode cache does not re-validate files
 	 *
 	 * @return void
+	 * @suppress PhanDeprecatedFunction
+	 * @suppress PhanUndeclaredConstant
 	 */
 	public static function clearOpcodeCache() {
 		// APC
@@ -1359,17 +1403,9 @@ class OC_Util {
 		if (function_exists('accelerator_reset')) {
 			accelerator_reset();
 		}
-		// XCache
-		if (function_exists('xcache_clear_cache')) {
-			if (\OC::$server->getIniWrapper()->getBool('xcache.admin.enable_auth')) {
-				\OCP\Util::writeLog('core', 'XCache opcode cache will not be cleared because "xcache.admin.enable_auth" is enabled.', \OCP\Util::WARN);
-			} else {
-				@xcache_clear_cache(XC_TYPE_PHP, 0);
-			}
-		}
 		// Opcache (PHP >= 5.5)
 		if (function_exists('opcache_reset')) {
-			opcache_reset();
+			@opcache_reset();
 		}
 	}
 
@@ -1393,16 +1429,6 @@ class OC_Util {
 		return $normalizedValue;
 	}
 
-	/**
-	 * @param boolean|string $file
-	 * @return string
-	 */
-	public static function basename($file) {
-		$file = rtrim($file, '/');
-		$t = explode('/', $file);
-		return array_pop($t);
-	}
-
 	/**
 	 * A human readable string is generated based on version and build number
 	 *
@@ -1495,4 +1521,17 @@ class OC_Util {
 		}
 	}
 
+	/**
+	 * is this Internet explorer ?
+	 *
+	 * @return boolean
+	 */
+	public static function isIe() {
+		if (!isset($_SERVER['HTTP_USER_AGENT'])) {
+			return false;
+		}
+
+		return preg_match(Request::USER_AGENT_IE, $_SERVER['HTTP_USER_AGENT']) === 1;
+	}
+
 }
