@@ -6,10 +6,11 @@
  * @author Bart Visscher <bartv@thisnet.nl>
  * @author Björn Schießle <bjoern@schiessle.org>
  * @author Frank Karlitschek <frank@karlitschek.de>
- * @author Georg Ehrke <georg@owncloud.com>
+ * @author Georg Ehrke <oc.list@georgehrke.com>
  * @author Individual IT Services <info@individual-it.net>
  * @author Jens-Christian Fischer <jens-christian.fischer@switch.ch>
  * @author Joas Schilling <coding@schilljs.com>
+ * @author Julius Härtl <jus@bitgrid.net>
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Michael Gapczynski <GapczynskiM@gmail.com>
  * @author Morris Jobke <hey@morrisjobke.de>
@@ -50,30 +51,43 @@
 // use OCP namespace for all classes that are considered public.
 // This means that they should be used by apps instead of the internal ownCloud classes
 namespace OCP;
-use DateTimeZone;
 
 /**
  * This class provides different helper functions to make the life of a developer easier
  * @since 4.0.0
  */
 class Util {
-	// consts for Logging
+	/**
+	 * @deprecated 14.0.0 use \OCP\ILogger::DEBUG
+	 */
 	const DEBUG=0;
+	/**
+	 * @deprecated 14.0.0 use \OCP\ILogger::INFO
+	 */
 	const INFO=1;
+	/**
+	 * @deprecated 14.0.0 use \OCP\ILogger::WARN
+	 */
 	const WARN=2;
+	/**
+	 * @deprecated 14.0.0 use \OCP\ILogger::ERROR
+	 */
 	const ERROR=3;
+	/**
+	 * @deprecated 14.0.0 use \OCP\ILogger::FATAL
+	 */
 	const FATAL=4;
 
 	/** \OCP\Share\IManager */
 	private static $shareManager;
 
 	/**
-	 * get the current installed version of ownCloud
+	 * get the current installed version of Nextcloud
 	 * @return array
 	 * @since 4.0.0
 	 */
 	public static function getVersion() {
-		return(\OC_Util::getVersion());
+		return \OC_Util::getVersion();
 	}
 	
 	/**
@@ -82,9 +96,6 @@ class Util {
 	 * @since 8.1.0
 	 */
 	public static function setChannel($channel) {
-		//Flush timestamp to reload version.php
-		\OC::$server->getSession()->set('OC_Version_Timestamp', 0);
-		\OC::$server->getAppConfig()->setValue('core', 'OC_Channel', $channel);
 		\OC::$server->getConfig()->setSystemValue('updater.release.channel', $channel);
 	}
 	
@@ -97,62 +108,13 @@ class Util {
 		return \OC_Util::getChannel();
 	}
 
-	/**
-	 * send an email
-	 * @param string $toaddress
-	 * @param string $toname
-	 * @param string $subject
-	 * @param string $mailtext
-	 * @param string $fromaddress
-	 * @param string $fromname
-	 * @param int $html
-	 * @param string $altbody
-	 * @param string $ccaddress
-	 * @param string $ccname
-	 * @param string $bcc
-	 * @deprecated 8.1.0 Use \OCP\Mail\IMailer instead
-	 * @since 4.0.0
-	 */
-	public static function sendMail($toaddress, $toname, $subject, $mailtext, $fromaddress, $fromname,
-		$html = 0, $altbody = '', $ccaddress = '', $ccname = '', $bcc = '') {
-		$mailer = \OC::$server->getMailer();
-		$message = $mailer->createMessage();
-		$message->setTo([$toaddress => $toname]);
-		$message->setSubject($subject);
-		$message->setPlainBody($mailtext);
-		$message->setFrom([$fromaddress => $fromname]);
-		if($html === 1) {
-			$message->setHTMLBody($altbody);
-		}
-
-		if($altbody === '') {
-			$message->setHTMLBody($mailtext);
-			$message->setPlainBody('');
-		} else {
-			$message->setHtmlBody($mailtext);
-			$message->setPlainBody($altbody);
-		}
-
-		if(!empty($ccaddress)) {
-			if(!empty($ccname)) {
-				$message->setCc([$ccaddress => $ccname]);
-			} else {
-				$message->setCc([$ccaddress]);
-			}
-		}
-		if(!empty($bcc)) {
-			$message->setBcc([$bcc]);
-		}
-
-		$mailer->send($message);
-	}
-
 	/**
 	 * write a message in the log
 	 * @param string $app
 	 * @param string $message
 	 * @param int $level
 	 * @since 4.0.0
+	 * @deprecated 13.0.0 use log of \OCP\ILogger
 	 */
 	public static function writeLog( $app, $message, $level ) {
 		$context = ['app' => $app];
@@ -167,7 +129,7 @@ class Util {
 	 * @since ....0.0 - parameter $level was added in 7.0.0
 	 * @deprecated 8.2.0 use logException of \OCP\ILogger
 	 */
-	public static function logException( $app, \Exception $ex, $level = \OCP\Util::FATAL ) {
+	public static function logException( $app, \Exception $ex, $level = ILogger::FATAL) {
 		\OC::$server->getLogger()->logException($ex, ['app' => $app]);
 	}
 
@@ -195,7 +157,7 @@ class Util {
 	 * get l10n object
 	 * @param string $application
 	 * @param string|null $language
-	 * @return \OC_L10N
+	 * @return \OCP\IL10N
 	 * @since 6.0.0 - parameter $language was added in 8.0.0
 	 */
 	public static function getL10N($application, $language = null) {
@@ -245,31 +207,6 @@ class Util {
 		\OC_Util::addHeader($tag, $attributes, $text);
 	}
 
-	/**
-	 * formats a timestamp in the "right" way
-	 * @param int $timestamp $timestamp
-	 * @param bool $dateOnly option to omit time from the result
-	 * @param DateTimeZone|string $timeZone where the given timestamp shall be converted to
-	 * @return string timestamp
-	 *
-	 * @deprecated 8.0.0 Use \OC::$server->query('DateTimeFormatter') instead
-	 * @since 4.0.0
-	 */
-	public static function formatDate($timestamp, $dateOnly=false, $timeZone = null) {
-		return(\OC_Util::formatDate($timestamp, $dateOnly, $timeZone));
-	}
-
-	/**
-	 * check if some encrypted files are stored
-	 * @return bool
-	 *
-	 * @deprecated 8.1.0 No longer required
-	 * @since 6.0.0
-	 */
-	public static function encryptedFiles() {
-		return false;
-	}
-
 	/**
 	 * Creates an absolute url to the given app and file.
 	 * @param string $app app
@@ -310,50 +247,13 @@ class Util {
 		return \OC_Helper::linkToPublic($service);
 	}
 
-	/**
-	 * Creates an url using a defined route
-	 * @param string $route
-	 * @param array $parameters
-	 * @internal param array $args with param=>value, will be appended to the returned url
-	 * @return string the url
-	 * @deprecated 8.1.0 Use \OC::$server->getURLGenerator()->linkToRoute($route, $parameters)
-	 * @since 5.0.0
-	 */
-	public static function linkToRoute( $route, $parameters = array() ) {
-		return \OC::$server->getURLGenerator()->linkToRoute($route, $parameters);
-	}
-
-	/**
-	 * Creates an url to the given app and file
-	 * @param string $app app
-	 * @param string $file file
-	 * @param array $args array with param=>value, will be appended to the returned url
-	 * 	The value of $args will be urlencoded
-	 * @return string the url
-	 * @deprecated 8.1.0 Use \OC::$server->getURLGenerator()->linkTo($app, $file, $args)
-	 * @since 4.0.0 - parameter $args was added in 4.5.0
-	 */
-	public static function linkTo( $app, $file, $args = array() ) {
-		return \OC::$server->getURLGenerator()->linkTo($app, $file, $args);
-	}
-
-	/**
-	 * Returns the server host, even if the website uses one or more reverse proxy
-	 * @return string the server host
-	 * @deprecated 8.1.0 Use \OCP\IRequest::getServerHost
-	 * @since 4.0.0
-	 */
-	public static function getServerHost() {
-		return \OC::$server->getRequest()->getServerHost();
-	}
-
 	/**
 	 * Returns the server host name without an eventual port number
 	 * @return string the server hostname
 	 * @since 5.0.0
 	 */
 	public static function getServerHostName() {
-		$host_name = self::getServerHost();
+		$host_name = \OC::$server->getRequest()->getServerHost();
 		// strip away port number (if existing)
 		$colon_pos = strpos($host_name, ':');
 		if ($colon_pos != FALSE) {
@@ -394,68 +294,26 @@ class Util {
 		return $user_part.'@localhost.localdomain';
 	}
 
-	/**
-	 * Returns the server protocol. It respects reverse proxy servers and load balancers
-	 * @return string the server protocol
-	 * @deprecated 8.1.0 Use \OCP\IRequest::getServerProtocol
-	 * @since 4.5.0
-	 */
-	public static function getServerProtocol() {
-		return \OC::$server->getRequest()->getServerProtocol();
-	}
-
-	/**
-	 * Returns the request uri, even if the website uses one or more reverse proxies
-	 * @return string the request uri
-	 * @deprecated 8.1.0 Use \OCP\IRequest::getRequestUri
-	 * @since 5.0.0
-	 */
-	public static function getRequestUri() {
-		return \OC::$server->getRequest()->getRequestUri();
-	}
-
-	/**
-	 * Returns the script name, even if the website uses one or more reverse proxies
-	 * @return string the script name
-	 * @deprecated 8.1.0 Use \OCP\IRequest::getScriptName
-	 * @since 5.0.0
-	 */
-	public static function getScriptName() {
-		return \OC::$server->getRequest()->getScriptName();
-	}
-
-	/**
-	 * Creates path to an image
-	 * @param string $app app
-	 * @param string $image image name
-	 * @return string the url
-	 * @deprecated 8.1.0 Use \OC::$server->getURLGenerator()->imagePath($app, $image)
-	 * @since 4.0.0
-	 */
-	public static function imagePath( $app, $image ) {
-		return \OC::$server->getURLGenerator()->imagePath($app, $image);
-	}
-
 	/**
 	 * Make a human file size (2048 to 2 kB)
 	 * @param int $bytes file size in bytes
 	 * @return string a human readable file size
 	 * @since 4.0.0
 	 */
-	public static function humanFileSize( $bytes ) {
-		return(\OC_Helper::humanFileSize( $bytes ));
+	public static function humanFileSize($bytes) {
+		return \OC_Helper::humanFileSize($bytes);
 	}
 
 	/**
 	 * Make a computer file size (2 kB to 2048)
 	 * @param string $str file size in a fancy format
-	 * @return int a file size in bytes
+	 * @return float a file size in bytes
 	 *
 	 * Inspired by: http://www.php.net/manual/en/function.filesize.php#92418
 	 * @since 4.0.0
 	 */
-	public static function computerFileSize( $str ) {
-		return(\OC_Helper::computerFileSize( $str ));
+	public static function computerFileSize($str) {
+		return \OC_Helper::computerFileSize($str);
 	}
 
 	/**
@@ -472,8 +330,8 @@ class Util {
 	 * TODO: write example
 	 * @since 4.0.0
 	 */
-	static public function connectHook($signalClass, $signalName, $slotClass, $slotName ) {
-		return(\OC_Hook::connect($signalClass, $signalName, $slotClass, $slotName ));
+	static public function connectHook($signalClass, $signalName, $slotClass, $slotName) {
+		return \OC_Hook::connect($signalClass, $signalName, $slotClass, $slotName);
 	}
 
 	/**
@@ -486,8 +344,8 @@ class Util {
 	 * TODO: write example
 	 * @since 4.0.0
 	 */
-	static public function emitHook( $signalclass, $signalname, $params = array()) {
-		return(\OC_Hook::emit( $signalclass, $signalname, $params ));
+	static public function emitHook($signalclass, $signalname, $params = array()) {
+		return \OC_Hook::emit($signalclass, $signalname, $params);
 	}
 
 	/**
@@ -520,7 +378,7 @@ class Util {
 			exit();
 		}
 
-		if (!(\OC::$server->getRequest()->passesCSRFCheck())) {
+		if (!\OC::$server->getRequest()->passesCSRFCheck()) {
 			exit();
 		}
 	}
@@ -551,7 +409,7 @@ class Util {
 	 * @since 6.0.0
 	 */
 	public static function encodePath($component) {
-		return(\OC_Util::encodePath($component));
+		return \OC_Util::encodePath($component);
 	}
 
 	/**
@@ -564,7 +422,7 @@ class Util {
 	 * @since 4.5.0
 	 */
 	public static function mb_array_change_key_case($input, $case = MB_CASE_LOWER, $encoding = 'UTF-8') {
-		return(\OC_Helper::mb_array_change_key_case($input, $case, $encoding));
+		return \OC_Helper::mb_array_change_key_case($input, $case, $encoding);
 	}
 
 	/**
@@ -604,12 +462,12 @@ class Util {
 	 *
 	 * @param array $haystack the array to be searched
 	 * @param string $needle the search string
-	 * @param int $index optional, only search this key name
+	 * @param mixed $index optional, only search this key name
 	 * @return mixed the key of the matching field, otherwise false
 	 * @since 4.5.0
 	 */
 	public static function recursiveArraySearch($haystack, $needle, $index = null) {
-		return(\OC_Helper::recursiveArraySearch($haystack, $needle, $index));
+		return \OC_Helper::recursiveArraySearch($haystack, $needle, $index);
 	}
 
 	/**
@@ -650,27 +508,17 @@ class Util {
 	 * @return bool true if the file name is valid, false otherwise
 	 * @deprecated 8.1.0 use \OC\Files\View::verifyPath()
 	 * @since 7.0.0
+	 * @suppress PhanDeprecatedFunction
 	 */
 	public static function isValidFileName($file) {
 		return \OC_Util::isValidFileName($file);
 	}
 
-	/**
-	 * Generates a cryptographic secure pseudo-random string
-	 * @param int $length of the random string
-	 * @return string
-	 * @deprecated 8.0.0 Use \OC::$server->getSecureRandom()->getMediumStrengthGenerator()->generate($length); instead
-	 * @since 7.0.0
-	 */
-	public static function generateRandomBytes($length = 30) {
-		return \OC::$server->getSecureRandom()->generate($length, \OCP\Security\ISecureRandom::CHAR_LOWER.\OCP\Security\ISecureRandom::CHAR_DIGITS);
-	}
-
 	/**
 	 * Compare two strings to provide a natural sort
 	 * @param string $a first string to compare
 	 * @param string $b second string to compare
-	 * @return -1 if $b comes before $a, 1 if $a comes before $b
+	 * @return int -1 if $b comes before $a, 1 if $a comes before $b
 	 * or 0 if the strings are identical
 	 * @since 7.0.0
 	 */
@@ -706,8 +554,18 @@ class Util {
 	 */
 	public static function needUpgrade() {
 		if (!isset(self::$needUpgradeCache)) {
-			self::$needUpgradeCache=\OC_Util::needUpgrade(\OC::$server->getConfig());
+			self::$needUpgradeCache=\OC_Util::needUpgrade(\OC::$server->getSystemConfig());
 		}		
 		return self::$needUpgradeCache;
 	}
+
+	/**
+	 * is this Internet explorer ?
+	 *
+	 * @return boolean
+	 * @since 14.0.0
+	 */
+	public static function isIe() {
+		return \OC_Util::isIe();
+	}
 }
