@@ -11,11 +11,8 @@ OC.L10N.register(
     "You successfully logged in using two-factor authentication (%1$s)" : "Έχετε συνδεθεί επιτυχώς με τη χρήση ελέγχου ταυτότητας δύο-παραγόντων (%1$s)",
     "A login attempt using two-factor authentication failed (%1$s)" : "Μία προσπάθεια σύνδεσης με τη χρήση ελέγχου ταυτότητας δύο-παραγόντων απέτυχε (%1$s)",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ο δικός σας <ισχυρός>κωδικός πρόσβασης</ισχυρός>ή<ισχυρός>αλληλογραφίας</ισχυρός>τροποποιήθηκε",
-    "Your apps" : "Οι εφαρμογές σας",
-    "Updates" : "Ενημερώσεις",
-    "Enabled apps" : "Ενεργοποιημένες εφαρμογές",
-    "Disabled apps" : "Απενεργοποιημένες εφαρμογές",
-    "App bundles" : "Πακέτα εφαρμογών",
+    "Couldn't remove app." : "Αδυναμία αφαίρεσης εφαρμογής.",
+    "Couldn't update app." : "Αδυναμία ενημέρωσης εφαρμογής",
     "Wrong password" : "Εσφαλμένο συνθηματικό",
     "Saved" : "Αποθηκεύτηκαν",
     "No user supplied" : "Δεν εισήχθη χρήστης",
@@ -26,10 +23,6 @@ OC.L10N.register(
     "Backend doesn't support password change, but the user's encryption key was updated." : "Το σύστημα δεν υποστηρίζει αλλαγή κωδικού, αλλά το κλειδί κρυπτογράφησης του χρήστη ενημερώθηκε επιτυχώς.",
     "installing and updating apps via the app store or Federated Cloud Sharing" : "εγκατάσταση και ενημέρωση εφαρμογών μέσω του καταστήματος εφαρμογών ή του ",
     "Federated Cloud Sharing" : "Διαμοιρασμός σε ομόσπονδα σύννεφα ",
-    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "Το cURL χρησιμοποιεί μια παρωχημένη %s έκδοση (%s). Παρακαλούμε αναβαθμίστε το λειτουργικό σας σύστημα αλλιώς δυνατότητες όπως %s δεν θα δουλέψουν αξιόπιστα.",
-    "Group already exists." : "Η ομάδα υπάρχει ήδη.",
-    "Unable to add group." : "Αδυναμία προσθήκης ομάδας.",
-    "Unable to delete group." : "Αδυναμία διαγραφής ομάδας.",
     "Invalid SMTP password." : "Μη έγκυρο συνθηματικό SMTP.",
     "Email setting test" : "Δοκιμή ρυθμίσεων email",
     "Well done, %s!" : "Συγχαρητήρια, %s!",
@@ -38,29 +31,16 @@ OC.L10N.register(
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Παρουσιάστηκε σφάλμα κατά την αποστολή e-mail. Παρακαλώ ελέγξτε τις ρυθμίσεις σας.(Error: %s)",
     "You need to set your user email before being able to send test emails." : "Πρέπει να ορίσετε το email του χρήστη πριν να είστε σε θέση να στείλετε δοκιμαστικά emails.",
     "Invalid mail address" : "Μη έγκυρη διεύθυνση ταχυδρομείου.",
-    "No valid group selected" : "Δεν επιλέθηκε έγκυρη ομάδα",
-    "A user with that name already exists." : "Υπάρχει ήδη χρήστης με το ίδιο όνομα",
-    "To send a password link to the user an email address is required." : "Για να στείλετε ένα σύνδεσμο συνθηματικού στον χρήστη μια διεύθυνση ηλεκτρονικού ταχυδρομείου είναι απαραίτητη.",
-    "Unable to create user." : "Αδυναμία δημιουργίας χρήστη.",
-    "Unable to delete user." : "Αδυναμία διαγραφής χρήστη.",
-    "Error while enabling user." : "Σφάλμα κατά την ενεργοποίηση χρήστη.",
-    "Error while disabling user." : "Σφάλμα κατά την απενεργοποίηση χρήστη.",
-    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Για να επιβεβαιώσετε τον λογαριασμό σας στο Twitter, δημοσιεύστε την παρακάτω δημοσίευση στο Twitter (σιγουρευτείτε ότι την δημοσιεύετε χωρίς χαρακτήρες αλλαγής γραμμής)",
     "Settings saved" : "Οι ρυθμίσεις αποθηκεύτηκαν",
     "Unable to change full name" : "Δεν ήταν δυνατή η αλλαγή του πλήρους ονόματός σας",
     "Unable to change email address" : "Αδυναμία αλλαγής διεύθυνσης ηλεκτρονικής αλληλογραφίας",
-    "Your full name has been changed." : "Το πλήρες όνομά σας άλλαξε.",
-    "Forbidden" : "Δεν επιτρέπεται",
-    "Invalid user" : "Μη έγκυρος χρήστης",
-    "Unable to change mail address" : "Αδυναμία αλλαγής διεύθυνσης αλληλογραφίας",
-    "Email saved" : "Το email αποθηκεύτηκε ",
+    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Για να επιβεβαιώσετε τον λογαριασμό σας στο Twitter, δημοσιεύστε την παρακάτω δημοσίευση στο Twitter (σιγουρευτείτε ότι την δημοσιεύετε χωρίς χαρακτήρες αλλαγής γραμμής)",
     "%1$s changed your password on %2$s." : "%1$sάλλαξε το συνθηματικό σε %2$s.",
     "Your password on %s was changed." : "Ο κωδικός πρόσβασης στο %s έχει αλλάξει.",
     "Your password on %s was reset by an administrator." : "Έχει γίνει επαναφορά του κωδικού πρόσβασης στο %s από τον διαχειριστή.",
     "Password for %1$s changed on %2$s" : "Ο κωδικός πρόσβασης για το %1$s άλλαξε σε %2$s",
     "Password changed for %s" : "Το συνθηματικό άλλαξε για τον %s",
     "If you did not request this, please contact an administrator." : "Εάν δεν το αιτηθήκατε, παρακαλούμε επικοινωνήστε με τον διαχειριστή.",
-    "%1$s changed your email address on %2$s." : "%1$sάλλαξε τη διεύθυνση ηλεκτρονικού ταχυδρομείου σε %2$s.",
     "Your email address on %s was changed." : "Η ηλεκτρονική σας διεύθυνση στο %s έχει αλλάξει.",
     "Your email address on %s was changed by an administrator." : "Η διεύθυνση ηλεκτρονικής αλληλογραφίας στο %s άλλαξε από τον διαχειριστή.",
     "Email address for %1$s changed on %2$s" : "Η διεύθυνση ηλεκτρονικού ταχυδρομείου για το %1$s άλλαξε σε %2$s",
@@ -73,38 +53,11 @@ OC.L10N.register(
     "Set your password" : "Καθορισμός συνθηματικού",
     "Go to %s" : "Πηγαίνετε στο %s",
     "Install Client" : "Εγκατάσταση πελάτη",
-    "Password confirmation is required" : "Απαιτείται επιβεβαίωση συνθηματικού",
-    "Couldn't remove app." : "Αδυναμία αφαίρεσης εφαρμογής.",
-    "Couldn't update app." : "Αδυναμία ενημέρωσης εφαρμογής",
     "Migration in progress. Please wait until the migration is finished" : "Μετάβαση σε εξέλιξη. Παρακαλούμε περιμένετε μέχρι να ολοκληρωθεί η μετάβαση",
     "Migration started …" : "Η μετάβαση ξεκίνησε ...",
     "Not saved" : "Δεν αποθηκεύτηκε",
     "Sending…" : "Γινεται αποστολή...",
     "Email sent" : "Το Email απεστάλη ",
-    "Official" : "Επίσημο",
-    "All" : "Όλες",
-    "Update to %s" : "Ενημέρωση σε %s",
-    "No apps found for your version" : "Δεν βρέθηκαν εφαρμογές για αυτή την έκδοση",
-    "The app will be downloaded from the app store" : "Αυτή η εφαρμογή θα ",
-    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Οι επίσημες εφαρμογές αναπτύσσονται μέσα από την κοινότητα. Προσφέρουν κεντρική λειτουργικότητα και είναι έτοιμες για παραγωγική χρήση. ",
-    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Οι εγκεκριμένες εφαρμογές αναπτύχθηκαν από αξιόπιστους προγραμματιστές και έχουν περάσει έναν συνοπτικό έλεγχο ασφαλείας. Διατηρούνται ενεργά σε ένα αποθετήριο ανοιχτού κώδικα και οι συντηρητές θεωρούν οτι είναι σταθερές για κανονική χρήση.",
-    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Η εφαρμογή αυτή δεν ελέγχεται για θέματα ασφάλειας και είναι νέα ή είναι γνωστό ότι είναι ασταθής. Η εγκατάσταση γίνεται με δική σας ευθύνη.",
-    "Disabling app …" : "Γίνεται απενεργοποίηση εφαρμογής...",
-    "Error while disabling app" : "Σφάλμα κατά την απενεργοποίηση εισόδου",
-    "Disable" : "Απενεργοποίηση",
-    "Enable" : "Ενεργοποίηση",
-    "Enabling app …" : "Γίνεται ενεργοποίηση εφαρμογής...",
-    "Error while enabling app" : "Σφάλμα κατά την ενεργοποίηση της εφαρμογής",
-    "Error: Could not disable broken app" : "Σφάλμα: αδυναμία απενεργοποίησης κατεστραμμένης εφαρμογής",
-    "Error while disabling broken app" : "Σφάλμα κατά την απενεργοποίηση κατεστραμμένης εφαρμογής",
-    "App up to date" : "Ενημερωμένη εφαρμογή",
-    "Updated" : "Ενημερώθηκε",
-    "Removing …" : "Αφαίρεση ...",
-    "Remove" : "Αφαίρεση",
-    "Approved" : "Εγκεκριμένο",
-    "Experimental" : "Πειραματικό",
-    "No apps found for {query}" : "Δεν βρέθηκαν εφαρμογές για {query}",
-    "Enable all" : "Ενεργοποίηση όλων",
     "Disconnect" : "Αποσύνδεση",
     "Revoke" : "Ανάκληση",
     "Internet Explorer" : "Internet Explorer",
@@ -140,49 +93,58 @@ OC.L10N.register(
     "Will be synced to a global and public address book" : "Θα συγχρονιστεί με παγκόσμιο και δημόσιο βιβλίο διευθύνσεων",
     "Verify" : "Επαλήθευση",
     "Verifying …" : "Γίνεται επαλήθευση ...",
-    "Select a profile picture" : "Επιλογή εικόνας προφίλ",
     "Very weak password" : "Πολύ αδύναμο συνθηματικό",
     "Weak password" : "Αδύναμο συνθηματικό",
     "So-so password" : "Μέτριο συνθηματικό",
     "Good password" : "Καλό συνθηματικό",
     "Strong password" : "Δυνατό συνθηματικό",
+    "Select a profile picture" : "Επιλογή εικόνας προφίλ",
     "Groups" : "Ομάδες",
-    "Unable to delete {objName}" : "Αδυναμία διαγραφής του {objName}",
-    "Error creating group: {message}" : "Σφάλμα δημιουργίας ομάδας: {message}",
-    "A valid group name must be provided" : "Πρέπει να δοθεί ένα έγκυρο όνομα ομάδας",
-    "deleted {groupName}" : "διαγραφή {groupName}",
-    "undo" : "αναίρεση",
-    "{size} used" : "{μέγεθος} που χρησιμοποιείται",
-    "never" : "ποτέ",
-    "deleted {userName}" : "διαγραφή {userName}",
-    "No user found for <strong>{pattern}</strong>" : "Δεν βρέθηκαν χρήστες για την αναζήτηση {search}",
-    "Unable to add user to group {group}" : "Αδυναμία προσθήκης χρήστη στην ομάδα {group}",
-    "Unable to remove user from group {group}" : "Αδυναμία αφαίρεσης χρήστη από την ομάδα {group}",
-    "Add group" : "Προσθήκη ομάδας",
-    "no group" : "καμια ομάδα",
-    "Password successfully changed" : "Το συνθηματικό αλλάχτηκε επιτυχώς",
-    "Changing the password will result in data loss, because data recovery is not available for this user" : "Η αλλαγή του κωδικού πρόσβασης θα έχει ως αποτέλεσμα το χάσιμο δεδομένων, επειδή η ανάκτηση δεδομένων δεν είναι διαθέσιμη γι' αυτόν τον χρήστη",
-    "Could not change the users email" : "Αδυναμία αλλαγής της ηλεκτρονικής διεύθυνσης του χρήστη",
-    "Error while changing status of {user}" : "Σφάλμα κατά την αλλαγή κατάστασης του {χρήστη}",
-    "A valid username must be provided" : "Πρέπει να δοθεί έγκυρο όνομα χρήστη",
-    "Error creating user: {message}" : "Σφάλμα δημιουργίας χρήστη: {message}",
-    "Developer documentation" : "Τεκμηρίωση προγραμματιστή",
-    "View in store" : "Προβολή στο κέντρο εφαρμογών",
     "Limit to groups" : "Όριο στις ομάδες",
-    "by %s" : "από %s",
-    "%s-licensed" : "%s-αδειοδοτημένο",
-    "Documentation:" : "Τεκμηρίωση:",
-    "User documentation" : "Τεκμηρίωση Χρήστη",
-    "Admin documentation" : "Τεκμηρίωση Διαχειριστή",
+    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Οι επίσημες εφαρμογές αναπτύσσονται μέσα από την κοινότητα. Προσφέρουν κεντρική λειτουργικότητα και είναι έτοιμες για παραγωγική χρήση. ",
+    "Official" : "Επίσημο",
+    "Remove" : "Αφαίρεση",
+    "Disable" : "Απενεργοποίηση",
+    "All" : "Όλες",
+    "View in store" : "Προβολή στο κέντρο εφαρμογών",
     "Visit website" : "Επισκεφθείτε την ιστοσελίδα",
     "Report a bug" : "Αναφέρετε σφάλμα",
-    "Show description …" : "Εμφάνιση περιγραφής",
-    "Hide description …" : "Απόκρυψη περιγραφής",
-    "This app has an update available." : "Αυτή η εφαρμογή έχει διαθέσιμη ενημέρωση.",
+    "User documentation" : "Τεκμηρίωση Χρήστη",
+    "Admin documentation" : "Τεκμηρίωση Διαχειριστή",
+    "Developer documentation" : "Τεκμηρίωση προγραμματιστή",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Αυτή η εφαρμογή δεν έχει ελάχιστη έκδοση του Nextcloud ανατεθειμένη. Αυτό θα αποτελεί σφάλμα στο μέλλον.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Αυτή η εφαρμογή δεν έχει μέγιστη έκδοση του Nextcloud ανατεθειμένη. Αυτό θα αποτελεί σφάλμα στο μέλλον.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Αυτή η εφαρμογή δεν μπορεί να εγκατασταθεί διότι δεν εκπληρώνονται οι ακόλουθες εξαρτήσεις:",
-    "Enable only for specific groups" : "Ενεργοποίηση μόνο για καθορισμένες ομάδες",
+    "No apps found for your version" : "Δεν βρέθηκαν εφαρμογές για αυτή την έκδοση",
+    "Enable all" : "Ενεργοποίηση όλων",
+    "Enable" : "Ενεργοποίηση",
+    "The app will be downloaded from the app store" : "Αυτή η εφαρμογή θα ",
+    "New password" : "Νέο συνθηματικό",
+    "Delete user" : "Διαγραφή χρήστη",
+    "Enable user" : "Ενεργοποίηση χρήστη",
+    "{size} used" : "{μέγεθος} που χρησιμοποιείται",
+    "Welcome mail sent!" : "Απεστάλη το μήνυμα καλωσορίσματος!",
+    "Username" : "Όνομα χρήστη",
+    "Password" : "Συνθηματικό",
+    "Email" : "Ηλεκτρονικό ταχυδρομείο",
+    "Group admin for" : "Ομαδα διαχειριστή για",
+    "Quota" : "Σύνολο Χώρου",
+    "Language" : "Γλώσσα",
+    "Storage location" : "Τοποθεσία αποθηκευτικού χώρου",
+    "User backend" : "Σύστημα υποστήριξης χρήστη",
+    "Last login" : "Τελευταία είσοδος",
+    "Unlimited" : "Απεριόριστο",
+    "Default quota" : "Προεπιλέγμενη χωρητικότητα",
+    "Your apps" : "Οι εφαρμογές σας",
+    "Disabled apps" : "Απενεργοποιημένες εφαρμογές",
+    "Updates" : "Ενημερώσεις",
+    "App bundles" : "Πακέτα εφαρμογών",
+    "Show last login" : "Εμφάνιση τελευταιας σύνδεσης",
+    "Show user backend" : "Εμφάνιση χρήστη συστήματος υποστήριξης",
+    "Admins" : "Διαχειριστές",
+    "Everyone" : "Όλοι",
+    "Add group" : "Προσθήκη ομάδας",
+    "App update" : "Ενημέρωση εφαρμογής",
     "SSL Root Certificates" : "Πιστοποιητικά SSL του Root",
     "Common Name" : "Κοινό Όνομα",
     "Valid until" : "Έγκυρο έως",
@@ -190,10 +152,7 @@ OC.L10N.register(
     "Valid until %s" : "Έγκυρο έως %s",
     "Import root certificate" : "Εισαγωγή Πιστοποιητικού Root",
     "Administrator documentation" : "Τεκμηρίωση Διαχειριστή",
-    "Online documentation" : "Τεκμηρίωση στο Διαδίκτυο",
     "Forum" : "Φόρουμ",
-    "Getting help" : "Λήψη βοήθειας",
-    "Commercial support" : "Εμπορική Υποστήριξη",
     "None" : "Τίποτα",
     "Login" : "Σύνδεση",
     "Plain" : "Απλό",
@@ -217,10 +176,15 @@ OC.L10N.register(
     "Store credentials" : "Διαπιστευτήρια αποθήκευσης",
     "Test email settings" : "Δοκιμή ρυθμίσεων email",
     "Send email" : "Αποστολή email",
+    "Security & setup warnings" : "Προειδοποιήσεις ασφάλειας & ρυθμίσεων",
+    "All checks passed." : "Όλοι οι έλεγχοι επιτυχείς.",
+    "There are some errors regarding your setup." : "Υπάρχουν μερικά σφάλματα σχετικά με τις ρυθμίσεις σας.",
+    "Version" : "Έκδοση",
     "Server-side encryption" : "Κρυπτογράφηση από τον Διακομιστή",
     "Enable server-side encryption" : "Ενεργοποίηση κρυπτογράφησης από το διακομιστή",
     "Please read carefully before activating server-side encryption: " : "Παρακαλούμε διαβάστε προσεκτικά πριν ενεργοποιήσετε την κρυπτογράφηση στο διακομιστή:",
     "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Μόλις ενεργοποιηθεί η κρυπτογράφηση, όλα τα αρχεία που θα μεταφορτωθούν από αυτό το σημείο και μετά θα κρυπτογραφηθούν στο διακομιστή. Η κρυπτογράφηση είναι δυνατόν να απενεργοποιηθεί αργότερα μόνο αν το ενεργό άρθρωμα κρυπτογράφησης υποστηρίζει αυτή τη λειτουργία και εκπληρούνται όλες οι προϋποθέσεις (πχ ορισμός κλειδιού ανάκτησης).",
+    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Η κρυπτογράφηση από μόνη της δεν εγγυάται την ασφάλεια του συστήματος. Για περισσότερες πληροφορίες σχετικά με τον τρόπο λειτουργίας της εφαρμογής κρυπτογράφησης και τις υποστηριζόμενες περιπτώσεις χρήσης, ανατρέξτε στην τεκμηρίωση.",
     "Be aware that encryption always increases the file size." : "Έχετε στο νου σας πως η κρυπτογράφηση πάντα αυξάνει το μέγεθος του αρχείου",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Είναι πάντοτε καλό να δημιουργείτε τακτικά αντίγραφα ασφαλείας των δεδομένων σας, στην περίπτωση της κρυπτογράφησης βεβαιωθείτε ότι έχετε λάβει αντίγραφο ασφαλείας των κλειδιών κρυπτογράφησης παράλληλα με τα δεδομένα σας.",
     "This is the final warning: Do you really want to enable encryption?" : "Αυτή είναι η τελευταία προειδοποίηση: Θέλετε πραγματικά να ενεργοποιήσετε την κρυπτογράφηση;",
@@ -230,18 +194,12 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Πρέπει να μεταφέρετε τα κλειδιά κρυπτογράφησής σας από την παλιά κρυπτογράφηση (ownCloud <= 8.0) στην καινούρια. Παρακαλούμε ενεργοποιήστε την \"Προεπιλεγμένη Μονάδα Κρυπτογράφησης\" και εκτελέστε την εντολή 'occ encryption:migrate'",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Πρέπει να μεταφέρετε τα κλειδιά σας κρυπτογράφησης από την παλιά κρυπτογράφηση (ownCloud <= 8.0) στην καινούρια.",
     "Start migration" : "Έναρξη μετάβασης",
-    "Security & setup warnings" : "Προειδοποιήσεις ασφάλειας & ρυθμίσεων",
-    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Η ρύθμιση  \"μόνο ανάγνωση\"  έχει ενεργοποιηθεί. Αυτό εμποδίζει τον καθορισμό κάποιων ρυθμίσεων μέσω της διεπαφής web. Επιπλέον, το αρχείο πρέπει να γίνει χειροκίνητα εγγράψιμο πριν από κάθε διαδικασία ενημέρωσης.",
-    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Αυτό πιθανόν προκλήθηκε από προσωρινή μνήμη (cache)/επιταχυντή όπως τη Zend OPcache ή τον eAccelerator.",
-    "System locale can not be set to a one which supports UTF-8." : "Οι ρυθμίσεις τοποθεσίας συστήματος δεν μπορούν να οριστούν σε κάποιες που δεν υποστηρίζουν UTF-8.",
-    "All checks passed." : "Όλοι οι έλεγχοι επιτυχείς.",
     "Background jobs" : "Εργασίες παρασκηνίου",
     "Execute one task with each page loaded" : "Εκτελεί μια διεργασία κάθε φορά που φορτώνεται μια σελίδα",
     "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "Το cron.php είναι καταχωρημένο σε μια υπηρεσία webcron ώστε να καλεί το cron.php κάθε 15 λεπτά μέσω HTTP.",
     "Use system cron service to call the cron.php file every 15 minutes." : "Χρησιμοποιήστε την cron υπηρεσία του συστήματος για να καλέσετε το cron.php αρχείο κάθε 15 λεπτά.",
     "The cron.php needs to be executed by the system user \"%s\"." : "Το cron.php πρέπει να εκτελεστεί από τον χρήστη του συστήματος \"%s\".",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Για να τρέξετε αυτό χρειάζεστε την επέκταση PHP POSIX. Δείτε {linkstart} PHP τεκμηρίωση {linked} για περισσότερες λεπτομέρειες.",
-    "Version" : "Έκδοση",
     "Sharing" : "Διαμοιρασμός",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Ως διαχειριστής μπορείτε να ρυθμίσετε λεπτομερώς την συμπεριφορά διαμοιρασμού.\nΠαρακαλούμε ανατρέξτε στην τεκμηρίωση για περισσότερες πληροφορίες.",
     "Allow apps to use the Share API" : "Επιτρέπει την χρήση του API διαμοιρασμού σε εφαρμογές ",
@@ -258,16 +216,13 @@ OC.L10N.register(
     "Restrict users to only share with users in their groups" : "Να επιτρέπεται σε χρήστες ο διαμοιρασμός μόνο με χρήστες που ανήκουν στις ομάδες τους",
     "Exclude groups from sharing" : "Εξαίρεση ομάδων από τον διαμοιρασμό",
     "These groups will still be able to receive shares, but not to initiate them." : "Αυτές οι ομάδες θα συνεχίσουν να λαμβάνουν διαμοιρασμούς, αλλά δεν θα είναι δυνατό να τους δημιουργήσουν.",
+    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Να επιτρέπεται η χρήση αυτόματης συμπλήρωσης του ονόματος χρήστη στο πεδίο διαμοιρασμού. Αν η ρύθμιση αυτή είναι απενεργοποιημένη θα πρέπει να εισαχθεί το πλήρες όνομα χρήστη ή το email του. ",
     "This text will be shown on the public link upload page when the file list is hidden." : "Αυτό το κείμενο θα ",
-    "Tips & tricks" : "Συμβουλές & τεχνάσματα",
-    "How to do backups" : "Πώς να κάνετε αντίγραφα ασφαλείας",
-    "Performance tuning" : "Ρύθμιση βελτίωσης της απόδοσης",
-    "Improving the config.php" : "Βελτίωση του  config.php",
-    "Theming" : "Θέματα",
-    "Check the security of your Nextcloud over our security scan" : "Ελέγξτε την ασφάλεια του Nextcloud σας μέσω της σάρωσης ασφαλείας",
-    "Hardening and security guidance" : "Οδηγίες ασφάλειας και θωράκισης",
-    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Χρησιμοποιείτε <strong>%s</strong> από <strong>%s</strong>",
-    "You are using <strong>%s</strong> of <strong>%s</strong> (<strong>%s %%</strong>)" : "Χρησιμοποιείτε <strong>%s</strong> του <strong>%s</strong>(<strong>%s%%</strong>)",
+    "Follow us on Google+" : "Ακολουθήστε μας στο Google+",
+    "Like our Facebook page" : "Ακολουθήστε μας στην σελίδα μας στο facebook!",
+    "Follow us on Twitter" : "Ακολουθήστε μας στο Twitter",
+    "Check out our blog" : "Επισκεφθείτε το ιστολόγιό μας!",
+    "Subscribe to our newsletter" : "Εγγραφείτε στο ενημερωτικό δελτίο μας!",
     "Profile picture" : "Φωτογραφία προφίλ",
     "Upload new" : "Μεταφόρτωση νέου",
     "Select from Files" : "Επιλογή από τα Αρχεία",
@@ -276,10 +231,9 @@ OC.L10N.register(
     "Picture provided by original account" : "Φωτογραφία που παρέχεται από τον πρωτότυπο λογαριασμό",
     "Cancel" : "Άκυρο",
     "Choose as profile picture" : "Επιλέξτε εικόνα προφίλ",
-    "You are member of the following groups:" : "Είστε μέλος των ακόλουθων ομάδων:",
+    "Details" : "Λεπτομέρειες",
     "Full name" : "Πλήρες όνομα",
     "No display name set" : "Δεν ορίστηκε όνομα",
-    "Email" : "Ηλεκτρονικό ταχυδρομείο",
     "Your email address" : "Η διεύθυνση ηλ. ταχυδρομείου σας",
     "No email address set" : "Δεν ορίστηκε διεύθυνση email",
     "For password reset and notifications" : "Για ανάκτηση συνθηματικού και ειδοποιήσεις",
@@ -291,11 +245,8 @@ OC.L10N.register(
     "It can take up to 24 hours before the account is displayed as verified." : "Η επαλήθευση του λογαριασμού μπορεί να διαρκέσει έως και 24 ώρες.",
     "Link https://…" : "Σύνδεσμος https://…",
     "Twitter" : "Twitter",
-    "Language" : "Γλώσσα",
     "Help translate" : "Βοηθήστε στη μετάφραση",
-    "Password" : "Συνθηματικό",
     "Current password" : "Τρέχων συνθηματικό",
-    "New password" : "Νέο συνθηματικό",
     "Change password" : "Αλλαγή συνθηματικού",
     "Web, desktop and mobile clients currently logged in to your account." : " ",
     "Device" : "Συσκευή",
@@ -304,49 +255,92 @@ OC.L10N.register(
     "Create new app password" : "Δημιουργία νέου συνθηματικού εφαρμογής",
     "Use the credentials below to configure your app or device." : "Χρησιμοποιήστε τα παρακάτω διαπιστευτήρια για να ρυθμίσετε την εφαρμογή ή την συσκευή σας.",
     "For security reasons this password will only be shown once." : "Για λόγους ασφαλείας αυτό το συνθηματικό θα εμφανιστεί μόνο μια φορά.",
-    "Username" : "Όνομα χρήστη",
     "Done" : "Ολοκληρώθηκε",
-    "Follow us on Google+" : "Ακολουθήστε μας στο Google+",
-    "Like our Facebook page" : "Ακολουθήστε μας στην σελίδα μας στο facebook!",
-    "Follow us on Twitter" : "Ακολουθήστε μας στο Twitter",
-    "Check out our blog" : "Επισκεφθείτε το ιστολόγιό μας!",
-    "Subscribe to our newsletter" : "Εγγραφείτε στο ενημερωτικό δελτίο μας!",
-    "Settings" : "Ρυθμίσεις",
-    "Show storage location" : "Εμφάνιση τοποθεσίας αποθήκευσης",
-    "Show user backend" : "Εμφάνιση χρήστη συστήματος υποστήριξης",
-    "Show last login" : "Εμφάνιση τελευταιας σύνδεσης",
-    "Add user" : "Προσθήκη χρήστη",
-    "Everyone" : "Όλοι",
-    "Admins" : "Διαχειριστές",
-    "Disabled" : "Απενεργοποιημένο",
-    "Default quota" : "Προεπιλέγμενη χωρητικότητα",
-    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Παρακαλώ εισάγετε επιτρεπόμενα μερίδια αποθηκευτικού χώρου (π.χ. \"512 MB\"  ή \"12 GB\")",
-    "Unlimited" : "Απεριόριστο",
-    "Other" : "Άλλο",
-    "Group admin for" : "Ομαδα διαχειριστή για",
-    "Recovery password" : "Επαναφορά συνθηματικού",
-    "Quota" : "Σύνολο Χώρου",
-    "Storage location" : "Τοποθεσία αποθηκευτικού χώρου",
-    "User backend" : "Σύστημα υποστήριξης χρήστη",
-    "Last login" : "Τελευταία είσοδος",
-    "E-Mail" : "Ηλεκτρονική αλληλογραφία",
-    "Admin Recovery Password" : "Κωδικός Επαναφοράς Διαχειριστή ",
-    "Enter the recovery password in order to recover the users files during password change" : "Εισάγετε το συνθηματικό ανάκτησης ώστε να ανακτήσετε τα αρχεία χρηστών κατά την αλλαγή συνθηματικού",
-    "change full name" : "αλλαγή πλήρους ονόματος",
-    "set new password" : "επιλογή νέου κωδικού",
-    "change email address" : "αλλαγή διεύθυνσης ηλ. αλληλογραφίας",
-    "Default" : "Προκαθορισμένο",
+    "Enabled apps" : "Ενεργοποιημένες εφαρμογές",
+    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "Το cURL χρησιμοποιεί μια παρωχημένη %s έκδοση (%s). Παρακαλούμε αναβαθμίστε το λειτουργικό σας σύστημα αλλιώς δυνατότητες όπως %s δεν θα δουλέψουν αξιόπιστα.",
     "A problem occurred, please check your log files (Error: %s)" : "Παρουσιάστηκε πρόβλημα, παρακαλώ ελέγξτε τα αρχεία καταγραφής σας (Σφάλμα: %s)",
     "Migration Completed" : "Η μετάβαση ολοκληρώθηκε",
+    "Group already exists." : "Η ομάδα υπάρχει ήδη.",
+    "Unable to add group." : "Αδυναμία προσθήκης ομάδας.",
+    "Unable to delete group." : "Αδυναμία διαγραφής ομάδας.",
+    "No valid group selected" : "Δεν επιλέθηκε έγκυρη ομάδα",
+    "A user with that name already exists." : "Υπάρχει ήδη χρήστης με το ίδιο όνομα",
+    "To send a password link to the user an email address is required." : "Για να στείλετε ένα σύνδεσμο συνθηματικού στον χρήστη μια διεύθυνση ηλεκτρονικού ταχυδρομείου είναι απαραίτητη.",
+    "Unable to create user." : "Αδυναμία δημιουργίας χρήστη.",
+    "Unable to delete user." : "Αδυναμία διαγραφής χρήστη.",
+    "Error while enabling user." : "Σφάλμα κατά την ενεργοποίηση χρήστη.",
+    "Error while disabling user." : "Σφάλμα κατά την απενεργοποίηση χρήστη.",
+    "Your full name has been changed." : "Το πλήρες όνομά σας άλλαξε.",
+    "Forbidden" : "Δεν επιτρέπεται",
+    "Invalid user" : "Μη έγκυρος χρήστης",
+    "Unable to change mail address" : "Αδυναμία αλλαγής διεύθυνσης αλληλογραφίας",
+    "Email saved" : "Το email αποθηκεύτηκε ",
+    "%1$s changed your email address on %2$s." : "%1$sάλλαξε τη διεύθυνση ηλεκτρονικού ταχυδρομείου σε %2$s.",
+    "Password confirmation is required" : "Απαιτείται επιβεβαίωση συνθηματικού",
     "Are you really sure you want add {domain} as trusted domain?" : "Θέλετε σίγουρα να προσθέσετε τον τομέα {domain} ως έμπιστο τομέα;",
     "Add trusted domain" : "Προσθέστε αξιόπιστη περιοχή",
+    "Update to %s" : "Ενημέρωση σε %s",
+    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Οι εγκεκριμένες εφαρμογές αναπτύχθηκαν από αξιόπιστους προγραμματιστές και έχουν περάσει έναν συνοπτικό έλεγχο ασφαλείας. Διατηρούνται ενεργά σε ένα αποθετήριο ανοιχτού κώδικα και οι συντηρητές θεωρούν οτι είναι σταθερές για κανονική χρήση.",
+    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Η εφαρμογή αυτή δεν ελέγχεται για θέματα ασφάλειας και είναι νέα ή είναι γνωστό ότι είναι ασταθής. Η εγκατάσταση γίνεται με δική σας ευθύνη.",
+    "Disabling app …" : "Γίνεται απενεργοποίηση εφαρμογής...",
+    "Error while disabling app" : "Σφάλμα κατά την απενεργοποίηση εισόδου",
+    "Enabling app …" : "Γίνεται ενεργοποίηση εφαρμογής...",
+    "Error while enabling app" : "Σφάλμα κατά την ενεργοποίηση της εφαρμογής",
+    "Error: Could not disable broken app" : "Σφάλμα: αδυναμία απενεργοποίησης κατεστραμμένης εφαρμογής",
+    "Error while disabling broken app" : "Σφάλμα κατά την απενεργοποίηση κατεστραμμένης εφαρμογής",
     "Updating...." : "Γίνεται ενημέρωση....",
     "Error while updating app" : "Σφάλμα κατά την ενημέρωση της εφαρμογής",
+    "Updated" : "Ενημερώθηκε",
+    "Removing …" : "Αφαίρεση ...",
+    "Error while removing app" : "Σφάλμα κατά την αφαίρεση της εφαρμογής",
+    "Approved" : "Εγκεκριμένο",
+    "Experimental" : "Πειραματικό",
+    "No apps found for {query}" : "Δεν βρέθηκαν εφαρμογές για {query}",
+    "Unable to delete {objName}" : "Αδυναμία διαγραφής του {objName}",
+    "Error creating group: {message}" : "Σφάλμα δημιουργίας ομάδας: {message}",
+    "A valid group name must be provided" : "Πρέπει να δοθεί ένα έγκυρο όνομα ομάδας",
+    "deleted {groupName}" : "διαγραφή {groupName}",
+    "undo" : "αναίρεση",
+    "never" : "ποτέ",
+    "deleted {userName}" : "διαγραφή {userName}",
+    "No user found for <strong>{pattern}</strong>" : "Δεν βρέθηκαν χρήστες για την αναζήτηση {search}",
+    "Unable to add user to group {group}" : "Αδυναμία προσθήκης χρήστη στην ομάδα {group}",
+    "Unable to remove user from group {group}" : "Αδυναμία αφαίρεσης χρήστη από την ομάδα {group}",
+    "no group" : "καμια ομάδα",
+    "Password successfully changed" : "Το συνθηματικό αλλάχτηκε επιτυχώς",
+    "Changing the password will result in data loss, because data recovery is not available for this user" : "Η αλλαγή του κωδικού πρόσβασης θα έχει ως αποτέλεσμα το χάσιμο δεδομένων, επειδή η ανάκτηση δεδομένων δεν είναι διαθέσιμη γι' αυτόν τον χρήστη",
+    "Could not change the users email" : "Αδυναμία αλλαγής της ηλεκτρονικής διεύθυνσης του χρήστη",
+    "Error while changing status of {user}" : "Σφάλμα κατά την αλλαγή κατάστασης του {χρήστη}",
+    "A valid username must be provided" : "Πρέπει να δοθεί έγκυρο όνομα χρήστη",
+    "Error creating user: {message}" : "Σφάλμα δημιουργίας χρήστη: {message}",
     "A valid password must be provided" : "Πρέπει να δοθεί έγκυρο συνθηματικό",
     "A valid email must be provided" : "Πρέπει να εισαχθεί ένα έγκυρο email",
     "__language_name__" : "Ελληνικά",
     "Personal info" : "Προσωπικές Πληροφορίες",
     "Sync clients" : "Συγχρονισμός πελατών",
+    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Η ρύθμιση  \"μόνο ανάγνωση\"  έχει ενεργοποιηθεί. Αυτό εμποδίζει τον καθορισμό κάποιων ρυθμίσεων μέσω της διεπαφής web. Επιπλέον, το αρχείο πρέπει να γίνει χειροκίνητα εγγράψιμο πριν από κάθε διαδικασία ενημέρωσης.",
+    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Αυτό πιθανόν προκλήθηκε από προσωρινή μνήμη (cache)/επιταχυντή όπως τη Zend OPcache ή τον eAccelerator.",
+    "System locale can not be set to a one which supports UTF-8." : "Οι ρυθμίσεις τοποθεσίας συστήματος δεν μπορούν να οριστούν σε κάποιες που δεν υποστηρίζουν UTF-8.",
+    "Tips & tricks" : "Συμβουλές & τεχνάσματα",
+    "How to do backups" : "Πώς να κάνετε αντίγραφα ασφαλείας",
+    "Performance tuning" : "Ρύθμιση βελτίωσης της απόδοσης",
+    "Improving the config.php" : "Βελτίωση του  config.php",
+    "Theming" : "Θέματα",
+    "Check the security of your Nextcloud over our security scan" : "Ελέγξτε την ασφάλεια του Nextcloud σας μέσω της σάρωσης ασφαλείας",
+    "Hardening and security guidance" : "Οδηγίες ασφάλειας και θωράκισης",
+    "This app has an update available." : "Αυτή η εφαρμογή έχει διαθέσιμη ενημέρωση.",
+    "by %s" : "από %s",
+    "%s-licensed" : "%s-αδειοδοτημένο",
+    "Documentation:" : "Τεκμηρίωση:",
+    "Show description …" : "Εμφάνιση περιγραφής",
+    "Hide description …" : "Απόκρυψη περιγραφής",
+    "Enable only for specific groups" : "Ενεργοποίηση μόνο για καθορισμένες ομάδες",
+    "Online documentation" : "Τεκμηρίωση στο Διαδίκτυο",
+    "Getting help" : "Λήψη βοήθειας",
+    "Commercial support" : "Εμπορική Υποστήριξη",
+    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Χρησιμοποιείτε <strong>%s</strong> από <strong>%s</strong>",
+    "You are using <strong>%s</strong> of <strong>%s</strong> (<strong>%s %%</strong>)" : "Χρησιμοποιείτε <strong>%s</strong> του <strong>%s</strong>(<strong>%s%%</strong>)",
+    "You are member of the following groups:" : "Είστε μέλος των ακόλουθων ομάδων:",
     "Desktop client" : "Πελάτης σταθερού υπολογιστή",
     "Android app" : "Εφαρμογή Android",
     "iOS app" : "Εφαρμογή iOS",
@@ -356,9 +350,25 @@ OC.L10N.register(
     "Follow us on Twitter!" : "Ακολουθήστε μας στο Twitter!",
     "Check out our blog!" : "Επισκεφθείτε το ιστολόγιό μας!",
     "Subscribe to our newsletter!" : "Εγγραφείτε στο ενημερωτικό δελτίο μας!",
+    "Settings" : "Ρυθμίσεις",
+    "Show storage location" : "Εμφάνιση τοποθεσίας αποθήκευσης",
     "Show email address" : "Εμφάνιση διεύθυνσης ηλ. αλληλογραφίας",
     "Send email to new user" : "Αποστολή μηνύματος στο νέο χρήστη",
+    "E-Mail" : "Ηλεκτρονική αλληλογραφία",
     "Create" : "Δημιουργία",
-    "Group name" : "Όνομα ομάδας"
+    "Admin Recovery Password" : "Κωδικός Επαναφοράς Διαχειριστή ",
+    "Enter the recovery password in order to recover the users files during password change" : "Εισάγετε το συνθηματικό ανάκτησης ώστε να ανακτήσετε τα αρχεία χρηστών κατά την αλλαγή συνθηματικού",
+    "Group name" : "Όνομα ομάδας",
+    "Disabled" : "Απενεργοποιημένο",
+    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Παρακαλώ εισάγετε επιτρεπόμενα μερίδια αποθηκευτικού χώρου (π.χ. \"512 MB\"  ή \"12 GB\")",
+    "Other" : "Άλλο",
+    "change full name" : "αλλαγή πλήρους ονόματος",
+    "set new password" : "επιλογή νέου κωδικού",
+    "change email address" : "αλλαγή διεύθυνσης ηλ. αλληλογραφίας",
+    "Default" : "Προκαθορισμένο",
+    "App up to date" : "Ενημερωμένη εφαρμογή",
+    "Updating …" : "Γίνεται ενημέρωση ....",
+    "Could not update app" : "Αδυναμία ενημέρωσης εφαρμογής",
+    "Could not remove app" : "Αδυναμία αφαίρεσης εφαρμογής"
 },
 "nplurals=2; plural=(n != 1);");
